@@ -174,7 +174,7 @@ struct State {
 	}
 	session->changes().messageUpdates(
 		Data::MessageUpdate::Flag::Destroyed
-	) | rpl::start_with_next([=](const Data::MessageUpdate &update) {
+	) | rpl::on_next([=](const Data::MessageUpdate &update) {
 		const auto i = context->cachedRead.find(update.item);
 		if (i != end(context->cachedRead)) {
 			session->api().request(i->second.requestId).cancel();
@@ -192,7 +192,7 @@ struct State {
 		session
 	) | rpl::skip(1) | rpl::filter(
 		rpl::mappers::_1
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		for (auto &[item, cache] : context->cachedRead) {
 			if (cache.data.current().state == Ui::WhoReadState::MyHidden) {
 				cache.data = Peers{ .state = Ui::WhoReadState::Unknown };
@@ -202,7 +202,7 @@ struct State {
 	session->api().globalPrivacy().hideReadTime(
 	) | rpl::skip(1) | rpl::filter(
 		!rpl::mappers::_1
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		for (auto &[item, cache] : context->cachedRead) {
 			if (cache.data.current().state == Ui::WhoReadState::MyHidden) {
 				cache.data = Peers{ .state = Ui::WhoReadState::Unknown };
@@ -240,13 +240,13 @@ struct State {
 [[nodiscard]] rpl::producer<Peers> WhoReadIds(
 		not_null<HistoryItem*> item,
 		not_null<QWidget*> context) {
-	auto weak = QPointer<QWidget>(context.get());
+	auto weak = base::make_weak(context);
 	const auto session = &item->history()->session();
 	return [=](auto consumer) {
 		if (!weak) {
 			return rpl::lifetime();
 		}
-		const auto context = PreparedContextAt(weak.data(), session);
+		const auto context = PreparedContextAt(weak.get(), session);
 		auto &entry = context->cacheRead(item);
 		if (entry.requestId) {
 		} else if (const auto user = item->history()->peer->asUser()) {
@@ -325,13 +325,13 @@ struct State {
 		not_null<HistoryItem*> item,
 		const ReactionId &reaction,
 		not_null<QWidget*> context) {
-	auto weak = QPointer<QWidget>(context.get());
+	auto weak = base::make_weak(context);
 	const auto session = &item->history()->session();
 	return [=](auto consumer) {
 		if (!weak) {
 			return rpl::lifetime();
 		}
-		const auto context = PreparedContextAt(weak.data(), session);
+		const auto context = PreparedContextAt(weak.get(), session);
 		auto &entry = context->cacheReacted(item, reaction);
 		if (!entry.requestId) {
 			using Flag = MTPmessages_GetMessageReactionsList::Flag;
@@ -590,7 +590,7 @@ rpl::producer<Ui::WhoReadContent> WhoReacted(
 		}
 		std::move(
 			idsWithReactions
-		) | rpl::start_with_next([=](PeersWithReactions &&peers) {
+		) | rpl::on_next([=](PeersWithReactions &&peers) {
 			if (peers.state == WhoReadState::Unknown) {
 				state->userpics.clear();
 				consumer.put_next(Ui::WhoReadContent{
@@ -624,7 +624,7 @@ rpl::producer<Ui::WhoReadContent> WhoReacted(
 		item->history()->session().downloaderTaskFinished(
 		) | rpl::filter([=] {
 			return state->someUserpicsNotLoaded && !state->scheduled;
-		}) | rpl::start_with_next([=] {
+		}) | rpl::on_next([=] {
 			for (const auto &userpic : state->userpics) {
 				if (userpic.peer->userpicUniqueKey(userpic.view)
 					!= userpic.uniqueKey) {
