@@ -24,7 +24,6 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 #include "ui/rect.h"
 #include "ui/text/text_utilities.h"
 #include "ui/vertical_list.h"
-#include "ui/widgets/label_with_custom_emoji.h"
 #include "window/window_session_controller.h"
 #include "styles/style_boxes.h"
 #include "styles/style_channel_earn.h"
@@ -53,9 +52,8 @@ void GiftCreditsBox(
 	Ui::AddSkip(content);
 	const auto &stUser = st::premiumGiftsUserpicButton;
 	const auto userpicWrap = content->add(
-		object_ptr<Ui::CenterWrap<>>(
-			content,
-			object_ptr<Ui::UserpicButton>(content, peer, stUser)));
+		object_ptr<Ui::UserpicButton>(content, peer, stUser),
+		style::al_top);
 	userpicWrap->setAttribute(Qt::WA_TransparentForMouseEvents);
 	Ui::AddSkip(content);
 	Ui::AddSkip(content);
@@ -78,19 +76,17 @@ void GiftCreditsBox(
 				u"internal:stars_examples"_q);
 		});
 		content->add(
-			object_ptr<Ui::CenterWrap<>>(
+			object_ptr<Ui::FlatLabel>(
 				content,
-				Ui::CreateLabelWithCustomEmoji(
-					content,
-					tr::lng_credits_box_history_entry_gift_out_about(
-						lt_user,
-						rpl::single(TextWithEntities{ peer->shortName() }),
-						lt_link,
-						std::move(link),
-						Ui::Text::RichLangValue),
-					Core::TextContext({ .session = &peer->session() }),
-					st::creditsBoxAbout)),
-			st::boxRowPadding);
+				tr::lng_credits_box_history_entry_gift_out_about(
+					lt_user,
+					rpl::single(TextWithEntities{ peer->shortName() }),
+					lt_link,
+					std::move(link),
+					Ui::Text::RichLangValue),
+				st::creditsBoxAbout),
+			st::boxRowPadding,
+			style::al_top);
 	}
 	Ui::AddSkip(content);
 	Ui::AddSkip(box->verticalLayout());
@@ -101,6 +97,7 @@ void GiftCreditsBox(
 		peer,
 		CreditsAmount(),
 		[=] { gifted(); box->uiShow()->hideLayer(); },
+		box->showFinishes(),
 		tr::lng_credits_summary_options_subtitle(),
 		{});
 
