@@ -348,8 +348,8 @@ void Controller::initNameFields(
 			_save();
 		}
 	};
-	first->submits() | rpl::start_with_next(submit, first->lifetime());
-	last->submits() | rpl::start_with_next(submit, last->lifetime());
+	first->submits() | rpl::on_next(submit, first->lifetime());
+	last->submits() | rpl::on_next(submit, last->lifetime());
 	first->setMaxLength(Ui::EditPeer::kMaxUserFirstLastName);
 	first->setMaxLength(Ui::EditPeer::kMaxUserFirstLastName);
 }
@@ -418,11 +418,11 @@ void Controller::setupNotesField() {
 	_emojiPanel->hide();
 	_emojiPanel->selector()->setCurrentPeer(_window->session().user());
 	_emojiPanel->selector()->emojiChosen(
-	) | rpl::start_with_next([=](ChatHelpers::EmojiChosen data) {
+	) | rpl::on_next([=](ChatHelpers::EmojiChosen data) {
 		Ui::InsertEmojiAtCursor(_notesField->textCursor(), data.emoji);
 	}, _notesField->lifetime());
 	_emojiPanel->selector()->customEmojiChosen(
-	) | rpl::start_with_next([=](ChatHelpers::FileChosen data) {
+	) | rpl::on_next([=](ChatHelpers::FileChosen data) {
 		const auto info = data.document->sticker();
 		if (info
 			&& info->setType == Data::StickersType::Emoji
@@ -449,32 +449,32 @@ void Controller::setupNotesField() {
 	};
 	const auto limitState = _notesField->lifetime().make_state<LimitState>();
 
-	const auto checkCharsLimitation = [=] {
+	const auto checkCharsLimitation = [=, w = _notesField->window()] {
 		const auto limit = Data::PremiumLimits(
 			&_user->session()).contactNoteLengthCurrent();
 		const auto remove = Ui::ComputeFieldCharacterCount(_notesField)
 			- limit;
 		if (!limitState->charsLimitation) {
+			const auto border = _notesField->st().borderActive;
 			limitState->charsLimitation = base::make_unique_q<Limit>(
 				_box->verticalLayout(),
 				emojiButton,
 				style::al_top,
-				QMargins{ 0, -st::lineWidth, 0, 0 });
-			_notesField->heightValue(
-			) | rpl::start_with_next([=](int height) {
-				const auto &st = _notesField->st();
-				const auto hasMultipleLines = height >
-					(st.textMargins.top()
-						+ st.style.font->height
-						+ st.textMargins.bottom() * 2);
-				limitState->charsLimitation->setVisible(hasMultipleLines);
+				QMargins{ 0, -border - _notesField->st().border, 0, 0 });
+			rpl::combine(
+				limitState->charsLimitation->geometryValue(),
+				_notesField->geometryValue()
+			) | rpl::on_next([=](QRect limit, QRect field) {
+				limitState->charsLimitation->setVisible(
+					(w->mapToGlobal(limit.bottomLeft()).y() - border)
+						< w->mapToGlobal(field.bottomLeft()).y());
 				limitState->charsLimitation->raise();
 			}, limitState->charsLimitation->lifetime());
 		}
 		limitState->charsLimitation->setLeft(remove);
 	};
 
-	_notesField->changes() | rpl::start_with_next([=] {
+	_notesField->changes() | rpl::on_next([=] {
 		checkCharsLimitation();
 	}, _notesField->lifetime());
 
@@ -484,7 +484,10 @@ void Controller::setupNotesField() {
 }
 
 void Controller::setupPhotoButtons() {
-	const auto iconSize = st::restoreUserpicIcon.size;
+	if (!_user->isContact()) {
+		return;
+	}
+	const auto iconPlaceholder = st::restoreUserpicIcon.size * 2;
 	auto nameValue = _firstNameField
 		? rpl::merge(
 			rpl::single(_firstNameField->getLastText().trimmed()),
@@ -493,7 +496,7 @@ void Controller::setupPhotoButtons() {
 		})) | rpl::map([=](const QString &text) {
 			return text.isEmpty() ? Ui::kQEllipsis : text;
 		})
-		: rpl::single(_user->shortName()) | rpl::type_erased();
+		: rpl::single(_user->shortName()) | rpl::type_erased;
 	const auto inner = _box->verticalLayout();
 	Ui::AddSkip(inner);
 
@@ -515,7 +518,8 @@ void Controller::setupPhotoButtons() {
 				.sessionWindow = base::make_weak(_window),
 			}));
 	});
-	suggestBirthdayWrap->toggleOn(rpl::single(!_user->birthday().valid()));
+	suggestBirthdayWrap->toggleOn(rpl::single(!_user->birthday().valid()
+		&& !_user->starsPerMessageChecked()));
 
 	_suggestIcon = Ui::MakeAnimatedIcon({
 		.generator = [] {
@@ -524,7 +528,7 @@ void Controller::setupPhotoButtons() {
 					QByteArray(),
 					u":/animations/photo_suggest_icon.tgs"_q));
 		},
-		.sizeOverride = iconSize * style::DevicePixelRatio(),
+		.sizeOverride = iconPlaceholder,
 		.colorized = true,
 	});
 
@@ -535,30 +539,36 @@ void Controller::setupPhotoButtons() {
 					QByteArray(),
 					u":/animations/camera_outline.tgs"_q));
 		},
-		.sizeOverride = iconSize * style::DevicePixelRatio(),
+		.sizeOverride = iconPlaceholder,
 		.colorized = true,
 	});
 
+	const auto suggestButtonWrap = inner->add(
+		object_ptr<Ui::SlideWrap<Ui::VerticalLayout>>(
+			inner,
+			object_ptr<Ui::VerticalLayout>(inner)));
+	suggestButtonWrap->toggleOn(
+		rpl::single(!_user->starsPerMessageChecked()));
+
 	const auto suggestButton = Settings::AddButtonWithIcon(
-		inner,
+		suggestButtonWrap->entity(),
 		tr::lng_suggest_photo_for(lt_user, rpl::duplicate(nameValue)),
 		st::settingsButtonLight,
 		{ nullptr });
 
 	_suggestIconWidget = Ui::CreateChild<Ui::RpWidget>(suggestButton);
-	_suggestIconWidget->resize(iconSize * style::DevicePixelRatio());
-	_suggestIconWidget->paintRequest() | rpl::start_with_next([=] {
+	_suggestIconWidget->resize(iconPlaceholder);
+	_suggestIconWidget->paintRequest() | rpl::on_next([=] {
 		if (_suggestIcon && _suggestIcon->valid()) {
 			auto p = QPainter(_suggestIconWidget);
 			const auto frame = _suggestIcon->frame(st::lightButtonFg->c);
-			const auto rect = _suggestIconWidget->rect();
-			p.drawImage(rect, frame);
+			p.drawImage(_suggestIconWidget->rect(), frame);
 		}
 	}, _suggestIconWidget->lifetime());
 
-	suggestButton->sizeValue() | rpl::start_with_next([=](QSize size) {
+	suggestButton->sizeValue() | rpl::on_next([=](QSize size) {
 		_suggestIconWidget->move(
-			st::settingsButtonLight.iconLeft - iconSize.width() / 2,
+			st::settingsButtonLight.iconLeft - iconPlaceholder.width() / 4,
 			(size.height() - _suggestIconWidget->height()) / 2);
 	}, _suggestIconWidget->lifetime());
 
@@ -579,19 +589,18 @@ void Controller::setupPhotoButtons() {
 		{ nullptr });
 
 	_cameraIconWidget = Ui::CreateChild<Ui::RpWidget>(setButton);
-	_cameraIconWidget->resize(iconSize * style::DevicePixelRatio());
-	_cameraIconWidget->paintRequest() | rpl::start_with_next([=] {
+	_cameraIconWidget->resize(iconPlaceholder);
+	_cameraIconWidget->paintRequest() | rpl::on_next([=] {
 		if (_cameraIcon && _cameraIcon->valid()) {
 			auto p = QPainter(_cameraIconWidget);
 			const auto frame = _cameraIcon->frame(st::lightButtonFg->c);
-			const auto rect = _cameraIconWidget->rect();
-			p.drawImage(rect, frame);
+			p.drawImage(_cameraIconWidget->rect(), frame);
 		}
 	}, _cameraIconWidget->lifetime());
 
-	setButton->sizeValue() | rpl::start_with_next([=](QSize size) {
+	setButton->sizeValue() | rpl::on_next([=](QSize size) {
 		_cameraIconWidget->move(
-			st::settingsButtonLight.iconLeft - iconSize.width() / 2,
+			st::settingsButtonLight.iconLeft - iconPlaceholder.width() / 4,
 			(size.height() - _cameraIconWidget->height()) / 2);
 	}, _cameraIconWidget->lifetime());
 
@@ -626,7 +635,7 @@ void Controller::setupPhotoButtons() {
 	userpicButton->setAttribute(Qt::WA_TransparentForMouseEvents);
 
 	resetButton->sizeValue(
-	) | rpl::start_with_next([=](QSize size) {
+	) | rpl::on_next([=](QSize size) {
 		userpicButton->move(
 			st::settingsButtonLight.iconLeft,
 			(size.height() - userpicButton->height()) / 2);
@@ -634,7 +643,7 @@ void Controller::setupPhotoButtons() {
 	resetButtonWrap->toggleOn(
 		_user->session().changes().peerFlagsValue(
 			_user,
-			Data::PeerUpdate::Flag::FullInfo
+			Data::PeerUpdate::Flag::FullInfo | Data::PeerUpdate::Flag::Photo
 		) | rpl::map([=] {
 			return _user->hasPersonalPhoto();
 		}) | rpl::distinct_until_changed());
@@ -645,10 +654,11 @@ void Controller::setupPhotoButtons() {
 				tr::now,
 				lt_user,
 				_user->shortName()),
-			.confirmed = [=] {
+			.confirmed = [=](Fn<void()> close) {
 				_window->session().api().peerPhoto().clearPersonal(_user);
+				close();
 			},
-			.confirmText = tr::lng_profile_photo_reset(tr::now),
+			.confirmText = tr::lng_profile_photo_reset_button(tr::now),
 		}));
 	});
 
@@ -810,11 +820,6 @@ void Controller::processChosenPhoto(QImage &&image, bool suggest) {
 	Api::PeerPhoto::UserPhoto photo{
 		.image = base::duplicate(image),
 	};
-	if (suggest && _suggestIcon && _suggestIcon->valid()) {
-		_suggestIcon->animate([=] { _suggestIconWidget->update(); });
-	} else if (!suggest && _cameraIcon && _cameraIcon->valid()) {
-		_cameraIcon->animate([=] { _cameraIconWidget->update(); });
-	}
 	if (suggest) {
 		_window->session().api().peerPhoto().suggest(_user, std::move(photo));
 		_window->showPeerHistory(_user->id);
@@ -831,11 +836,6 @@ void Controller::processChosenPhotoWithMarkup(
 		.markupDocumentId = data.id,
 		.markupColors = std::move(data.colors),
 	};
-	if (suggest && _suggestIcon && _suggestIcon->valid()) {
-		_suggestIcon->animate([=] { _suggestIconWidget->update(); });
-	} else if (!suggest && _cameraIcon && _cameraIcon->valid()) {
-		_cameraIcon->animate([=] { _cameraIconWidget->update(); });
-	}
 	if (suggest) {
 		_window->session().api().peerPhoto().suggest(_user, std::move(photo));
 		_window->showPeerHistory(_user->id);
