@@ -94,7 +94,7 @@ EditParticipantBox::Inner::Inner(
 , _hasAdminRights(hasAdminRights)
 , _rows(this) {
 	_rows->heightValue(
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		resizeToWidth(width());
 	}, lifetime());
 
@@ -246,7 +246,8 @@ ChatAdminRightsInfo EditAdminBox::defaultRights() const {
 			| Flag::DeleteStories
 			| Flag::InviteByLinkOrAdd
 			| Flag::ManageCall
-			| Flag::ManageDirect) };
+			| Flag::ManageDirect
+			| Flag::BanUsers) };
 }
 
 void EditAdminBox::prepare() {
@@ -281,7 +282,7 @@ void EditAdminBox::prepare() {
 					true)),
 			st::rightsToggleMargin + (st::rightsDividerMargin / 2));
 		_addAsAdmin->checkedChanges(
-		) | rpl::start_with_next([=](bool checked) {
+		) | rpl::on_next([=](bool checked) {
 			_adminControlsWrap->toggle(checked, anim::type::normal);
 			refreshButtons();
 		}, _addAsAdmin->lifetime());
@@ -450,9 +451,9 @@ void EditAdminBox::prepare() {
 			if (!_saveCallback) {
 				return;
 			} else if (_addAsAdmin && !_addAsAdmin->checked()) {
-				const auto weak = Ui::MakeWeak(this);
+				const auto weak = base::make_weak(this);
 				AddBotToGroup(show, user(), peer(), _addingBot->token);
-				if (const auto strong = weak.data()) {
+				if (const auto strong = weak.get()) {
 					strong->closeBox();
 				}
 				return;
@@ -529,7 +530,7 @@ not_null<Ui::InputField*> EditAdminBox::addRankInput(
 	result->setMaxLength(kAdminRoleLimit);
 	result->setInstantReplaces(Ui::InstantReplaces::TextOnly());
 	result->changes(
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		const auto text = result->getLastText();
 		const auto removed = TextUtilities::RemoveEmoji(text);
 		if (removed != text) {
@@ -653,7 +654,7 @@ void EditAdminBox::requestTransferPassword(not_null<ChannelData*> channel) {
 	peer()->session().api().cloudPassword().state(
 	) | rpl::take(
 		1
-	) | rpl::start_with_next([=](const Core::CloudPasswordState &state) {
+	) | rpl::on_next([=](const Core::CloudPasswordState &state) {
 		auto fields = PasscodeBox::CloudFields::From(state);
 		fields.customTitle = tr::lng_rights_transfer_password_title();
 		fields.customDescription
@@ -661,7 +662,7 @@ void EditAdminBox::requestTransferPassword(not_null<ChannelData*> channel) {
 		fields.customSubmitButton = tr::lng_passcode_submit();
 		fields.customCheckCallback = crl::guard(this, [=](
 				const Core::CloudPasswordResult &result,
-				QPointer<PasscodeBox> box) {
+				base::weak_qptr<PasscodeBox> box) {
 			sendTransferRequestFrom(box, channel, result);
 		});
 		getDelegate()->show(Box<PasscodeBox>(&channel->session(), fields));
@@ -669,13 +670,13 @@ void EditAdminBox::requestTransferPassword(not_null<ChannelData*> channel) {
 }
 
 void EditAdminBox::sendTransferRequestFrom(
-		QPointer<PasscodeBox> box,
+		base::weak_qptr<PasscodeBox> box,
 		not_null<ChannelData*> channel,
 		const Core::CloudPasswordResult &result) {
 	if (_transferRequestId) {
 		return;
 	}
-	const auto weak = Ui::MakeWeak(this);
+	const auto weak = base::make_weak(this);
 	const auto user = this->user();
 	const auto api = &channel->session().api();
 	_transferRequestId = api->request(MTPchannels_EditCreator(
@@ -726,7 +727,7 @@ void EditAdminBox::sendTransferRequestFrom(
 				|| type.startsWith(u"PASSWORD_TOO_FRESH_"_q)
 				|| type.startsWith(u"SESSION_TOO_FRESH_"_q);
 		}();
-		const auto weak = Ui::MakeWeak(this);
+		const auto weak = base::make_weak(this);
 		getDelegate()->show(Ui::MakeInformBox(problem));
 		if (box) {
 			box->closeBox();
