@@ -29,6 +29,7 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 #include "history/history.h"
 #include "history/history_item_helpers.h" // GetErrorForSending.
 #include "history/view/history_view_group_call_bar.h" // GenerateUserpics...
+#include "info/channel_statistics/earn/earn_icons.h"
 #include "lang/lang_keys.h"
 #include "main/main_session.h"
 #include "qr/qr_generate.h"
@@ -42,6 +43,7 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 #include "ui/controls/userpic_button.h"
 #include "ui/painter.h"
 #include "ui/rect.h"
+#include "ui/text/custom_emoji_helper.h"
 #include "ui/text/format_values.h"
 #include "ui/text/text_utilities.h"
 #include "ui/toast/toast.h"
@@ -247,6 +249,9 @@ private:
 	const Role _role = Role::Joined;
 	rpl::variable<LinkData> _data;
 
+	Ui::Text::CustomEmojiHelper _emojiHelper;
+	TextWithEntities _creditsEmoji;
+
 	base::unique_qptr<Ui::PopupMenu> _menu;
 	rpl::event_stream<Processed> _processed;
 
@@ -374,11 +379,11 @@ void QrBox(
 	const auto button = Ui::CreateChild<Ui::AbstractButton>(container);
 	button->resize(size, size);
 	button->paintRequest(
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		QPainter(button).drawImage(QRect(0, 0, size, size), qr);
 	}, button->lifetime());
 	container->widthValue(
-	) | rpl::start_with_next([=](int width) {
+	) | rpl::on_next([=](int width) {
 		button->move((width - size) / 2, st::inviteLinkQrSkip);
 	}, button->lifetime());
 	button->setClickedCallback(copyCallback);
@@ -408,6 +413,8 @@ Controller::Controller(
 	const auto current = _data.current();
 	_link = current.link;
 	_revoked = current.revoked;
+	_creditsEmoji = _emojiHelper.paletteDependent(
+		Ui::Earn::IconCreditsEmoji());
 }
 
 rpl::producer<LinkData> Controller::dataValue() const {
@@ -499,7 +506,7 @@ void Controller::addHeaderBlock(not_null<Ui::VerticalLayout*> container) {
 		st::inviteLinkFieldPadding);
 
 	label->clicks(
-	) | rpl::start_with_next(copyLink, label->lifetime());
+	) | rpl::on_next(copyLink, label->lifetime());
 
 	const auto reactivateWrap = container->add(
 		object_ptr<Ui::SlideWrap<Ui::VerticalLayout>>(
@@ -559,7 +566,7 @@ void Controller::addHeaderBlock(not_null<Ui::VerticalLayout*> container) {
 	Ui::AddSkip(container);
 
 	dataValue(
-	) | rpl::start_with_next([=](const LinkData &data) {
+	) | rpl::on_next([=](const LinkData &data) {
 		const auto now = base::unixtime::now();
 		const auto expired = IsExpiredLink(data, now);
 		reactivateWrap->toggle(
@@ -634,7 +641,7 @@ not_null<Ui::SlideWrap<>*> Controller::addRequestedListBlock(
 	controller->setDelegate(delegate);
 
 	controller->processed(
-	) | rpl::start_with_next([=](Processed processed) {
+	) | rpl::on_next([=](Processed processed) {
 		updateWithProcessed(processed);
 	}, lifetime());
 
@@ -725,7 +732,7 @@ void Controller::setupAboveJoinedWidget() {
 				? tr::lng_group_invite_subscription_info_title(
 					tr::now,
 					lt_emoji,
-					session().data().customEmojiManager().creditsEmoji(),
+					_creditsEmoji,
 					lt_price,
 					{ QString::number(current.subscription.credits) },
 					lt_multiplier,
@@ -736,22 +743,19 @@ void Controller::setupAboveJoinedWidget() {
 				: tr::lng_group_invite_subscription_info_title_none(
 					tr::now,
 					lt_emoji,
-					session().data().customEmojiManager().creditsEmoji(),
+					_creditsEmoji,
 					lt_price,
 					{ QString::number(current.subscription.credits) },
 					Ui::Text::WithEntities),
 			kMarkupTextOptions,
-			Core::TextContext({
-				.session = &session(),
-				.repaint = [=] { widget->update(); },
-			}));
+			_emojiHelper.context([=] { widget->update(); }));
 		auto &lifetime = widget->lifetime();
 		const auto rateValue = lifetime.make_state<rpl::variable<float64>>(
 			session().credits().rateValue(_peer));
 		const auto currency = u"USD"_q;
 		const auto allCredits = current.subscription.credits * current.usage;
 		widget->paintRequest(
-		) | rpl::start_with_next([=] {
+		) | rpl::on_next([=] {
 			auto p = Painter(widget);
 			p.setBrush(Qt::NoBrush);
 			p.setPen(st.nameFg);
@@ -860,7 +864,7 @@ void Controller::setupAboveJoinedWidget() {
 		std::move(remainingText),
 		st::inviteLinkTitleRight);
 	dataValue(
-	) | rpl::start_with_next([=](const LinkData &data) {
+	) | rpl::on_next([=](const LinkData &data) {
 		remaining->setTextColorOverride(
 			(data.usageLimit && (data.usageLimit <= data.usage)
 				? std::make_optional(st::boxTextFgError->c)
@@ -878,7 +882,7 @@ void Controller::setupAboveJoinedWidget() {
 		listTitle->positionValue(),
 		remaining->widthValue(),
 		listHeader->widthValue()
-	) | rpl::start_with_next([=](
+	) | rpl::on_next([=](
 			QPoint position,
 			int width,
 			int outerWidth) {
@@ -965,46 +969,44 @@ void Controller::rowClicked(not_null<PeerListRow*> row) {
 
 		const auto photoSize = st::boostReplaceUserpic.photoSize;
 		const auto session = &row->peer()->session();
-		content->add(object_ptr<Ui::CenterWrap<>>(
-			content,
-			Settings::SubscriptionUserpic(content, channel, photoSize)));
+		content->add(
+			Settings::SubscriptionUserpic(content, channel, photoSize),
+			style::al_top);
 
 		Ui::AddSkip(content);
 		Ui::AddSkip(content);
 
-		box->addRow(object_ptr<Ui::CenterWrap<>>(
-			box,
+		box->addRow(
 			object_ptr<Ui::FlatLabel>(
 				box,
 				tr::lng_credits_box_subscription_title(),
-				st::creditsBoxAboutTitle)));
+				st::creditsBoxAboutTitle),
+			style::al_top);
 
 		Ui::AddSkip(content);
 
 		const auto subtitle1 = box->addRow(
-			object_ptr<Ui::CenterWrap<Ui::FlatLabel>>(
+			object_ptr<Ui::FlatLabel>(
 				box,
-				object_ptr<Ui::FlatLabel>(
-					box,
-					st::creditsTopupPrice)))->entity();
+				st::creditsTopupPrice),
+			style::al_top);
 		subtitle1->setMarkedText(
 			tr::lng_credits_subscription_subtitle(
 				tr::now,
 				lt_emoji,
-				session->data().customEmojiManager().creditsEmoji(),
+				_creditsEmoji,
 				lt_cost,
 				{ QString::number(data.subscription.credits) },
 				Ui::Text::WithEntities),
-			Core::TextContext({ .session = session }));
+			_emojiHelper.context());
 		const auto subtitle2 = box->addRow(
-			object_ptr<Ui::CenterWrap<Ui::FlatLabel>>(
+			object_ptr<Ui::FlatLabel>(
 				box,
-				object_ptr<Ui::FlatLabel>(
-					box,
-					st::creditsTopupPrice)))->entity();
+				st::creditsTopupPrice),
+			style::al_top);
 		session->credits().rateValue(
 			channel
-		) | rpl::start_with_next([=, currency = u"USD"_q](float64 rate) {
+		) | rpl::on_next([=, currency = u"USD"_q](float64 rate) {
 			subtitle2->setText(
 				tr::lng_credits_subscriber_subtitle(
 					tr::now,
@@ -1023,8 +1025,7 @@ void Controller::rowClicked(not_null<PeerListRow*> row) {
 		Ui::AddSkip(content);
 		Ui::AddSkip(content);
 
-		box->addRow(object_ptr<Ui::CenterWrap<>>(
-			box,
+		box->addRow(
 			object_ptr<Ui::FlatLabel>(
 				box,
 				tr::lng_credits_box_out_about(
@@ -1033,18 +1034,12 @@ void Controller::rowClicked(not_null<PeerListRow*> row) {
 					) | Ui::Text::ToLink(
 						tr::lng_credits_box_out_about_link(tr::now)),
 					Ui::Text::WithEntities),
-				st::creditsBoxAboutDivider)));
+				st::creditsBoxAboutDivider),
+			style::al_top);
 
-		const auto button = box->addButton(tr::lng_box_ok(), [=] {
+		box->addButton(tr::lng_box_ok(), [=] {
 			box->closeBox();
 		});
-		const auto buttonWidth = st::boxWidth
-			- rect::m::sum::h(st::giveawayGiftCodeBox.buttonPadding);
-		button->widthValue() | rpl::filter([=] {
-			return (button->widthNoMargins() != buttonWidth);
-		}) | rpl::start_with_next([=] {
-			button->resizeToWidth(buttonWidth);
-		}, button->lifetime());
 	}));
 }
 
@@ -1174,7 +1169,7 @@ void SingleRowController::prepare() {
 	if (_status) {
 		std::move(
 			_status
-		) | rpl::start_with_next([=](const QString &status) {
+		) | rpl::on_next([=](const QString &status) {
 			raw->setCustomStatus(status);
 			delegate()->peerListUpdateRow(raw);
 		}, _lifetime);
@@ -1183,7 +1178,7 @@ void SingleRowController::prepare() {
 	delegate()->peerListRefreshRows();
 
 	if (topic) {
-		topic->destroyed() | rpl::start_with_next([=] {
+		topic->destroyed() | rpl::on_next([=] {
 			while (delegate()->peerListFullRowsCount()) {
 				delegate()->peerListRemoveRow(delegate()->peerListRowAt(0));
 			}
@@ -1280,7 +1275,7 @@ void AddPermanentLinkBlock(
 	} else {
 		rpl::duplicate(
 			fromList
-		) | rpl::start_with_next([=](const Api::InviteLink &link) {
+		) | rpl::on_next([=](const Api::InviteLink &link) {
 			*currentLinkFields = link;
 		}, container->lifetime());
 
@@ -1356,7 +1351,7 @@ void AddPermanentLinkBlock(
 		st::inviteLinkFieldPadding);
 
 	label->clicks(
-	) | rpl::start_with_next(copyLink, label->lifetime());
+	) | rpl::on_next(copyLink, label->lifetime());
 
 	AddCopyShareLinkButtons(container, copyLink, shareLink);
 
@@ -1393,7 +1388,7 @@ void AddPermanentLinkBlock(
 			data.link,
 			data.usage);
 	}) | rpl::flatten_latest(
-	) | rpl::start_with_next([=](const Api::JoinedByLinkSlice &slice) {
+	) | rpl::on_next([=](const Api::JoinedByLinkSlice &slice) {
 		auto list = std::vector<HistoryView::UserpicInRow>();
 		list.reserve(slice.users.size());
 		for (const auto &item : slice.users) {
@@ -1415,7 +1410,7 @@ void AddPermanentLinkBlock(
 	peer->session().downloaderTaskFinished(
 	) | rpl::filter([=] {
 		return !state->allUserpicsLoaded;
-	}) | rpl::start_with_next([=] {
+	}) | rpl::on_next([=] {
 		auto pushing = false;
 		state->allUserpicsLoaded = true;
 		for (const auto &element : state->list) {
@@ -1706,7 +1701,7 @@ object_ptr<Ui::BoxContent> ShowInviteLinkBox(
 		not_null<Ui::BoxContent*> box) {
 		rpl::duplicate(
 			data
-		) | rpl::start_with_next([=](const LinkData &link) {
+		) | rpl::on_next([=](const LinkData &link) {
 			if (ClosingLinkBox(link, revoked)) {
 				box->closeBox();
 				return;
