@@ -50,7 +50,7 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 
 namespace {
 
-constexpr auto kSlowmodeValues = 7;
+constexpr auto kSlowmodeValues = 8;
 constexpr auto kBoostsUnrestrictValues = 5;
 constexpr auto kForceDisableTooltipDuration = 3 * crl::time(1000);
 constexpr auto kDefaultChargeStars = 10;
@@ -174,6 +174,7 @@ constexpr auto kDefaultChargeStars = 10;
 		{ Flag::ManageCall, tr::lng_rights_channel_manage_calls(tr::now) },
 		{ Flag::ManageDirect, tr::lng_rights_channel_manage_direct(tr::now) },
 		{ Flag::AddAdmins, tr::lng_rights_add_admins(tr::now) },
+		{ Flag::BanUsers, tr::lng_rights_group_ban(tr::now) },
 	};
 	return {
 		{ std::nullopt, std::move(first) },
@@ -188,12 +189,13 @@ int SlowmodeDelayByIndex(int index) {
 
 	switch (index) {
 	case 0: return 0;
-	case 1: return 10;
-	case 2: return 30;
-	case 3: return 60;
-	case 4: return 5 * 60;
-	case 5: return 15 * 60;
-	case 6: return 60 * 60;
+	case 1: return 5;
+	case 2: return 10;
+	case 3: return 30;
+	case 4: return 60;
+	case 5: return 5 * 60;
+	case 6: return 15 * 60;
+	case 7: return 60 * 60;
 	}
 	Unexpected("Index in SlowmodeDelayByIndex.");
 }
@@ -405,14 +407,14 @@ not_null<Ui::RpWidget*> AddInnerToggle(
 	{
 		const auto separator = Ui::CreateChild<Ui::RpWidget>(container.get());
 		separator->paintRequest(
-		) | rpl::start_with_next([=, bg = st.textBgOver] {
+		) | rpl::on_next([=, bg = st.textBgOver] {
 			auto p = QPainter(separator);
 			p.fillRect(separator->rect(), bg);
 		}, separator->lifetime());
 		const auto separatorHeight = 2 * st.toggle.border
 			+ st.toggle.diameter;
 		button->geometryValue(
-		) | rpl::start_with_next([=](const QRect &r) {
+		) | rpl::on_next([=](const QRect &r) {
 			const auto w = st::rightsButtonToggleWidth;
 			toggleButton->setGeometry(
 				r.x() + r.width() - w,
@@ -429,12 +431,12 @@ not_null<Ui::RpWidget*> AddInnerToggle(
 		const auto checkWidget = Ui::CreateChild<Ui::RpWidget>(toggleButton);
 		checkWidget->resize(checkView->getSize());
 		checkWidget->paintRequest(
-		) | rpl::start_with_next([=] {
+		) | rpl::on_next([=] {
 			auto p = QPainter(checkWidget);
 			checkView->paint(p, 0, 0, checkWidget->width());
 		}, checkWidget->lifetime());
 		toggleButton->sizeValue(
-		) | rpl::start_with_next([=](const QSize &s) {
+		) | rpl::on_next([=](const QSize &s) {
 			checkWidget->moveToRight(
 				st.toggleSkip,
 				(s.height() - checkWidget->height()) / 2);
@@ -442,7 +444,7 @@ not_null<Ui::RpWidget*> AddInnerToggle(
 	}
 	state->anyChanges.events_starting_with(
 		rpl::empty_value()
-	) | rpl::map(countChecked) | rpl::start_with_next([=](int count) {
+	) | rpl::map(countChecked) | rpl::on_next([=](int count) {
 		checkView->setChecked(count > 0, anim::type::normal);
 	}, toggleButton->lifetime());
 	checkView->setLocked(locked.has_value());
@@ -469,7 +471,7 @@ not_null<Ui::RpWidget*> AddInnerToggle(
 		const auto &icon = st::permissionsExpandIcon;
 		arrow->resize(icon.size());
 		arrow->paintRequest(
-		) | rpl::start_with_next([=, &icon] {
+		) | rpl::on_next([=, &icon] {
 			auto p = QPainter(arrow);
 			const auto center = QPointF(
 				icon.width() / 2.,
@@ -487,7 +489,7 @@ not_null<Ui::RpWidget*> AddInnerToggle(
 		}, arrow->lifetime());
 	}
 	button->sizeValue(
-	) | rpl::start_with_next([=, &st](const QSize &s) {
+	) | rpl::on_next([=, &st](const QSize &s) {
 		const auto labelLeft = st.padding.left();
 		const auto labelRight = s.width() - toggleButton->width();
 
@@ -502,7 +504,7 @@ not_null<Ui::RpWidget*> AddInnerToggle(
 			(s.height() - arrow->height()) / 2);
 	}, button->lifetime());
 	wrap->toggledValue(
-	) | rpl::skip(1) | rpl::start_with_next([=](bool toggled) {
+	) | rpl::skip(1) | rpl::on_next([=](bool toggled) {
 		state->animation.start(
 			[=] { arrow->update(); },
 			toggled ? 0. : 1.,
@@ -519,14 +521,14 @@ not_null<Ui::RpWidget*> AddInnerToggle(
 	};
 
 	button->clicks(
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		if (!handleLocked()) {
 			wrap->toggle(!wrap->toggled(), anim::type::normal);
 		}
 	}, button->lifetime());
 
 	toggleButton->clicks(
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		if (!handleLocked()) {
 			const auto checked = !checkView->checked();
 			for (const auto &innerCheck : state->innerChecks) {
@@ -561,7 +563,7 @@ template <typename Flags>
 		});
 
 		state->forceDisabled.value(
-		) | rpl::start_with_next([=](bool disabled) {
+		) | rpl::on_next([=](bool disabled) {
 			if (disabled) {
 				for (const auto &[flags, checkView] : state->checkViews) {
 					checkView->setChecked(false, anim::type::normal);
@@ -627,7 +629,7 @@ template <typename Flags>
 				rpl::combine(
 					verticalLayout->widthValue(),
 					checkbox->geometryValue()
-				) | rpl::start_with_next([=](int w, const QRect &r) {
+				) | rpl::on_next([=](int w, const QRect &r) {
 					button->setGeometry(0, r.y(), w, r.height());
 				}, button->lifetime());
 				checkbox->setAttribute(Qt::WA_TransparentForMouseEvents);
@@ -657,12 +659,12 @@ template <typename Flags>
 					[=] { toggle->update(); });
 				toggle->resize(checkView->getSize());
 				toggle->paintRequest(
-				) | rpl::start_with_next([=] {
+				) | rpl::on_next([=] {
 					auto p = QPainter(toggle);
 					checkView->paint(p, 0, 0, toggle->width());
 				}, toggle->lifetime());
 				button->sizeValue(
-				) | rpl::start_with_next([=](const QSize &s) {
+				) | rpl::on_next([=](const QSize &s) {
 					toggle->moveToRight(
 						st.toggleSkip,
 						(s.height() - toggle->height()) / 2);
@@ -678,7 +680,7 @@ template <typename Flags>
 		}();
 		state->checkViews.emplace(flags, checkView);
 		checkView->checkedChanges(
-		) | rpl::start_with_next([=](bool checked) {
+		) | rpl::on_next([=](bool checked) {
 			if (checked && state->forceDisabled.current()) {
 				if (!state->toast) {
 					state->toast = Ui::Toast::Show(container, {
@@ -740,7 +742,7 @@ template <typename Flags>
 				{ nestedWithLabel.nested.front().icon });
 			container->add(std::move(wrap));
 			container->widthValue(
-			) | rpl::start_with_next([=](int w) {
+			) | rpl::on_next([=](int w) {
 				raw->resizeToWidth(w);
 			}, raw->lifetime());
 		}
@@ -778,7 +780,7 @@ void AddSlowmodeLabels(
 		rpl::combine(
 			labels->widthValue(),
 			label->widthValue()
-		) | rpl::start_with_next([=](int outer, int inner) {
+		) | rpl::on_next([=](int outer, int inner) {
 			const auto skip = st::localStorageLimitMargin;
 			const auto size = st::localStorageLimitSlider.seekSize;
 			const auto available = outer
@@ -886,36 +888,22 @@ rpl::producer<int> AddSlowmodeSlider(
 	return secondsCount->value();
 }
 
-void AddBoostsUnrestrictLabels(
-		not_null<Ui::VerticalLayout*> container,
-		not_null<Main::Session*> session) {
+void AddBoostsUnrestrictLabels(not_null<Ui::VerticalLayout*> container) {
 	const auto labels = container->add(
 		object_ptr<Ui::FixedHeightWidget>(container, st::normalFont->height),
 		st::slowmodeLabelsMargin);
-	const auto manager = &session->data().customEmojiManager();
-	const auto one = Ui::Text::SingleCustomEmoji(
-		manager->registerInternalEmoji(
-			st::boostMessageIcon,
-			st::boostMessageIconPadding));
-	const auto many = Ui::Text::SingleCustomEmoji(
-		manager->registerInternalEmoji(
-			st::boostsMessageIcon,
-			st::boostsMessageIconPadding));
-	const auto context = Core::TextContext({
-		.session = session,
-		.customEmojiLoopLimit = 1,
-	});
+	const auto one = Ui::Text::IconEmoji(&st::boostMessageIcon);
+	const auto many = Ui::Text::IconEmoji(&st::boostsMessageIcon);
 	for (auto i = 0; i != kBoostsUnrestrictValues; ++i) {
 		const auto label = Ui::CreateChild<Ui::FlatLabel>(
 			labels,
 			st::boostsUnrestrictLabel);
 		label->setMarkedText(
-			TextWithEntities(i ? many : one).append(QString::number(i + 1)),
-			context);
+			TextWithEntities(i ? many : one).append(QString::number(i + 1)));
 		rpl::combine(
 			labels->widthValue(),
 			label->widthValue()
-		) | rpl::start_with_next([=](int outer, int inner) {
+		) | rpl::on_next([=](int outer, int inner) {
 			const auto skip = st::localStorageLimitMargin;
 			const auto size = st::localStorageLimitSlider.seekSize;
 			const auto available = outer
@@ -960,7 +948,7 @@ rpl::producer<int> AddBoostsUnrestrictSlider(
 		tr::lng_rights_boosts_no_restrict(),
 		st::defaultSettingsButton
 	))->toggleOn(rpl::duplicate(enabled))->toggledValue(
-	) | rpl::start_with_next([=](bool toggled) {
+	) | rpl::on_next([=](bool toggled) {
 		if (toggled && !boostsUnrestrict->current()) {
 			*boostsUnrestrict = 1;
 		} else if (!toggled && boostsUnrestrict->current()) {
@@ -977,7 +965,7 @@ rpl::producer<int> AddBoostsUnrestrictSlider(
 
 	const auto inner = outer->entity();
 
-	AddBoostsUnrestrictLabels(inner, &peer->session());
+	AddBoostsUnrestrictLabels(inner);
 
 	const auto slider = inner->add(
 		object_ptr<Ui::MediaSlider>(inner, st::localStorageLimitSlider),
