@@ -183,12 +183,12 @@ void Controller::confirmAdd(not_null<PeerData*> peer) {
 
 		Ui::AddSkip(box->verticalLayout());
 
-		field->changes() | rpl::start_with_next([=] {
+		field->changes() | rpl::on_next([=] {
 			state->description = field->getLastText();
 		}, field->lifetime());
 
 		field->setMaxLength(limit * 2);
-		Ui::AddLengthLimitLabel(field, limit, std::nullopt);
+		Ui::AddLengthLimitLabel(field, limit);
 
 		Ui::AddDividerText(box->verticalLayout(), phrases.about());
 	}));
