@@ -14,6 +14,7 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 #include "boxes/passcode_box.h"
 #include "lang/lang_keys.h"
 #include "main/main_session.h"
+#include "ui/rect.h"
 #include "ui/widgets/checkbox.h"
 #include "ui/widgets/labels.h"
 #include "ui/text/text_utilities.h"
@@ -47,7 +48,7 @@ void AddDeleteAccount(
 		session->api().cloudPassword().state(
 		) | rpl::take(
 			1
-		) | rpl::start_with_next([=](const Core::CloudPasswordState &state) {
+		) | rpl::on_next([=](const Core::CloudPasswordState &state) {
 			auto fields = PasscodeBox::CloudFields::From(state);
 			fields.customTitle = tr::lng_settings_destroy_title();
 			fields.customDescription = tr::lng_context_mark_read_all_sure_2(
@@ -116,7 +117,7 @@ SelfDestructionBox::SelfDestructionBox(
 		preloaded
 	) | rpl::take(
 		1
-	) | rpl::start_with_next([=](int days) {
+	) | rpl::on_next([=](int days) {
 		gotCurrent(days);
 	}, lifetime());
 }
@@ -148,6 +149,8 @@ void SelfDestructionBox::showContent() {
 			: tr::lng_self_destruct_sessions_description(tr::now)),
 		st::boxLabel);
 	_description->moveToLeft(st::boxPadding.left(), y);
+	_description->resizeToWidth(st::boxWidth
+		- rect::m::sum::h(st::boxPadding));
 	y += _description->height() + st::boxMediumSkip;
 
 	for (const auto value : _ttlValues) {
@@ -200,6 +203,8 @@ void SelfDestructionBox::prepare() {
 			? tr::lng_self_destruct_description(tr::now)
 			: tr::lng_self_destruct_sessions_description(tr::now)),
 		st::boxLabel);
+	fake->resizeToWidth(st::boxWidth
+		- rect::m::sum::h(st::boxPadding));
 	const auto boxHeight = st::boxOptionListPadding.top()
 		+ fake->height() + st::boxMediumSkip
 		+ (_ttlValues.size()
