@@ -125,7 +125,7 @@ void AddTerms(
 		.shadowIgnoreTopSkip = stBox.shadowIgnoreTopSkip,
 		.shadowIgnoreBottomSkip = stBox.shadowIgnoreBottomSkip,
 	});
-	button->geometryValue() | rpl::start_with_next([=](const QRect &rect) {
+	button->geometryValue() | rpl::on_next([=](const QRect &rect) {
 		terms->resizeToWidth(box->width()
 			- rect::m::sum::h(st::boxRowPadding));
 		terms->moveToLeft(
@@ -266,7 +266,7 @@ void AddTerms(
 	const auto radius = smaller.height() / 2.;
 	widget->resize(size);
 
-	widget->paintRequest() | rpl::start_with_next([=] {
+	widget->paintRequest() | rpl::on_next([=] {
 		auto p = QPainter(widget);
 		auto hq = PainterHighQualityEnabler(p);
 		p.setPen(QPen(st::premiumButtonFg, st::chatGiveawayBadgeStroke * 1.));
@@ -331,13 +331,13 @@ void SendCreditsBox(
 		ministars->setColorOverride(Ui::Premium::CreditsIconGradientStops());
 
 		ministarsContainer->paintRequest(
-		) | rpl::start_with_next([=] {
+		) | rpl::on_next([=] {
 			auto p = QPainter(ministarsContainer);
 			ministars->paint(p);
 		}, ministarsContainer->lifetime());
 
 		box->widthValue(
-		) | rpl::start_with_next([=](int width) {
+		) | rpl::on_next([=](int width) {
 			ministarsContainer->resize(width, fullHeight);
 			const auto w = fullHeight / 3 * 2;
 			ministars->setCenter(QRect(
@@ -348,13 +348,13 @@ void SendCreditsBox(
 		}, ministarsContainer->lifetime());
 	}
 
-	const auto thumb = box->addRow(object_ptr<Ui::CenterWrap<>>(
-		content,
-		SendCreditsThumbnail(content, session, form.get(), photoSize)));
+	const auto thumb = box->addRow(
+		SendCreditsThumbnail(content, session, form.get(), photoSize),
+		style::al_top);
 	thumb->setAttribute(Qt::WA_TransparentForMouseEvents);
 	if (form->invoice.subscriptionPeriod) {
 		const auto badge = SendCreditsBadge(content, form->invoice.amount);
-		thumb->geometryValue() | rpl::start_with_next([=](const QRect &r) {
+		thumb->geometryValue() | rpl::on_next([=](const QRect &r) {
 			badge->moveToLeft(
 				r.x() + (r.width() - badge->width()) / 2,
 				rect::bottom(r) - badge->height() / 2);
@@ -364,31 +364,30 @@ void SendCreditsBox(
 	}
 
 	Ui::AddSkip(content);
-	box->addRow(object_ptr<Ui::CenterWrap<>>(
-		box,
+	box->addRow(
 		object_ptr<Ui::FlatLabel>(
 			box,
 			form->invoice.subscriptionPeriod
 				? rpl::single(form->title)
 				: tr::lng_credits_box_out_title(),
-			st::settingsPremiumUserTitle)));
+			st::settingsPremiumUserTitle),
+		style::al_top);
 	if (form->invoice.subscriptionPeriod && form->botId && form->photo) {
 		Ui::AddSkip(content);
 		Ui::AddSkip(content);
 		const auto bot = session->data().user(form->botId);
 		box->addRow(
-			object_ptr<Ui::CenterWrap<>>(
-				box,
-				Ui::CreatePeerBubble(box, bot)));
+			Ui::CreatePeerBubble(box, bot),
+			style::al_top);
 		Ui::AddSkip(content);
 	}
 	Ui::AddSkip(content);
-	box->addRow(object_ptr<Ui::CenterWrap<>>(
-		box,
+	box->addRow(
 		object_ptr<Ui::FlatLabel>(
 			box,
 			SendCreditsConfirmText(session, form.get()),
-			st::creditsBoxAbout)));
+			st::creditsBoxAbout),
+		style::al_top);
 	Ui::AddSkip(content);
 	Ui::AddSkip(content);
 
@@ -421,7 +420,7 @@ void SendCreditsBox(
 			if (id == u"BOT_PRECHECKOUT_FAILED"_q) {
 				auto error = ::Ui::MakeInformBox(
 					tr::lng_payments_precheckout_stars_failed(tr::now));
-				error->boxClosing() | rpl::start_with_next([=] {
+				error->boxClosing() | rpl::on_next([=] {
 					if (const auto paybox = weak.get()) {
 						paybox->closeBox();
 					}
@@ -455,7 +454,7 @@ void SendCreditsBox(
 					lt_count,
 					rpl::single(form->invoice.amount) | tr::to_count(),
 					lt_emoji,
-					rpl::single(CreditsEmojiSmall(session)),
+					rpl::single(CreditsEmojiSmall()),
 					Ui::Text::RichLangValue),
 			state->confirmButtonBusy.value()
 		) | rpl::map([](TextWithEntities &&text, bool busy) {
@@ -465,20 +464,12 @@ void SendCreditsBox(
 		st::creditsBoxButtonLabel,
 		&box->getDelegate()->style().button.textFg);
 
-	const auto buttonWidth = st::boxWidth
-		- rect::m::sum::h(stBox.buttonPadding);
-	button->widthValue() | rpl::filter([=] {
-		return (button->widthNoMargins() != buttonWidth);
-	}) | rpl::start_with_next([=] {
-		button->resizeToWidth(buttonWidth);
-	}, button->lifetime());
-
 	{
 		const auto close = Ui::CreateChild<Ui::IconButton>(
 			content,
 			st::boxTitleClose);
 		close->setClickedCallback([=] { box->closeBox(); });
-		content->widthValue() | rpl::start_with_next([=](int) {
+		content->widthValue() | rpl::on_next([=](int) {
 			close->moveToRight(0, 0);
 		}, close->lifetime());
 	}
@@ -493,7 +484,7 @@ void SendCreditsBox(
 		rpl::combine(
 			balance->sizeValue(),
 			content->sizeValue()
-		) | rpl::start_with_next([=](const QSize &, const QSize &) {
+		) | rpl::on_next([=](const QSize &, const QSize &) {
 			balance->moveToLeft(
 				st::creditsHistoryRightSkip * 2,
 				st::creditsHistoryRightSkip);
@@ -502,16 +493,13 @@ void SendCreditsBox(
 	}
 }
 
-TextWithEntities CreditsEmoji(not_null<Main::Session*> session) {
-	return Ui::Text::SingleCustomEmoji(
-		session->data().customEmojiManager().registerInternalEmoji(
-			st::settingsPremiumIconStar,
-			QMargins{ 0, -st::moderateBoxExpandInnerSkip, 0, 0 },
-			true),
+TextWithEntities CreditsEmoji() {
+	return Ui::Text::IconEmoji(
+		&st::starIconEmojiLarge,
 		QString(QChar(0x2B50)));
 }
 
-TextWithEntities CreditsEmojiSmall(not_null<Main::Session*> session) {
+TextWithEntities CreditsEmojiSmall() {
 	return Ui::Text::IconEmoji(
 		&st::starIconEmoji,
 		QString(QChar(0x2B50)));
@@ -532,17 +520,17 @@ not_null<FlatLabel*> SetButtonMarkedLabel(
 		text
 	) | rpl::filter([=](const TextWithEntities &text) {
 		return !text.text.isEmpty();
-	}) | rpl::start_with_next([=](const TextWithEntities &text) {
+	}) | rpl::on_next([=](const TextWithEntities &text) {
 		buttonLabel->setMarkedText(text, context);
 	}, buttonLabel->lifetime());
 	if (textFg) {
 		buttonLabel->setTextColorOverride((*textFg)->c);
-		style::PaletteChanged() | rpl::start_with_next([=] {
+		style::PaletteChanged() | rpl::on_next([=] {
 			buttonLabel->setTextColorOverride((*textFg)->c);
 		}, buttonLabel->lifetime());
 	}
 	button->sizeValue(
-	) | rpl::start_with_next([=](const QSize &size) {
+	) | rpl::on_next([=](const QSize &size) {
 		buttonLabel->moveToLeft(
 			(size.width() - buttonLabel->width()) / 2,
 			(size.height() - buttonLabel->height()) / 2);
