@@ -61,7 +61,7 @@ ShowButton::ShowButton(not_null<Ui::RpWidget*> parent)
 : RpWidget(parent)
 , _button(this, tr::lng_usernames_activate_confirm(tr::now)) {
 	_button.sizeValue(
-	) | rpl::start_with_next([=](const QSize &s) {
+	) | rpl::on_next([=](const QSize &s) {
 		resize(
 			s.width() + st::defaultEmojiSuggestions.fadeRight.width(),
 			s.height());
@@ -161,7 +161,7 @@ void TranslateBox(
 		rpl::combine(
 			container->widthValue(),
 			original->geometryValue()
-		) | rpl::start_with_next([=](int width, const QRect &rect) {
+		) | rpl::on_next([=](int width, const QRect &rect) {
 			show->moveToLeft(
 				width - show->width() - st::boxRowPadding.right(),
 				rect.y() + std::abs(lineHeight - show->height()) / 2);
@@ -169,7 +169,7 @@ void TranslateBox(
 		original->entity()->heightValue(
 		) | rpl::filter([](int height) {
 			return height > 0;
-		}) | rpl::take(1) | rpl::start_with_next([=](int height) {
+		}) | rpl::take(1) | rpl::on_next([=](int height) {
 			if (height > lineHeight) {
 				show->show(anim::type::instant);
 			}
@@ -189,7 +189,7 @@ void TranslateBox(
 			state->to.value() | rpl::map(LanguageName));
 
 		// Workaround.
-		state->to.value() | rpl::start_with_next([=] {
+		state->to.value() | rpl::on_next([=] {
 			subtitle->resizeToWidth(container->width()
 				- padding.left()
 				- padding.right());
@@ -208,7 +208,7 @@ void TranslateBox(
 		box,
 		CreateLoadingTextWidget(
 			box,
-			st::aboutLabel,
+			st::aboutLabel.style,
 			std::min(original->entity()->height() / lineHeight, kMaxLines),
 			state->to.value() | rpl::map([=](LanguageId id) {
 				return id.locale().textDirection() == Qt::RightToLeft;
@@ -248,19 +248,16 @@ void TranslateBox(
 				showText(
 					Ui::Text::Italic(tr::lng_translate_box_error(tr::now)));
 			} else {
-				showText(TextWithEntities{
-					.text = qs(list.front().data().vtext()),
-					.entities = Api::EntitiesFromMTP(
-						&peer->session(),
-						list.front().data().ventities().v),
-				});
+				showText(Api::ParseTextWithEntities(
+					&peer->session(),
+					list.front()));
 			}
 		}).fail([=](const MTP::Error &error) {
 			showText(
 				Ui::Text::Italic(tr::lng_translate_box_error(tr::now)));
 		}).send();
 	};
-	state->to.value() | rpl::start_with_next(send, box->lifetime());
+	state->to.value() | rpl::on_next(send, box->lifetime());
 
 	box->addLeftButton(tr::lng_settings_language(), [=] {
 		if (loading->toggled()) {
