@@ -75,6 +75,7 @@ void SaveCallJoinMuted(
 	const auto call = peer->groupCall();
 	if (!call
 		|| call->id() != callId
+		|| peer->isUser()
 		|| !peer->canManageGroupCall()
 		|| !call->canChangeJoinMuted()
 		|| call->joinMuted() == joinMuted) {
@@ -86,7 +87,8 @@ void SaveCallJoinMuted(
 		MTP_flags(Flag::f_join_muted),
 		call->input(),
 		MTP_bool(joinMuted),
-		MTPBool() // messages_enabled
+		MTPBool(), // messages_enabled
+		MTPlong() // send_paid_messages_stars
 	)).send();
 }
 
@@ -98,7 +100,7 @@ void SaveCallMessagesEnabled(
 	if (!call
 		|| call->id() != callId
 		|| !peer->canManageGroupCall()
-		|| !call->canChangeJoinMuted()
+		|| !call->canChangeMessagesEnabled()
 		|| call->messagesEnabled() == messagesEnabled) {
 		return;
 	}
@@ -108,7 +110,8 @@ void SaveCallMessagesEnabled(
 		MTP_flags(Flag::f_messages_enabled),
 		call->input(),
 		MTPBool(), // join_muted
-		MTP_bool(messagesEnabled)
+		MTP_bool(messagesEnabled),
+		MTPlong() // send_paid_messages_stars
 	)).send();
 }
 
@@ -285,7 +288,7 @@ void SettingsBox(
 		layout->add(object_ptr<Ui::BoxContentDivider>(
 			layout,
 			st::boxDividerHeight,
-			st::groupCallDividerBg));
+			st::groupCallDividerBar));
 	};
 
 	if (addCheck || addMessages) {
@@ -374,7 +377,7 @@ void SettingsBox(
 		))->toggleOn(rpl::single(
 			settings.groupCallNoiseSuppression()
 		))->toggledChanges(
-		) | rpl::start_with_next([=](bool enabled) {
+		) | rpl::on_next([=](bool enabled) {
 			Core::App().settings().setGroupCallNoiseSuppression(enabled);
 			call->setNoiseSuppression(enabled);
 			Core::App().saveSettingsDelayed();
@@ -479,7 +482,7 @@ void SettingsBox(
 							kCheckAccessibilityInterval
 						) | rpl::filter([] {
 							return base::GlobalShortcutsAllowed();
-						}) | rpl::start_with_next([=] {
+						}) | rpl::on_next([=] {
 							box->closeBox();
 						}, box->lifetime());
 					}
@@ -576,7 +579,7 @@ void SettingsBox(
 				settings.groupCallPushToTalk(),
 				anim::type::instant);
 			pushToTalk->toggledChanges(
-			) | rpl::start_with_next([=](bool toggled) {
+			) | rpl::on_next([=](bool toggled) {
 				if (!toggled) {
 					stopRecording();
 				} else if (!ensureManager()) {
@@ -690,6 +693,7 @@ void SettingsBox(
 			const auto session = &peer->session();
 			state->requestId = session->api().request(
 				MTPphone_GetGroupCallStreamRtmpUrl(
+					MTP_flags(0),
 					peer->input,
 					MTP_bool(true)
 			)).done([=](const MTPphone_GroupCallStreamRtmpUrl &result) {
@@ -797,12 +801,12 @@ void SettingsBox(
 		});
 
 		volumeItem->toggleMuteLocallyRequests(
-		) | rpl::start_with_next([=](bool muted) {
+		) | rpl::on_next([=](bool muted) {
 			toggleMute(muted, true);
 		}, volumeItem->lifetime());
 
 		volumeItem->changeVolumeLocallyRequests(
-		) | rpl::start_with_next([=](int volume) {
+		) | rpl::on_next([=](int volume) {
 			changeVolume(volume, true);
 		}, volumeItem->lifetime());
 	}
@@ -845,7 +849,7 @@ void SettingsBox(
 
 	box->setTitle(tr::lng_group_call_settings_title());
 	box->boxClosing(
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		if (canChangeJoinMuted
 			&& muteJoined
 			&& muteJoined->toggled() != joinMuted) {
@@ -887,7 +891,7 @@ std::pair<Fn<void()>, rpl::lifetime> ShareInviteLinkAction(
 		bool generatingLink = false;
 	};
 	const auto state = lifetime.make_state<State>(&peer->session());
-	if (!peer->canManageGroupCall()) {
+	if (peer->isUser() || !peer->canManageGroupCall()) {
 		state->linkSpeaker = QString();
 	}
 
