@@ -126,24 +126,24 @@ GifsListWidget::GifsListWidget(
 		[=] { sendInlineRequest(); });
 
 	session().data().stickers().savedGifsUpdated(
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		refreshSavedGifs();
 	}, lifetime());
 
 	session().downloaderTaskFinished(
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		updateInlineItems();
 	}, lifetime());
 
 	_show->pauseChanged(
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		if (!paused()) {
 			updateInlineItems();
 		}
 	}, lifetime());
 
 	sizeValue(
-	) | rpl::start_with_next([=](const QSize &s) {
+	) | rpl::on_next([=](const QSize &s) {
 		_mosaic.setFullWidth(s.width());
 	}, lifetime());
 
@@ -181,13 +181,13 @@ object_ptr<TabbedSelector::InnerFooter> GifsListWidget::createFooter() {
 
 	GifSectionsValue(
 		&session()
-	) | rpl::start_with_next([=](std::vector<GifSection> &&list) {
+	) | rpl::on_next([=](std::vector<GifSection> &&list) {
 		_sections = std::move(list);
 		refreshIcons();
 	}, _footer->lifetime());
 
 	_footer->setChosen(
-	) | rpl::start_with_next([=](uint64 setId) {
+	) | rpl::on_next([=](uint64 setId) {
 		if (_search) {
 			_search->cancel();
 		}
