@@ -143,7 +143,7 @@ PreviewWrap::PreviewWrap(
 	const auto closeCallback = [=] { _closeRequests.fire({}); };
 	HistoryView::TTLVoiceStops(
 		item->fullId()
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		_lastFrameCache = Ui::GrabWidgetToImage(this, _elementGeometry);
 		closeCallback();
 	}, lifetime());
@@ -155,20 +155,20 @@ PreviewWrap::PreviewWrap(
 
 	std::move(
 		theme
-	) | rpl::start_with_next([=](std::shared_ptr<Ui::ChatTheme> theme) {
+	) | rpl::on_next([=](std::shared_ptr<Ui::ChatTheme> theme) {
 		_theme = std::move(theme);
 		_style->apply(_theme.get());
 	}, lifetime());
 
 	const auto session = &_item->history()->session();
 	session->data().viewRepaintRequest(
-	) | rpl::start_with_next([=](not_null<const HistoryView::Element*> view) {
+	) | rpl::on_next([=](not_null<const HistoryView::Element*> view) {
 		if (view == _element.get()) {
 			update(_elementGeometry);
 		}
 	}, lifetime());
 	session->data().itemViewRefreshRequest(
-	) | rpl::start_with_next([=](not_null<const HistoryItem*> item) {
+	) | rpl::on_next([=](not_null<const HistoryItem*> item) {
 		if (item == _item) {
 			if (goodItem()) {
 				createView();
@@ -180,13 +180,13 @@ PreviewWrap::PreviewWrap(
 		}
 	}, lifetime());
 	session->data().itemDataChanges(
-	) | rpl::start_with_next([=](not_null<HistoryItem*> item) {
+	) | rpl::on_next([=](not_null<HistoryItem*> item) {
 		if (item == _item) {
 			_element->itemDataChanged();
 		}
 	}, lifetime());
 	session->data().itemRemoved(
-	) | rpl::start_with_next([=](not_null<const HistoryItem*> item) {
+	) | rpl::on_next([=](not_null<const HistoryItem*> item) {
 		if (item == _item) {
 			_closeRequests.fire({});
 		}
@@ -206,7 +206,7 @@ PreviewWrap::PreviewWrap(
 		rpl::combine(
 			sizeValue(),
 			_elementInner.value()
-		) | rpl::start_with_next([=](QSize size, QRect inner) {
+		) | rpl::on_next([=](QSize size, QRect inner) {
 			close->moveToLeft(
 				inner.x() + (inner.width() - close->width()) / 2,
 				(size.height()
@@ -246,7 +246,7 @@ PreviewWrap::PreviewWrap(
 		_elementInner.value(
 		) | rpl::filter([](const QRect &inner) {
 			return !inner.isEmpty();
-		}) | rpl::start_with_next([=](const QRect &inner) {
+		}) | rpl::on_next([=](const QRect &inner) {
 			tooltip->pointAt(inner, RectPart::Top, [=](QSize size) {
 				return QPoint{
 					inner.x() + (inner.width() - size.width()) / 2,
@@ -281,7 +281,7 @@ void PreviewWrap::createView() {
 	rpl::combine(
 		sizeValue(),
 		_globalViewport.value()
-	) | rpl::start_with_next([=](QSize outer, QRect globalViewport) {
+	) | rpl::on_next([=](QSize outer, QRect globalViewport) {
 		_viewport = globalViewport.isEmpty()
 			? rect()
 			: mapFromGlobal(globalViewport);
@@ -371,7 +371,7 @@ void ShowTTLMediaLayerWidget(
 			controller,
 			item->history()->peer));
 	preview->closeRequests(
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		show->hideLayer();
 	}, preview->lifetime());
 	auto layer = std::make_unique<Editor::LayerWidget>(
