@@ -1010,7 +1010,7 @@ rpl::producer<bool> ChannelData::unrestrictedByBoostsValue() const {
 	return mgInfo
 		? mgInfo->unrestrictedByBoostsChanges.events_starting_with(
 			unrestrictedByBoosts())
-		: (rpl::single(false) | rpl::type_erased());
+		: (rpl::single(false) | rpl::type_erased);
 }
 
 void ChannelData::setBoostsUnrestrict(int applied, int unrestrict) {
@@ -1099,7 +1099,7 @@ void ChannelData::setGroupCall(
 			data.vaccess_hash().v,
 			scheduleDate,
 			rtmp,
-			false); // conference
+			Data::GroupCallOrigin::Group);
 		owner().registerGroupCall(_call.get());
 		session().changes().peerUpdated(this, UpdateFlag::GroupCall);
 		addFlags(Flag::CallActive);
@@ -1158,20 +1158,34 @@ bool ChannelData::hasUnreadStories() const {
 	return flags() & Flag::HasUnreadStories;
 }
 
+bool ChannelData::hasActiveVideoStream() const {
+	return flags() & Flag::HasActiveVideoStream;
+}
+
 void ChannelData::setStoriesState(StoriesState state) {
 	Expects(state != StoriesState::Unknown);
 
 	const auto was = flags();
 	switch (state) {
 	case StoriesState::None:
-		_flags.remove(Flag::HasActiveStories | Flag::HasUnreadStories);
+		_flags.remove(Flag::HasActiveStories
+			| Flag::HasUnreadStories
+			| Flag::HasActiveVideoStream);
 		break;
 	case StoriesState::HasRead:
-		_flags.set(
-			(flags() & ~Flag::HasUnreadStories) | Flag::HasActiveStories);
+		_flags.set(Flag::HasActiveStories
+			| (was
+				& ~(Flag::HasUnreadStories | Flag::HasActiveVideoStream)));
 		break;
 	case StoriesState::HasUnread:
-		_flags.add(Flag::HasActiveStories | Flag::HasUnreadStories);
+		_flags.set((was & ~Flag::HasActiveVideoStream)
+			| Flag::HasActiveStories
+			| Flag::HasUnreadStories);
+		break;
+	case StoriesState::HasVideoStream:
+		_flags.set((was & ~Flag::HasUnreadStories)
+			| Flag::HasActiveStories
+			| Flag::HasActiveVideoStream);
 		break;
 	}
 	if (flags() != was) {
@@ -1464,7 +1478,7 @@ void ApplyChannelUpdate(
 			}
 			creditsLoadLifetime->destroy();
 		});
-		base::timer_once(kTimeout) | rpl::start_with_next([=] {
+		base::timer_once(kTimeout) | rpl::on_next([=] {
 			creditsLoadLifetime->destroy();
 		}, *creditsLoadLifetime);
 		const auto currencyLoadLifetime = std::make_shared<rpl::lifetime>();
@@ -1476,13 +1490,13 @@ void ApplyChannelUpdate(
 			}
 			currencyLoadLifetime->destroy();
 		};
-		currencyLoad->request() | rpl::start_with_error_done(
+		currencyLoad->request() | rpl::on_error_done(
 			[=](const QString &error) {
 				apply(CreditsAmount(0, CreditsType::Ton));
 			},
 			[=] { apply(currencyLoad->data().currentBalance); },
 			*currencyLoadLifetime);
-		base::timer_once(kTimeout) | rpl::start_with_next([=] {
+		base::timer_once(kTimeout) | rpl::on_next([=] {
 			currencyLoadLifetime->destroy();
 		}, *currencyLoadLifetime);
 	}
