@@ -91,7 +91,9 @@ public:
 	}
 
 	[[nodiscard]] std::shared_ptr<RepliesList> replies() const;
-	[[nodiscard]] not_null<ChannelData*> channel() const;
+	[[nodiscard]] not_null<PeerData*> peer() const;
+	[[nodiscard]] UserData *bot() const;
+	[[nodiscard]] ChannelData *channel() const;
 	[[nodiscard]] not_null<History*> history() const;
 	[[nodiscard]] not_null<Forum*> forum() const;
 	[[nodiscard]] rpl::producer<> destroyed() const;
@@ -148,6 +150,7 @@ public:
 
 	[[nodiscard]] QString title() const;
 	[[nodiscard]] TextWithEntities titleWithIcon() const;
+	[[nodiscard]] TextWithEntities titleWithIconOrLogo() const;
 	[[nodiscard]] int titleVersion() const;
 	void applyTitle(const QString &title);
 	[[nodiscard]] DocumentId iconId() const;
@@ -157,6 +160,7 @@ public:
 	void applyCreator(PeerId creatorId);
 	void applyCreationDate(TimeId date);
 	void applyIsMy(bool my);
+	void applyMaybeLast(not_null<HistoryItem*> item);
 	void applyItemAdded(not_null<HistoryItem*> item);
 	void applyItemRemoved(MsgId id);
 	void maybeSetLastMessage(not_null<HistoryItem*> item);
