@@ -134,12 +134,13 @@ struct GiveawayResults {
 };
 
 enum class GiftType : uchar {
-	Premium, // count - months
+	Premium, // count - days
 	Credits, // count - credits
 	Ton, // count - nano tons
 	StarGift, // count - stars
 	ChatTheme,
 	BirthdaySuggest,
+	GiftOffer,
 };
 
 struct GiftCode {
@@ -149,16 +150,20 @@ struct GiftCode {
 	PeerData *stargiftReleasedBy = nullptr;
 	std::shared_ptr<UniqueGift> unique;
 	TextWithEntities message;
+	PeerData *auctionTo = nullptr;
 	ChannelData *channel = nullptr;
 	PeerData *channelFrom = nullptr;
 	uint64 channelSavedId = 0;
 	QString giftPrepayUpgradeHash;
+	QString giftTitle;
 	MsgId giveawayMsgId = 0;
 	MsgId realGiftMsgId = 0;
 	int starsConverted = 0;
 	int starsToUpgrade = 0;
 	int starsUpgradedBySender = 0;
 	int starsForDetailsRemove = 0;
+	int starsBid = 0;
+	int giftNum = 0;
 	int limitedCount = 0;
 	int limitedLeft = 0;
 	int64 count = 0;
@@ -166,6 +171,7 @@ struct GiftCode {
 	bool viaGiveaway : 1 = false;
 	bool transferred : 1 = false;
 	bool upgradeSeparate : 1 = false;
+	bool upgradeGifted : 1 = false;
 	bool upgradable : 1 = false;
 	bool unclaimed : 1 = false;
 	bool anonymous : 1 = false;
