@@ -387,11 +387,11 @@ public:
 	void setUserpicPhoto(const MTPPhoto &data);
 
 	void paintUserpic(
-		Painter &p,
+		QPainter &p,
 		Ui::PeerUserpicView &view,
 		PaintUserpicContext context) const;
 	void paintUserpic(
-			Painter &p,
+			QPainter &p,
 			Ui::PeerUserpicView &view,
 			int x,
 			int y,
@@ -406,7 +406,7 @@ public:
 		});
 	}
 	void paintUserpicLeft(
-			Painter &p,
+			QPainter &p,
 			Ui::PeerUserpicView &view,
 			int x,
 			int y,
@@ -489,7 +489,7 @@ public:
 	[[nodiscard]] auto barSettingsValue() const {
 		return (_barSettings.current() & PeerBarSetting::Unknown)
 			? _barSettings.changes()
-			: (_barSettings.value() | rpl::type_erased());
+			: (_barSettings.value() | rpl::type_erased);
 	}
 	[[nodiscard]] int paysPerMessage() const;
 	void clearPaysPerMessage();
