@@ -200,6 +200,10 @@ int PremiumLimits::aboutLengthCurrent() const {
 		: aboutLengthDefault();
 }
 
+int PremiumLimits::contactNoteLengthCurrent() const {
+	return appConfigLimit("contact_note_length_limit", 128);
+}
+
 int PremiumLimits::maxBoostLevel() const {
 	return appConfigLimit(
 		u"boosts_channel_level_max"_q,
