@@ -204,7 +204,7 @@ rpl::producer<Ui::SlideWrap<Ui::RpWidget>*> TopBarSuggestionValue(
 				rpl::combine(
 					parent->widthValue(),
 					state->content->desiredHeightValue()
-				) | rpl::start_with_next([=](int width, int height) {
+				) | rpl::on_next([=](int width, int height) {
 					state->content->resize(width, height);
 				}, state->content->lifetime());
 			}
@@ -292,7 +292,7 @@ rpl::producer<Ui::SlideWrap<Ui::RpWidget>*> TopBarSuggestionValue(
 				const auto button = lifetime.template make_state<Button>();
 				const auto window = FindSessionController(parent);
 				auctions->active(
-				) | rpl::start_with_next([=](ActiveAuctions &&active) {
+				) | rpl::on_next([=](ActiveAuctions &&active) {
 					const auto empty = active.list.empty();
 					state->desiredWrapToggle.force_assign(
 						Toggle{ !empty, anim::type::normal });
@@ -425,7 +425,7 @@ rpl::producer<Ui::SlideWrap<Ui::RpWidget>*> TopBarSuggestionValue(
 				};
 				session->credits().load();
 				state->creditsLifetime.destroy();
-				session->credits().balanceValue() | rpl::start_with_next([=] {
+				session->credits().balanceValue() | rpl::on_next([=] {
 					state->creditsLifetime.destroy();
 					state->creditsHistory->requestSubscriptions(
 						Data::CreditsStatusSlice::OffsetToken(),
@@ -513,7 +513,7 @@ rpl::producer<Ui::SlideWrap<Ui::RpWidget>*> TopBarSuggestionValue(
 						widget->setAttribute(
 							Qt::WA_TransparentForMouseEvents);
 						content->sizeValue() | rpl::filter_size(
-						) | rpl::start_with_next([=](const QSize &size) {
+						) | rpl::on_next([=](const QSize &size) {
 							widget->resize(size);
 							widget->show();
 							widget->raise();
@@ -523,7 +523,7 @@ rpl::producer<Ui::SlideWrap<Ui::RpWidget>*> TopBarSuggestionValue(
 								s->inRow.push_back({ .peer = user });
 							}
 						}
-						widget->paintRequest() | rpl::start_with_next([=] {
+						widget->paintRequest() | rpl::on_next([=] {
 							auto p = QPainter(widget);
 							const auto regenerate = [&] {
 								if (s->userpics.isNull()) {
@@ -573,7 +573,7 @@ rpl::producer<Ui::SlideWrap<Ui::RpWidget>*> TopBarSuggestionValue(
 						rpl::combine(
 							state->leftPadding.value(),
 							content->sizeValue() | rpl::filter_size()
-						) | rpl::start_with_next([=](int p, const QSize &s) {
+						) | rpl::on_next([=](int p, const QSize &s) {
 							fake->raise();
 							fake->show();
 							fake->moveToLeft(
@@ -605,7 +605,7 @@ rpl::producer<Ui::SlideWrap<Ui::RpWidget>*> TopBarSuggestionValue(
 						Data::IsBirthdayTodayValue
 					) | rpl::flatten_latest(
 					) | rpl::distinct_until_changed(
-					) | rpl::start_with_next([=] {
+					) | rpl::on_next([=] {
 						repeat(repeat);
 					});
 				});
@@ -667,7 +667,7 @@ rpl::producer<Ui::SlideWrap<Ui::RpWidget>*> TopBarSuggestionValue(
 					content->setRightIcon(RightIcon::Arrow);
 					content->setLeftPadding(state->leftPadding.value());
 					const auto api = &session->api().premium();
-					api->statusTextValue() | rpl::start_with_next([=] {
+					api->statusTextValue() | rpl::on_next([=] {
 						for (const auto &o : api->subscriptionOptions()) {
 							if (o.months == 12) {
 								set(o.discount);
@@ -692,7 +692,7 @@ rpl::producer<Ui::SlideWrap<Ui::RpWidget>*> TopBarSuggestionValue(
 				rpl::combine(
 					state->leftPadding.value(),
 					content->sizeValue() | rpl::filter_size()
-				) | rpl::start_with_next([=](int padding, const QSize &s) {
+				) | rpl::on_next([=](int padding, const QSize &s) {
 					upload->raise();
 					upload->show();
 					upload->moveToLeft(
@@ -700,7 +700,7 @@ rpl::producer<Ui::SlideWrap<Ui::RpWidget>*> TopBarSuggestionValue(
 						(s.height() - upload->height()) / 2);
 				}, content->lifetime());
 				setLeftPaddingRelativeTo(content, upload);
-				upload->chosenImages() | rpl::start_with_next([=](
+				upload->chosenImages() | rpl::on_next([=](
 						Ui::UserpicButton::ChosenImage &&chosen) {
 					if (chosen.type == Ui::UserpicButton::ChosenType::Set) {
 						session->api().peerPhoto().upload(
@@ -716,7 +716,7 @@ rpl::producer<Ui::SlideWrap<Ui::RpWidget>*> TopBarSuggestionValue(
 				state->userpicLifetime = session->changes().peerUpdates(
 					session->user(),
 					Data::PeerUpdate::Flag::Photo
-				) | rpl::start_with_next([=] {
+				) | rpl::on_next([=] {
 					if (session->user()->userpicPhotoId()) {
 						repeat(repeat);
 					}
@@ -762,7 +762,7 @@ rpl::producer<Ui::SlideWrap<Ui::RpWidget>*> TopBarSuggestionValue(
 		state->desiredWrapToggle.value() | rpl::combine_previous(
 		) | rpl::filter([=] {
 			return state->wrap != nullptr;
-		}) | rpl::start_with_next([=](Toggle was, Toggle now) {
+		}) | rpl::on_next([=](Toggle was, Toggle now) {
 			state->wrap->toggle(
 				state->outerWrapToggle.current() && now.value,
 				(was.value == now.value)
@@ -773,7 +773,7 @@ rpl::producer<Ui::SlideWrap<Ui::RpWidget>*> TopBarSuggestionValue(
 		state->outerWrapToggle.value() | rpl::combine_previous(
 		) | rpl::filter([=] {
 			return state->wrap != nullptr;
-		}) | rpl::start_with_next([=](bool was, bool now) {
+		}) | rpl::on_next([=](bool was, bool now) {
 			const auto toggle = state->desiredWrapToggle.current();
 			state->wrap->toggle(
 				toggle.value && now,
@@ -785,7 +785,7 @@ rpl::producer<Ui::SlideWrap<Ui::RpWidget>*> TopBarSuggestionValue(
 			session->api().authorizations().unreviewedChanges(),
 			Data::AmPremiumValue(session) | rpl::skip(1) | rpl::to_empty,
 			session->giftAuctions().hasActiveChanges() | rpl::to_empty
-		) | rpl::start_with_next([=] {
+		) | rpl::on_next([=] {
 			const auto was = state->wrap.get();
 			const auto weak = base::make_weak(was);
 			processCurrentSuggestion(processCurrentSuggestion);
