@@ -198,7 +198,8 @@ MTPMessage PrepareLogMessage(const MTPMessage &message, TimeId newDate) {
 			MTPFactCheck(),
 			MTPint(), // report_delivery_until_date
 			MTP_long(data.vpaid_message_stars().value_or_empty()),
-			MTPSuggestedPost());
+			MTPSuggestedPost(),
+			MTPint()); // schedule_repeat_period
 	});
 }
 
@@ -295,12 +296,6 @@ TextWithEntities GenerateAdminChangeText(
 	phraseMap[Flag::InviteByLinkOrAdd] = invitePhrase;
 	phraseMap[Flag::ManageCall] = callPhrase;
 
-	if (!channel->isMegagroup()) {
-		// Don't display "Ban users" changes in channels.
-		newRights.flags &= ~Flag::BanUsers;
-		prevRights.flags &= ~Flag::BanUsers;
-	}
-
 	const auto changes = CollectChanges(
 		phraseMap,
 		newRights.flags,
