@@ -223,7 +223,7 @@ std::optional<SendPaymentDetails> ComputePaymentDetails(
 
 bool SuggestPaymentDataReady(
 		not_null<PeerData*> peer,
-		SuggestPostOptions suggest) {
+		SuggestOptions suggest) {
 	if (!suggest.exists || !suggest.price() || peer->amMonoforumAdmin()) {
 		return true;
 	} else if (suggest.ton && !peer->session().credits().tonLoaded()) {
@@ -460,7 +460,7 @@ bool SendPaymentHelper::check(
 			peer->session().credits().loadedValue(
 			) | rpl::filter(
 				rpl::mappers::_1
-			) | rpl::take(1) | rpl::start_with_next([=] {
+			) | rpl::take(1) | rpl::on_next([=] {
 				if (const auto callback = base::take(_resend)) {
 					callback();
 				}
@@ -472,7 +472,7 @@ bool SendPaymentHelper::check(
 			peer->session().credits().tonLoadedValue(
 			) | rpl::filter(
 				rpl::mappers::_1
-			) | rpl::take(1) | rpl::start_with_next([=] {
+			) | rpl::take(1) | rpl::on_next([=] {
 				if (const auto callback = base::take(_resend)) {
 					callback();
 				}
@@ -482,7 +482,7 @@ bool SendPaymentHelper::check(
 		peer->session().changes().peerUpdates(
 			peer,
 			Data::PeerUpdate::Flag::FullInfo
-		) | rpl::start_with_next([=] {
+		) | rpl::on_next([=] {
 			if (const auto callback = base::take(_resend)) {
 				callback();
 			}
@@ -994,6 +994,8 @@ MediaCheckResult CheckMessageMedia(const MTPMessageMedia &media) {
 		return Result::Good;
 	}, [](const MTPDmessageMediaPaidMedia &) {
 		return Result::Good;
+	}, [](const MTPDmessageMediaVideoStream &) {
+		return Result::Good;
 	}, [](const MTPDmessageMediaUnsupported &) {
 		return Result::Unsupported;
 	});
