@@ -10,6 +10,7 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 #include "ui/chat/message_bubble.h"
 #include "ui/chat/chat_style.h"
 #include "ui/effects/reaction_fly_animation.h"
+#include "ui/text/format_values.h"
 #include "ui/text/text_options.h"
 #include "ui/text/text_utilities.h"
 #include "ui/painter.h"
@@ -21,6 +22,7 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 #include "history/view/media/history_view_media.h"
 #include "history/view/history_view_message.h"
 #include "history/view/history_view_cursor_state.h"
+#include "base/unixtime.h"
 #include "chat_helpers/emoji_interactions.h"
 #include "core/click_handler_types.h"
 #include "main/main_session.h"
@@ -34,6 +36,39 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 #include "styles/style_dialogs.h"
 
 namespace HistoryView {
+namespace {
+
+[[nodiscard]] QString SchedulePeriodText(TimeId period) {
+	struct Entry {
+		TimeId period = 0;
+		QString text;
+	};
+	const auto map = std::vector<Entry>{
+		{ 60, u"minutely"_q },
+		{ 300, u"5-minutely"_q },
+		{ 24 * 60 * 60, tr::lng_repeated_daily(tr::now) },
+		{ 7 * 24 * 60 * 60, tr::lng_repeated_weekly(tr::now) },
+		{ 14 * 24 * 60 * 60, tr::lng_repeated_biweekly(tr::now) },
+		{ 30 * 24 * 60 * 60, tr::lng_repeated_monthly(tr::now) },
+		{
+			91 * 24 * 60 * 60,
+			tr::lng_repeated_every_month(tr::now, lt_count, 3)
+		},
+		{
+			182 * 24 * 60 * 60,
+			tr::lng_repeated_every_month(tr::now, lt_count, 6)
+		},
+		{ 365 * 24 * 60 * 60, tr::lng_repeated_yearly(tr::now) },
+	};
+	for (const auto &entry : map) {
+		if (entry.period >= period) {
+			return entry.text;
+		}
+	}
+	return map.back().text;
+}
+
+} // namespace
 
 struct BottomInfo::Effect {
 	mutable std::unique_ptr<Ui::ReactionFlyAnimation> animation;
@@ -102,6 +137,7 @@ int BottomInfo::firstLineWidth() const {
 
 bool BottomInfo::isWide() const {
 	return (_data.flags & Data::Flag::Edited)
+		|| _data.scheduleRepeatPeriod
 		|| !_data.author.isEmpty()
 		|| !_views.isEmpty()
 		|| !_replies.isEmpty()
@@ -412,12 +448,14 @@ void BottomInfo::layoutDateText() {
 		? (tr::lng_edited(tr::now) + ' ')
 		: (_data.flags & Data::Flag::EstimateDate)
 		? (tr::lng_approximate(tr::now) + ' ')
+		: _data.scheduleRepeatPeriod
+		? (SchedulePeriodText(_data.scheduleRepeatPeriod) + ' ')
 		: QString();
 	const auto author = _data.author;
 	const auto prefix = !author.isEmpty() ? u", "_q : QString();
-	const auto date = edited + QLocale().toString(
-		_data.date.time(),
-		QLocale::ShortFormat);
+	const auto date = edited + ((_data.flags & Data::Flag::ForwardedDate)
+		? Ui::FormatDateTimeSavedFrom(_data.date)
+		: QLocale().toString(_data.date.time(), QLocale::ShortFormat));
 	const auto afterAuthor = prefix + date;
 	const auto afterAuthorWidth = st::msgDateFont->width(afterAuthor);
 	const auto authorWidth = st::msgDateFont->width(author);
@@ -615,6 +653,17 @@ BottomInfo::Data BottomInfoDataFromMessage(not_null<Message*> message) {
 	if (item->awaitingVideoProcessing()) {
 		result.flags |= Flag::EstimateDate;
 	}
+	if (item->isScheduled()) {
+		result.scheduleRepeatPeriod = item->scheduleRepeatPeriod();
+	}
+	if (forwarded
+		&& forwarded->originalDate
+		&& (message->context() == Context::SavedSublist
+			|| item->history()->peer->isSelf())
+		&& !item->externalReply()) {
+		result.date = base::unixtime::parse(forwarded->originalDate);
+		result.flags |= Flag::ForwardedDate;
+	}
 	// We don't want to pass and update it in Data for now.
 	//if (item->unread()) {
 	//	result.flags |= Flag::Unread;
