@@ -74,6 +74,7 @@ class EmptyPainter;
 class PinnedTracker;
 class TranslateBar;
 class SubsectionTabs;
+class SelfForwardsTagger;
 
 struct ChatViewId {
 	not_null<History*> history;
@@ -454,6 +455,8 @@ private:
 
 	bool _loaded = false;
 
+	std::unique_ptr<HistoryView::SelfForwardsTagger> _selfForwardsTagger;
+
 };
 
 class ChatMemento final : public Window::SectionMemento {
