@@ -94,7 +94,7 @@ rpl::producer<TextWithEntities> AgeVerifyAbout(
 	auto result = object_ptr<Ui::RpWidget>(parent);
 	const auto raw = result.data();
 	raw->resize(full);
-	raw->paintRequest() | rpl::start_with_next([=] {
+	raw->paintRequest() | rpl::on_next([=] {
 		auto p = QPainter(raw);
 		const auto x = (raw->width() - full.width()) / 2;
 		auto hq = PainterHighQualityEnabler(p);
@@ -354,19 +354,22 @@ void ShowAgeVerification(
 				box,
 				tr::lng_age_verify_title(),
 				st::settingsAgeVerifyTitle),
-			st::boxRowPadding + st::settingsAgeVerifyMargin);
+			st::boxRowPadding + st::settingsAgeVerifyMargin,
+			style::al_top);
 		box->addRow(
 			object_ptr<Ui::FlatLabel>(
 				box,
 				AgeVerifyAbout(&bot->session()),
 				st::settingsAgeVerifyText),
-			st::boxRowPadding + st::settingsAgeVerifyMargin);
+			st::boxRowPadding + st::settingsAgeVerifyMargin,
+			style::al_top);
 		box->addRow(
 			object_ptr<Ui::FlatLabel>(
 				box,
 				tr::lng_age_verify_here(Ui::Text::RichLangValue),
 				st::settingsAgeVerifyText),
-			st::boxRowPadding + st::settingsAgeVerifyMargin);
+			st::boxRowPadding + st::settingsAgeVerifyMargin,
+			style::al_top);
 
 		const auto weak = QPointer<Ui::GenericBox>(box);
 		const auto done = crl::guard(&bot->session(), [=](int age) {
@@ -396,7 +399,7 @@ void ShowAgeVerification(
 			});
 		});
 		box->widthValue(
-		) | rpl::start_with_next([=](int width) {
+		) | rpl::on_next([=](int width) {
 			const auto &padding = st::settingsAgeVerifyBox.buttonPadding;
 			button->resizeToWidth(width
 				- padding.left()
@@ -411,7 +414,7 @@ void ShowAgeVerification(
 			box->closeBox();
 		});
 		box->widthValue(
-		) | rpl::start_with_next([=](int width) {
+		) | rpl::on_next([=](int width) {
 			close->moveToRight(0, 0);
 		}, box->lifetime());
 		crl::on_main(close, [=] { close->raise(); });
@@ -435,7 +438,7 @@ void ShowAgeVerificationMobile(
 			st::peerAppearanceIconPadding);
 
 		box->showFinishes(
-		) | rpl::start_with_next([animate = std::move(icon.animate)] {
+		) | rpl::on_next([animate = std::move(icon.animate)] {
 			animate(anim::repeat::once);
 		}, box->lifetime());
 
@@ -446,13 +449,15 @@ void ShowAgeVerificationMobile(
 				box,
 				AgeVerifyAbout(session),
 				st::settingsAgeVerifyText),
-			st::boxRowPadding + st::settingsAgeVerifyMargin);
+			st::boxRowPadding + st::settingsAgeVerifyMargin,
+			style::al_top);
 		box->addRow(
 			object_ptr<Ui::FlatLabel>(
 				box,
 				tr::lng_age_verify_mobile(Ui::Text::RichLangValue),
 				st::settingsAgeVerifyText),
-			st::boxRowPadding + st::settingsAgeVerifyMargin);
+			st::boxRowPadding + st::settingsAgeVerifyMargin,
+			style::al_top);
 
 		box->addButton(tr::lng_box_ok(), [=] {
 			box->closeBox();
@@ -498,7 +503,7 @@ void ShowAgeVerificationRequired(
 			state->lifetime = sensitive->loadedValue(
 			) | rpl::filter(
 				rpl::mappers::_1
-			) | rpl::take(1) | rpl::start_with_next(state->check);
+			) | rpl::take(1) | rpl::on_next(state->check);
 			return;
 		} else if (!state->bot.has_value()) {
 			return;
