@@ -278,7 +278,7 @@ ClickHandlerPtr PremiumGift::createViewLink() {
 						return window->session().credits().tonLoaded();
 					}
 					return false;
-				}) | rpl::take(1) | rpl::start_with_next([=] {
+				}) | rpl::take(1) | rpl::on_next([=] {
 					if (const auto window = weak.get()) {
 						window->showSettings(Settings::CurrencyId());
 					}
@@ -513,6 +513,9 @@ ClickHandlerPtr OpenStarGiftLink(not_null<HistoryItem*> item) {
 	}
 	const auto data = *gift;
 	const auto itemId = item->fullId();
+	const auto upgradedMsgId = data.upgraded
+		? data.realGiftMsgId
+		: MsgId(0);
 	const auto openInsteadId = data.realGiftMsgId
 		? Data::SavedStarGiftId::User(data.realGiftMsgId)
 		: (data.channel && data.channelSavedId)
@@ -536,33 +539,70 @@ ClickHandlerPtr OpenStarGiftLink(not_null<HistoryItem*> item) {
 			return;
 		}
 		*requesting = true;
-		controller->session().api().request(MTPpayments_GetSavedStarGift(
-			MTP_vector<MTPInputSavedStarGift>(
-				1,
-				Api::InputSavedStarGiftId(openInsteadId))
-		)).done([=](const MTPpayments_SavedStarGifts &result) {
-			*requesting = false;
-			if (const auto window = weak.get()) {
-				const auto &data = result.data();
-				window->session().data().processUsers(data.vusers());
-				window->session().data().processChats(data.vchats());
-				const auto owner = openInsteadId.chat()
-					? openInsteadId.chat()
-					: window->session().user();
-				const auto &list = data.vgifts().v;
-				if (list.empty()) {
-					quick(window);
-				} else if (auto parsed = Api::FromTL(owner, list[0])) {
-					Settings::ShowSavedStarGiftBox(window, owner, *parsed);
+		const auto requestSavedGift = [=] {
+			controller->session().api().request(MTPpayments_GetSavedStarGift(
+				MTP_vector<MTPInputSavedStarGift>(
+					1,
+					Api::InputSavedStarGiftId(openInsteadId))
+			)).done([=](const MTPpayments_SavedStarGifts &result) {
+				*requesting = false;
+				if (const auto window = weak.get()) {
+					const auto &data = result.data();
+					window->session().data().processUsers(data.vusers());
+					window->session().data().processChats(data.vchats());
+					const auto owner = openInsteadId.chat()
+						? openInsteadId.chat()
+						: window->session().user();
+					const auto &list = data.vgifts().v;
+					if (list.empty()) {
+						quick(window);
+					} else if (auto g = Api::FromTL(owner, list[0])) {
+						Settings::ShowSavedStarGiftBox(window, owner, *g);
+					}
 				}
+			}).fail([=](const MTP::Error &error) {
+				*requesting = false;
+				if (const auto window = weak.get()) {
+					window->showToast(error.type());
+					quick(window);
+				}
+			}).send();
+		};
+		if (const auto msgId = upgradedMsgId) {
+			const auto session = &controller->session();
+			const auto owner = &controller->session().data();
+			const auto processItem = [=](not_null<HistoryItem*> item) {
+				const auto media = item->media();
+				if (!media || !media->gift() || !media->gift()->unique) {
+					*requesting = false;
+					if (const auto window = weak.get()) {
+						quick(window);
+					}
+					return;
+				}
+				// It is not possible to request a saved star gift
+				// when it is transferred and does not belong to you.
+				if (!media->gift()->transferred) {
+					return requestSavedGift();
+				}
+				*requesting = false;
+				const auto local = u"nft/"_q + media->gift()->unique->slug;
+				UrlClickHandler::Open(session->createInternalLinkFull(local));
+			};
+			if (const auto item = owner->nonChannelMessage(msgId)) {
+				processItem(item);
+			} else {
+				session->api().requestMessageData(nullptr, msgId, [=] {
+					if (const auto item = owner->nonChannelMessage(msgId)) {
+						processItem(item);
+					} else {
+						*requesting = false;
+					}
+				});
 			}
-		}).fail([=](const MTP::Error &error) {
-			*requesting = false;
-			if (const auto window = weak.get()) {
-				window->showToast(error.type());
-				quick(window);
-			}
-		}).send();
+		} else {
+			requestSavedGift();
+		}
 	});
 }
 
