@@ -111,6 +111,10 @@ private:
 	void paintPath(Painter &p, const PaintContext &context, const QRect &r);
 	[[nodiscard]] QPixmap paintedPixmap(const PaintContext &context) const;
 	[[nodiscard]] bool mirrorHorizontal() const;
+	void paintSensitiveTag(
+		Painter &p,
+		const PaintContext &context,
+		const QRect &r);
 
 	void ensureDataMediaCreated() const;
 	void dataMediaCreated() const;
@@ -145,6 +149,7 @@ private:
 	bool _webpagePart : 1 = false;
 	bool _playingOnce : 1 = false;
 	bool _stopOnLastFrame : 1 = false;
+	bool _sensitiveBlurred : 1 = false;
 
 };
 
