@@ -7,6 +7,7 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 */
 #include "history/view/media/history_view_web_page.h"
 
+#include "base/unixtime.h"
 #include "core/application.h"
 #include "countries/countries_instance.h"
 #include "base/qt/qt_key_modifiers.h"
@@ -236,14 +237,20 @@ constexpr auto kSponsoredUserpicLines = 2;
 		? tr::lng_view_button_storyalbum(tr::now)
 		: (type == WebPageType::GiftCollection)
 		? tr::lng_view_button_collection(tr::now)
+		: (type == WebPageType::Auction)
+		? ((page->auction
+			&& page->auction->endDate
+			&& page->auction->endDate <= base::unixtime::now())
+			? tr::lng_auction_preview_view_results(tr::now)
+			: (page->auction
+				&& page->auction->auctionGift->auctionStartDate
+				&& (page->auction->auctionGift->auctionStartDate
+				> base::unixtime::now()))
+			? tr::lng_auction_bar_view(tr::now)
+			: tr::lng_auction_preview_join(tr::now))
 		: QString());
 	if (page->iv) {
-		const auto manager = &page->owner().customEmojiManager();
-		const auto &icon = st::historyIvIcon;
-		const auto padding = st::historyIvIconPadding;
-		return Ui::Text::SingleCustomEmoji(
-			manager->registerInternalEmoji(icon, padding)
-		).append(text);
+		return Ui::Text::IconEmoji(&st::historyIvIcon).append(text);
 	}
 	return { text };
 }
@@ -276,7 +283,8 @@ constexpr auto kSponsoredUserpicLines = 2;
 			&& webpage->document->isWallPaper())
 		|| (type == WebPageType::StickerSet)
 		|| (type == WebPageType::StoryAlbum)
-		|| (type == WebPageType::GiftCollection);
+		|| (type == WebPageType::GiftCollection)
+		|| (type == WebPageType::Auction);
 }
 
 } // namespace
@@ -522,8 +530,33 @@ QSize WebPage::countOptimalSize() {
 				_data->uniqueGift),
 				MediaGenericDescriptor{
 					.maxWidth = st::msgServiceGiftPreview,
-					.paintBg = UniqueGiftBg(_parent, _data->uniqueGift),
+					.paintBgFactory = [=] {
+						return UniqueGiftBg(_parent, _data->uniqueGift);
+					},
 				});
+	} else if (!_attach && _data->auction) {
+		const auto &gift = _data->auction->auctionGift;
+		const auto backdrop = gift->background
+			? gift->background->backdrop()
+			: Data::UniqueGiftBackdrop();
+		_attach = std::make_unique<MediaGeneric>(
+			_parent,
+			GenerateAuctionPreview(
+				_parent,
+				nullptr,
+				gift,
+				backdrop),
+			MediaGenericDescriptor{
+				.maxWidth = st::msgServiceGiftPreview,
+				.paintBgFactory = [=] {
+					return AuctionBg(
+						_parent,
+						backdrop,
+						gift,
+						_data->auction->auctionGift->auctionStartDate,
+						_data->auction->endDate);
+				},
+			});
 	} else if (!_attach && !_asArticle) {
 		_attach = CreateAttach(
 			_parent,
@@ -538,7 +571,8 @@ QSize WebPage::countOptimalSize() {
 	// init strings
 	if (_description.isEmpty()
 		&& !_data->description.text.isEmpty()
-		&& !_data->uniqueGift) {
+		&& !_data->uniqueGift
+		&& !_data->auction) {
 		const auto &text = _data->description;
 		using Type = Core::TextContextDetails::HashtagMentionType;
 		auto context = Core::TextContext({
@@ -900,45 +934,60 @@ void WebPage::draw(Painter &p, const PaintContext &context) const {
 
 	const auto selected = context.selected();
 	const auto view = parent();
-	const auto from = view->data()->contentColorsFrom();
 	const auto colorIndex = factcheck
 		? 0 // red
 		: (sponsored && sponsored->colorIndex)
 		? sponsored->colorIndex
-		: from
-		? from->colorIndex()
-		: view->colorIndex();
-	const auto cache = context.outbg
-		? stm->replyCache[st->colorPatternIndex(colorIndex)].get()
-		: st->coloredReplyCache(selected, colorIndex).get();
+		: view->contentColorIndex();
+	const auto &colorCollectible = factcheck
+		? nullptr
+		: (sponsored && sponsored->colorIndex)
+		? nullptr
+		: view->contentColorCollectible();
+	const auto colorPattern = colorCollectible
+		? st->collectiblePatternIndex(colorCollectible)
+		: st->colorPatternIndex(colorIndex);
+	const auto useColorCollectible = colorCollectible && !context.outbg;
+	const auto useColorIndex = !context.outbg;
+	const auto cache = useColorCollectible
+		? st->collectibleReplyCache(selected, colorCollectible).get()
+		: useColorIndex
+		? st->coloredReplyCache(selected, colorIndex).get()
+		: stm->replyCache[colorPattern].get();
 	const auto backgroundEmojiId = factcheck
 		? DocumentId()
 		: (sponsored && sponsored->backgroundEmojiId)
 		? sponsored->backgroundEmojiId
-		: from
-		? from->backgroundEmojiId()
-		: DocumentId();
-	const auto backgroundEmoji = backgroundEmojiId
-		? st->backgroundEmojiData(backgroundEmojiId).get()
+		: view->contentBackgroundEmojiId();
+	const auto backgroundEmojiData = backgroundEmojiId
+		? st->backgroundEmojiData(backgroundEmojiId, colorCollectible).get()
 		: nullptr;
-	const auto backgroundEmojiCache = backgroundEmoji
-		? &backgroundEmoji->caches[Ui::BackgroundEmojiData::CacheIndex(
+	const auto backgroundEmojiCache = !backgroundEmojiData
+		? nullptr
+		: useColorCollectible
+		? &backgroundEmojiData->collectibleCaches[colorCollectible]
+		: &backgroundEmojiData->caches[Ui::BackgroundEmojiData::CacheIndex(
 			selected,
 			context.outbg,
 			true,
-			colorIndex + 1)]
-		: nullptr;
+			useColorIndex ? (colorIndex + 1) : 0)];
 	Ui::Text::ValidateQuotePaintCache(*cache, _st);
 	Ui::Text::FillQuotePaint(p, outer, *cache, _st);
-	if (backgroundEmoji) {
+	if (backgroundEmojiData) {
 		ValidateBackgroundEmoji(
 			backgroundEmojiId,
-			backgroundEmoji,
+			colorCollectible,
+			backgroundEmojiData,
 			backgroundEmojiCache,
 			cache,
 			view);
 		if (!backgroundEmojiCache->frames[0].isNull()) {
-			FillBackgroundEmoji(p, outer, false, *backgroundEmojiCache);
+			FillBackgroundEmoji(
+				p,
+				outer,
+				false,
+				*backgroundEmojiCache,
+				backgroundEmojiData->firstGiftFrame);
 		}
 	} else if (factcheck && factcheck->expandable) {
 		const auto &icon = factcheck->expanded ? _st.collapse : _st.expand;
@@ -1035,9 +1084,11 @@ void WebPage::draw(Painter &p, const PaintContext &context) const {
 	}
 	if (_siteNameLines) {
 		p.setPen(cache->icon);
-		p.setTextPalette(context.outbg
-			? stm->semiboldPalette
-			: st->coloredTextPalette(selected, colorIndex));
+		p.setTextPalette(useColorCollectible
+			? st->collectibleTextPalette(selected, colorCollectible)
+			: useColorIndex
+			? st->coloredTextPalette(selected, colorIndex)
+			: stm->semiboldPalette);
 
 		const auto endskip = _siteName.hasSkipBlock()
 			? _parent->skipBlockWidth()
