@@ -9,6 +9,7 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 
 #include "info/polls/info_polls_results_widget.h"
 #include "lang/lang_keys.h"
+#include "core/ui_integration.h"
 #include "data/data_peer.h"
 #include "data/data_poll.h"
 #include "data/data_session.h"
@@ -448,7 +449,7 @@ ListController *CreateAnswerRows(
 		st::infoCommonGroupsList));
 
 	controller->count(
-	) | rpl::filter(_1 > 0) | rpl::start_with_next([=] {
+	) | rpl::filter(_1 > 0) | rpl::on_next([=] {
 		delete placeholder;
 	}, placeholder->lifetime());
 
@@ -461,7 +462,9 @@ ListController *CreateAnswerRows(
 					.append(QString::fromUtf8(" \xe2\x80\x94 "))
 					.append(QString::number(percent))
 					.append('%')),
-			st::boxDividerLabel),
+			st::boxDividerLabel,
+			st::defaultPopupMenu,
+			Core::TextContext({ .session = session })),
 		style::margins(
 			st::pollResultsHeaderPadding.left(),
 			st::pollResultsHeaderPadding.top(),
@@ -485,7 +488,7 @@ ListController *CreateAnswerRows(
 	rpl::combine(
 		controller->fullCount(),
 		controller->count()
-	) | rpl::start_with_next([=](int fullCount, int count) {
+	) | rpl::on_next([=](int fullCount, int count) {
 		const auto many = (fullCount > kFirstPage)
 			&& (count > kFirstPage - kLeavePreloaded);
 		collapse->setVisible(many);
@@ -493,7 +496,7 @@ ListController *CreateAnswerRows(
 	}, collapse->lifetime());
 
 	headerWrap->widthValue(
-	) | rpl::start_with_next([=](int width) {
+	) | rpl::on_next([=](int width) {
 		header->resizeToWidth(width);
 		votes->moveToRight(
 			st::pollResultsHeaderPadding.right(),
@@ -506,7 +509,7 @@ ListController *CreateAnswerRows(
 	}, header->lifetime());
 
 	header->heightValue(
-	) | rpl::start_with_next([=](int height) {
+	) | rpl::on_next([=](int height) {
 		headerWrap->resize(headerWrap->width(), height);
 	}, header->lifetime());
 
@@ -527,7 +530,7 @@ ListController *CreateAnswerRows(
 		controller->allowLoadMore();
 	});
 	controller->loadMoreCount(
-	) | rpl::map(_1 > 0) | rpl::start_with_next([=](bool visible) {
+	) | rpl::map(_1 > 0) | rpl::on_next([=](bool visible) {
 		more->toggle(visible, anim::type::instant);
 	}, more->lifetime());
 
@@ -541,7 +544,7 @@ ListController *CreateAnswerRows(
 		moreTop->topValue()
 	) | rpl::filter([=](int, QRect headerRect, int moreTop) {
 		return moreTop >= headerRect.y() + headerRect.height();
-	}) | rpl::start_with_next([=](
+	}) | rpl::on_next([=](
 			int visibleTop,
 			QRect headerRect,
 			int moreTop) {
@@ -610,7 +613,9 @@ void InnerWidget::setupContent() {
 		object_ptr<Ui::FlatLabel>(
 			_content,
 			rpl::single(_poll->question),
-			st::pollResultsQuestion),
+			st::pollResultsQuestion,
+			st::defaultPopupMenu,
+			Core::TextContext({ .session = &_controller->session() })),
 		st::boxRowPadding);
 	Ui::AddSkip(_content, st::boxLittleSkip / 2);
 	_content->add(
@@ -639,19 +644,19 @@ void InnerWidget::setupContent() {
 			_showPeerInfoRequests,
 			lifetime());
 		controller->scrollToRequests(
-		) | rpl::start_with_next([=](int y) {
+		) | rpl::on_next([=](int y) {
 			_scrollToRequests.fire({ y, -1 });
 		}, lifetime());
 		_sections.emplace(answer.option, controller);
 	}
 
 	widthValue(
-	) | rpl::start_with_next([=](int newWidth) {
+	) | rpl::on_next([=](int newWidth) {
 		_content->resizeToWidth(newWidth);
 	}, _content->lifetime());
 
 	_content->heightValue(
-	) | rpl::start_with_next([=](int height) {
+	) | rpl::on_next([=](int height) {
 		resize(width(), height);
 	}, _content->lifetime());
 }
