@@ -93,11 +93,11 @@ void ProcessZoom(
 		return;
 	}
 	widget->zoomRequests(
-	) | rpl::start_with_next([=](float64 x) {
+	) | rpl::on_next([=](float64 x) {
 		d.api->requestZoom(
 			zoomToken,
 			x
-		) | rpl::start_with_next_error_done([=](
+		) | rpl::on_next_error_done([=](
 				const Data::StatisticalGraph &graph) {
 			if (graph.chart) {
 				widget->setZoomedChartData(graph.chart, x, type);
@@ -165,7 +165,7 @@ void FillStatistic(
 			descriptor.api->requestZoom(
 				graphData.zoomToken,
 				0
-			) | rpl::start_with_next_error_done([=, graphPtr = &graphData](
+			) | rpl::on_next_error_done([=, graphPtr = &graphData](
 					const Data::StatisticalGraph &graph) mutable {
 				{
 					// Save the loaded async data to cache.
@@ -393,7 +393,7 @@ void FillOverview(
 		sub->setTextColorOverride(st::windowSubTextFg->c);
 
 		primary->geometryValue(
-		) | rpl::start_with_next([=](const QRect &g) {
+		) | rpl::on_next([=](const QRect &g) {
 			const auto &padding = st::statisticsOverviewSecondValuePadding;
 			second->moveToLeft(
 				rect::right(g) + padding.left(),
@@ -539,7 +539,7 @@ void FillOverview(
 	}
 	container->showChildren();
 	container->sizeValue() | rpl::distinct_until_changed(
-	) | rpl::start_with_next([=](const QSize &s) {
+	) | rpl::on_next([=](const QSize &s) {
 		const auto halfWidth = s.width() / 2;
 		{
 			const auto &p = st::statisticsOverviewValuePadding;
@@ -579,12 +579,12 @@ void FillLoading(
 		: u"stats"_q;
 	auto icon = ::Settings::CreateLottieIcon(
 		content,
-		{ .name = iconName, .sizeOverride = Size(st::changePhoneIconSize) },
+		{ .name = iconName, .sizeOverride = st::normalBoxLottieSize },
 		st::settingsBlockedListIconPadding);
 
 	(
 		std::move(showFinished) | rpl::take(1)
-	) | rpl::start_with_next([animate = std::move(icon.animate)] {
+	) | rpl::on_next([animate = std::move(icon.animate)] {
 		animate(anim::repeat::loop);
 	}, icon.widget->lifetime());
 	content->add(std::move(icon.widget));
@@ -646,10 +646,10 @@ void InnerWidget::load() {
 		_showFinished.events());
 
 	_showFinished.events(
-	) | rpl::take(1) | rpl::start_with_next([=] {
+	) | rpl::take(1) | rpl::on_next([=] {
 		if (!_contextId && !_storyId) {
 			descriptor.api->request(
-			) | rpl::start_with_done([=] {
+			) | rpl::on_done([=] {
 				_state.stats = Data::AnyStatistics{
 					descriptor.api->channelStats(),
 					descriptor.api->supergroupStats(),
@@ -839,7 +839,7 @@ void InnerWidget::fillRecentPosts(not_null<Ui::VerticalLayout*> container) {
 		_messagePreviews.push_back(raw);
 		raw->show();
 		button->sizeValue(
-		) | rpl::start_with_next([=](const QSize &s) {
+		) | rpl::on_next([=](const QSize &s) {
 			if (!s.isNull()) {
 				raw->setGeometry(Rect(s)
 					- st::statisticsRecentPostButton.padding);
