@@ -266,16 +266,16 @@ MainWidget::MainWidget(
 	}
 
 	_history->cancelRequests(
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		handleHistoryBack();
 	}, lifetime());
 
 	Core::App().calls().currentCallValue(
-	) | rpl::start_with_next([=](Calls::Call *call) {
+	) | rpl::on_next([=](Calls::Call *call) {
 		setCurrentCall(call);
 	}, lifetime());
 	Core::App().calls().currentGroupCallValue(
-	) | rpl::start_with_next([=](Calls::GroupCall *call) {
+	) | rpl::on_next([=](Calls::GroupCall *call) {
 		setCurrentGroupCall(call);
 	}, lifetime());
 	if (_callTopBar) {
@@ -286,12 +286,12 @@ MainWidget::MainWidget(
 		floatPlayerDelegate());
 
 	Core::App().floatPlayerClosed(
-	) | rpl::start_with_next([=](FullMsgId itemId) {
+	) | rpl::on_next([=](FullMsgId itemId) {
 		floatPlayerClosed(itemId);
 	}, lifetime());
 
 	Core::App().exportManager().currentView(
-	) | rpl::start_with_next([=](Export::View::PanelController *view) {
+	) | rpl::on_next([=](Export::View::PanelController *view) {
 		setCurrentExportView(view);
 	}, lifetime());
 	if (_exportTopBar) {
@@ -299,12 +299,12 @@ MainWidget::MainWidget(
 	}
 
 	Media::Player::instance()->closePlayerRequests(
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		closeBothPlayers();
 	}, lifetime());
 
 	Media::Player::instance()->updatedNotifier(
-	) | rpl::start_with_next([=](const Media::Player::TrackState &state) {
+	) | rpl::on_next([=](const Media::Player::TrackState &state) {
 		handleAudioUpdate(state);
 	}, lifetime());
 	handleAudioUpdate(Media::Player::instance()->getState(AudioMsgId::Type::Song));
@@ -314,7 +314,7 @@ MainWidget::MainWidget(
 	}
 
 	_controller->chatsForceDisplayWideChanges(
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		crl::on_main(this, [=] {
 			updateDialogsWidthAnimated();
 		});
@@ -331,13 +331,13 @@ MainWidget::MainWidget(
 		Core::App().settings().dialogsNoChatWidthRatioChanges(
 		) | filter(false) | rpl::to_empty,
 		Core::App().settings().thirdColumnWidthChanges() | rpl::to_empty
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		updateControlsGeometry();
 	}, lifetime());
 
 	session().changes().historyUpdates(
 		Data::HistoryUpdate::Flag::MessageSent
-	) | rpl::start_with_next([=](const Data::HistoryUpdate &update) {
+	) | rpl::on_next([=](const Data::HistoryUpdate &update) {
 		const auto history = update.history;
 		history->forgetScrollState();
 		if (const auto from = history->peer->migrateFrom()) {
@@ -350,7 +350,7 @@ MainWidget::MainWidget(
 
 	session().changes().entryUpdates(
 		Data::EntryUpdate::Flag::LocalDraftSet
-	) | rpl::start_with_next([=](const Data::EntryUpdate &update) {
+	) | rpl::on_next([=](const Data::EntryUpdate &update) {
 		auto params = Window::SectionShow();
 		params.reapplyLocalDraft = true;
 		controller->showThread(
@@ -381,14 +381,14 @@ MainWidget::MainWidget(
 			return std::make_tuple(key, can);
 		});
 	}) | rpl::flatten_latest(
-	) | rpl::start_with_next([this](Dialogs::Key key, bool canWrite) {
+	) | rpl::on_next([this](Dialogs::Key key, bool canWrite) {
 		updateThirdColumnToCurrentChat(key, canWrite);
 	}, lifetime());
 
 	QCoreApplication::instance()->installEventFilter(this);
 
 	Media::Player::instance()->tracksFinished(
-	) | rpl::start_with_next([=](AudioMsgId::Type type) {
+	) | rpl::on_next([=](AudioMsgId::Type type) {
 		if (type == AudioMsgId::Type::Voice) {
 			const auto songState = Media::Player::instance()->getState(
 				AudioMsgId::Type::Song);
@@ -405,7 +405,7 @@ MainWidget::MainWidget(
 	}, lifetime());
 
 	_controller->adaptive().changes(
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		handleAdaptiveLayoutUpdate();
 	}, lifetime());
 
@@ -446,7 +446,7 @@ void MainWidget::setupConnectingWidget() {
 		&session().account(),
 		_controller->adaptive().oneColumnValue() | rpl::map(!_1));
 	_controller->connectingBottomSkipValue(
-	) | rpl::start_with_next([=](int skip) {
+	) | rpl::on_next([=](int skip) {
 		_connecting->setBottomSkip(skip);
 	}, lifetime());
 }
@@ -606,7 +606,7 @@ bool MainWidget::shareUrl(
 			.topicRootId = topicRootId,
 			.monoforumPeerId = monoforumPeerId,
 		},
-		SuggestPostOptions(),
+		SuggestOptions(),
 		cursor,
 		Data::WebPageDraft()));
 	history->clearLocalEditDraft(topicRootId, monoforumPeerId);
@@ -721,7 +721,7 @@ void MainWidget::hiderLayer(base::unique_qptr<Window::HistoryHider> hider) {
 	_hider->setParent(this);
 
 	_hider->hidden(
-	) | rpl::start_with_next([=, instance = _hider.get()] {
+	) | rpl::on_next([=, instance = _hider.get()] {
 		clearHider(instance);
 		instance->hide();
 		instance->deleteLater();
@@ -874,7 +874,7 @@ void MainWidget::createPlayer() {
 		rpl::merge(
 			_player->heightValue() | rpl::map_to(true),
 			_player->shownValue()
-		) | rpl::start_with_next(
+		) | rpl::on_next(
 			[this] { playerHeightUpdated(); },
 			_player->lifetime());
 		_player->entity()->setCloseCallback([=] {
@@ -893,7 +893,7 @@ void MainWidget::createPlayer() {
 		});
 
 		_player->entity()->togglePlaylistRequests(
-		) | rpl::start_with_next([=](bool shown) {
+		) | rpl::on_next([=](bool shown) {
 			if (!shown) {
 				_playerPlaylist->hideFromOther();
 				return;
@@ -953,7 +953,7 @@ void MainWidget::setCurrentCall(Calls::Call *call) {
 	if (call) {
 		_callTopBar.destroy();
 		call->stateValue(
-		) | rpl::start_with_next([=](Calls::Call::State state) {
+		) | rpl::on_next([=](Calls::Call::State state) {
 			using State = Calls::Call::State;
 			if (state != State::Established) {
 				destroyCallTopBar();
@@ -975,7 +975,7 @@ void MainWidget::setCurrentGroupCall(Calls::GroupCall *call) {
 	if (call) {
 		_callTopBar.destroy();
 		_currentGroupCall->stateValue(
-		) | rpl::start_with_next([=](Calls::GroupCall::State state) {
+		) | rpl::on_next([=](Calls::GroupCall::State state) {
 			using State = Calls::GroupCall::State;
 			if (state != State::Creating
 				&& state != State::Waiting
@@ -1005,7 +1005,7 @@ void MainWidget::createCallTopBar(
 			: object_ptr<Calls::TopBar>(this, group, show)));
 	_callTopBar->entity()->initBlobsUnder(this, _callTopBar->geometryValue());
 	_callTopBar->heightValue(
-	) | rpl::start_with_next([this](int value) {
+	) | rpl::on_next([this](int value) {
 		callTopBarHeightUpdated(value);
 	}, lifetime());
 	orderWidgets();
@@ -1041,7 +1041,7 @@ void MainWidget::setCurrentExportView(Export::View::PanelController *view) {
 	_currentExportView = view;
 	if (_currentExportView) {
 		_currentExportView->progressState(
-		) | rpl::start_with_next([=](Export::View::Content &&data) {
+		) | rpl::on_next([=](Export::View::Content &&data) {
 			if (!data.rows.empty()
 				&& data.rows[0].id == Export::View::Content::kDoneId) {
 				LOG(("Export Info: Destroy top bar by Done."));
@@ -1067,7 +1067,7 @@ void MainWidget::createExportTopBar(Export::View::Content &&data) {
 		object_ptr<Export::View::TopBar>(this, std::move(data)),
 		_controller->adaptive().oneColumnValue());
 	_exportTopBar->entity()->clicks(
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		if (_currentExportView) {
 			_currentExportView->activatePanel();
 		}
@@ -1085,7 +1085,7 @@ void MainWidget::createExportTopBar(Export::View::Content &&data) {
 	rpl::merge(
 		_exportTopBar->heightValue() | rpl::map_to(true),
 		_exportTopBar->shownValue()
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		exportTopBarHeightUpdated();
 	}, _exportTopBar->lifetime());
 }
@@ -1636,7 +1636,7 @@ bool MainWidget::saveSectionInStack(
 	const auto raw = _stack.back().get();
 	raw->setThirdSectionWeak(_thirdSection.data());
 	raw->removeRequests(
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		for (auto i = begin(_stack); i != end(_stack); ++i) {
 			if (i->get() == raw) {
 				_stack.erase(i);
@@ -1858,7 +1858,7 @@ void MainWidget::showNewSection(
 	if (newThirdSection) {
 		_thirdSection = std::move(newThirdSection);
 		_thirdSection->removeRequests(
-		) | rpl::start_with_next([=] {
+		) | rpl::on_next([=] {
 			destroyThirdSection();
 			_thirdShadow.destroy();
 			updateControlsGeometry();
