@@ -17,6 +17,8 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 #include "lang/lang_keys.h"
 #include "ui/controls/userpic_button.h"
 #include "ui/layers/box_content.h"
+#include "ui/text/custom_emoji_helper.h"
+#include "ui/text/custom_emoji_text_badge.h"
 #include "ui/text/format_values.h"
 #include "ui/text/text_utilities.h"
 #include "ui/widgets/buttons.h"
@@ -27,6 +29,7 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 #include "ui/painter.h"
 #include "ui/rp_widget.h"
 #include "ui/ui_utility.h"
+#include "styles/style_calls.h"
 #include "styles/style_media_view.h"
 
 #include <QtGui/QGuiApplication>
@@ -296,8 +299,9 @@ Header::Header(not_null<Controller*> controller)
 
 Header::~Header() = default;
 
-void Header::show(HeaderData data) {
+void Header::show(HeaderData data, rpl::producer<int> videoStreamViewers) {
 	if (_data == data) {
+		setVideoStreamViewers(std::move(videoStreamViewers));
 		return;
 	}
 	const auto peerChanged = !_data || (_data->peer != data.peer);
@@ -360,13 +364,13 @@ void Header::show(HeaderData data) {
 		rpl::combine(
 			_name->widthValue(),
 			raw->heightValue()
-		) | rpl::start_with_next(updateInfoGeometry, _name->lifetime());
+		) | rpl::on_next(updateInfoGeometry, _name->lifetime());
 
 		raw->show();
 		_widget = std::move(widget);
 
 		_controller->layoutValue(
-		) | rpl::start_with_next([=](const Layout &layout) {
+		) | rpl::on_next([=](const Layout &layout) {
 			raw->setGeometry(layout.header);
 			_contentGeometry = layout.content;
 			updateTooltipGeometry();
@@ -378,12 +382,12 @@ void Header::show(HeaderData data) {
 		std::move(timestamp.text),
 		st::storiesHeaderDate);
 	_date->setAttribute(Qt::WA_TransparentForMouseEvents);
-	_date->setOpacity(kDateOpacity);
 	_date->show();
 	_date->move(st::storiesHeaderDatePosition);
+	setVideoStreamViewers(std::move(videoStreamViewers));
 
 	_date->widthValue(
-	) | rpl::start_with_next(updateInfoGeometry, _date->lifetime());
+	) | rpl::on_next(updateInfoGeometry, _date->lifetime());
 
 	if (!data.fromPeer && data.repostFrom.isEmpty()) {
 		_repost = nullptr;
@@ -409,7 +413,7 @@ void Header::show(HeaderData data) {
 		}
 		_repost->show();
 		_repost->widthValue(
-		) | rpl::start_with_next(updateInfoGeometry, _repost->lifetime());
+		) | rpl::on_next(updateInfoGeometry, _repost->lifetime());
 	}
 
 	auto counter = ComposeCounter(data);
@@ -444,26 +448,32 @@ void Header::show(HeaderData data) {
 				&& _privacyBadgeGeometry.contains(
 					static_cast<QMouseEvent*>(e.get())->pos());
 			return (_privacyBadgeOver != over);
-		}) | rpl::start_with_next([=] {
+		}) | rpl::on_next([=] {
 			_privacyBadgeOver = !_privacyBadgeOver;
 			toggleTooltip(Tooltip::Privacy, _privacyBadgeOver);
 		}, _privacy->lifetime());
 	}
 
-	if (data.video) {
-		createPlayPause();
+	if (data.video || data.videoStream) {
+		if (data.video) {
+			createPlayPause();
+		}
 		createVolumeToggle();
 
-		_widget->widthValue() | rpl::start_with_next([=](int width) {
-			const auto playPause = st::storiesPlayButtonPosition;
-			_playPause->moveToRight(playPause.x(), playPause.y(), width);
+		_widget->widthValue() | rpl::on_next([=](int width) {
+			if (_playPause) {
+				const auto playPause = st::storiesPlayButtonPosition;
+				_playPause->moveToRight(playPause.x(), playPause.y(), width);
+			}
 			const auto volume = st::storiesVolumeButtonPosition;
 			_volumeToggle->moveToRight(volume.x(), volume.y(), width);
 			updateTooltipGeometry();
-		}, _playPause->lifetime());
+		}, _volumeToggle->lifetime());
 
-		_pauseState = _controller->pauseState();
-		applyPauseState();
+		if (data.video) {
+			_pauseState = _controller->pauseState();
+			applyPauseState();
+		}
 	} else {
 		_playPause = nullptr;
 		_volumeToggle = nullptr;
@@ -474,7 +484,7 @@ void Header::show(HeaderData data) {
 		_widget->widthValue(),
 		_counter ? _counter->widthValue() : rpl::single(0),
 		_dateUpdated.events_starting_with_copy(rpl::empty)
-	) | rpl::start_with_next([=](int outer, int counter, auto) {
+	) | rpl::on_next([=](int outer, int counter, auto) {
 		const auto right = _playPause
 			? _playPause->x()
 			: (outer - st::storiesHeaderMargin.right());
@@ -527,6 +537,37 @@ void Header::show(HeaderData data) {
 	}
 }
 
+void Header::setVideoStreamViewers(rpl::producer<int> viewers) {
+	_videoStreamViewersLifetime.destroy();
+	if (!_date) {
+		return;
+	} else if (!viewers) {
+		_date->setOpacity(kDateOpacity);
+		return;
+	}
+	_date->setOpacity(1.);
+	auto helper = Ui::Text::CustomEmojiHelper();
+	const auto badge = helper.paletteDependent(
+		Ui::Text::CustomEmojiTextBadge(
+			tr::lng_video_stream_live(tr::now),
+			st::groupCallMessageBadge,
+			st::groupCallMessageBadgeMargin));
+	const auto context = helper.context();
+	_videoStreamViewersLifetime = std::move(
+		viewers
+	) | rpl::on_next([=](int count) {
+		auto text = badge;
+		if (count) {
+			text.append(' ').append(tr::lng_group_call_rtmp_viewers(
+				tr::now,
+				lt_count_decimal,
+				count));
+		}
+		_date->setMarkedText(text, context);
+		_dateUpdated.fire({});
+	});
+}
+
 void Header::createPlayPause() {
 	struct PlayPauseState {
 		Ui::Animations::Simple overAnimation;
@@ -538,7 +579,7 @@ void Header::createPlayPause() {
 	const auto state = lifetime.make_state<PlayPauseState>();
 
 	_playPause->events(
-	) | rpl::start_with_next([=](not_null<QEvent*> e) {
+	) | rpl::on_next([=](not_null<QEvent*> e) {
 		const auto type = e->type();
 		if (type == QEvent::Enter || type == QEvent::Leave) {
 			const auto over = (e->type() == QEvent::Enter);
@@ -562,7 +603,7 @@ void Header::createPlayPause() {
 		}
 	}, lifetime);
 
-	_playPause->paintRequest() | rpl::start_with_next([=] {
+	_playPause->paintRequest() | rpl::on_next([=] {
 		auto p = QPainter(_playPause.get());
 		const auto paused = (_pauseState == PauseState::Paused)
 			|| (_pauseState == PauseState::InactivePaused);
@@ -596,7 +637,11 @@ void Header::createVolumeToggle() {
 		bool dropdownOver = false;
 	};
 	_volumeToggle = std::make_unique<Ui::RpWidget>(_widget.get());
-	auto &lifetime = _volumeToggle->lifetime();
+	_volume = std::make_unique<Ui::FadeWrap<Ui::RpWidget>>(
+		_widget->parentWidget(),
+		object_ptr<Ui::RpWidget>(_widget->parentWidget()));
+
+	auto &lifetime = _volume->lifetime();
 	const auto state = lifetime.make_state<VolumeState>();
 	state->silent = _data->silent;
 	state->hideTimer.setCallback([=] {
@@ -604,7 +649,7 @@ void Header::createVolumeToggle() {
 	});
 
 	_volumeToggle->events(
-	) | rpl::start_with_next([=](not_null<QEvent*> e) {
+	) | rpl::on_next([=](not_null<QEvent*> e) {
 		const auto type = e->type();
 		if (type == QEvent::Enter || type == QEvent::Leave) {
 			const auto over = (e->type() == QEvent::Enter);
@@ -622,7 +667,7 @@ void Header::createVolumeToggle() {
 		}
 	}, lifetime);
 
-	_volumeToggle->paintRequest() | rpl::start_with_next([=] {
+	_volumeToggle->paintRequest() | rpl::on_next([=] {
 		auto p = QPainter(_volumeToggle.get());
 		p.setOpacity(state->silent
 			? kControlOpacityDisabled
@@ -634,12 +679,9 @@ void Header::createVolumeToggle() {
 	}, lifetime);
 	updateVolumeIcon();
 
-	_volume = std::make_unique<Ui::FadeWrap<Ui::RpWidget>>(
-		_widget->parentWidget(),
-		object_ptr<Ui::RpWidget>(_widget->parentWidget()));
 	_volume->toggle(false, anim::type::instant);
 	_volume->events(
-	) | rpl::start_with_next([=](not_null<QEvent*> e) {
+	) | rpl::on_next([=](not_null<QEvent*> e) {
 		const auto type = e->type();
 		if (type == QEvent::Enter || type == QEvent::Leave) {
 			const auto over = (e->type() == QEvent::Enter);
@@ -660,7 +702,7 @@ void Header::createVolumeToggle() {
 		_widget->positionValue(),
 		_volumeToggle->positionValue(),
 		rpl::mappers::_1 + rpl::mappers::_2
-	) | rpl::start_with_next([=](QPoint position) {
+	) | rpl::on_next([=](QPoint position) {
 		_volume->move(position);
 	}, _volume->lifetime());
 
@@ -809,7 +851,7 @@ void Header::rebuildVolumeControls(
 		dropdown.get(),
 		st::storiesVolumeButton);
 	_volumeIcon.value(
-	) | rpl::start_with_next([=](const style::icon *icon) {
+	) | rpl::on_next([=](const style::icon *icon) {
 		button->setIconOverride(icon, icon);
 	}, button->lifetime());
 
@@ -860,7 +902,7 @@ void Header::rebuildVolumeControls(
 	}
 
 	dropdown->paintRequest(
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		auto p = QPainter(dropdown);
 		auto hq = PainterHighQualityEnabler(p);
 		const auto radius = button->width() / 2.;
@@ -916,7 +958,7 @@ rpl::producer<bool> Header::tooltipShownValue() const {
 }
 
 void Header::updateDateText() {
-	if (!_date || !_data || !_data->date) {
+	if (!_date || !_data || !_data->date || _videoStreamViewersLifetime) {
 		return;
 	}
 	auto timestamp = ComposeDetails(*_data, base::unixtime::now());
