@@ -12,6 +12,7 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 #include "base/unixtime.h"
 #include "boxes/abstract_box.h"
 #include "boxes/premium_preview_box.h"
+#include "calls/group/calls_group_stars_box.h"
 #include "chat_helpers/compose/compose_show.h"
 #include "chat_helpers/stickers_emoji_pack.h"
 #include "core/shortcuts.h"
@@ -405,7 +406,7 @@ void EffectPreview::setupBackground() {
 		QImage::Format_ARGB32_Premultiplied);
 	_bg.setDevicePixelRatio(ratio);
 	repaintBackground();
-	_theme->repaintBackgroundRequests() | rpl::start_with_next([=] {
+	_theme->repaintBackgroundRequests() | rpl::on_next([=] {
 		repaintBackground();
 		update();
 	}, lifetime());
@@ -484,7 +485,7 @@ void EffectPreview::setupLottie() {
 	}
 	rpl::single(rpl::empty) | rpl::then(
 		_show->session().downloaderTaskFinished()
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		if (checkLoaded()) {
 			_readyCheckLifetime.destroy();
 			createLottie();
@@ -500,7 +501,7 @@ void EffectPreview::createLottie() {
 		Stickers::EffectType::MessageEffect);
 	const auto raw = _lottie.get();
 	raw->updates(
-	) | rpl::start_with_next([=](Lottie::Update update) {
+	) | rpl::on_next([=](Lottie::Update update) {
 		v::match(update.data, [&](const Lottie::Information &information) {
 		}, [&](const Lottie::DisplayFrameRequest &request) {
 			this->update();
@@ -589,7 +590,7 @@ void EffectPreview::toggle(bool shown) {
 Fn<void(Action, Details)> DefaultCallback(
 		std::shared_ptr<ChatHelpers::Show> show,
 		Fn<void(Api::SendOptions)> send) {
-	const auto guard = Ui::MakeWeak(show->toastParent());
+	const auto guard = base::make_weak(show->toastParent());
 	return [=](Action action, Details details) {
 		if (action.type == ActionType::Send) {
 			send(action.options);
@@ -601,9 +602,9 @@ Fn<void(Action, Details)> DefaultCallback(
 			details,
 			send,
 			action.options);
-		const auto weak = Ui::MakeWeak(box.data());
+		const auto weak = base::make_weak(box.data());
 		show->showBox(std::move(box));
-		if (const auto strong = weak.data()) {
+		if (const auto strong = weak.get()) {
 			strong->setCloseByOutsideClick(false);
 		}
 	};
@@ -618,9 +619,9 @@ FillMenuResult AttachSendMenuEffect(
 	Expects(show != nullptr);
 
 	using namespace HistoryView::Reactions;
-	const auto effect = std::make_shared<QPointer<EffectPreview>>();
+	const auto effect = std::make_shared<base::weak_qptr<EffectPreview>>();
 	const auto position = desiredPositionOverride.value_or(QCursor::pos());
-	const auto selector = (show && details.effectAllowed)
+	const auto selector = details.effectAllowed
 		? AttachSelectorToMenu(
 			menu,
 			position,
@@ -640,18 +641,18 @@ FillMenuResult AttachSendMenuEffect(
 	}
 
 	(*selector)->chosen(
-	) | rpl::start_with_next([=](ChosenReaction chosen) {
+	) | rpl::on_next([=](ChosenReaction chosen) {
 		const auto &reactions = show->session().data().reactions();
 		const auto &effects = reactions.list(Data::Reactions::Type::Effects);
 		const auto i = ranges::find(effects, chosen.id, &Data::Reaction::id);
 		if (i != end(effects)) {
-			if (const auto strong = effect->data()) {
+			if (const auto strong = effect->get()) {
 				strong->hideAnimated();
 			}
-			const auto weak = Ui::MakeWeak(menu);
+			const auto weak = base::make_weak(menu);
 			const auto done = [=] {
-				delete effect->data();
-				if (const auto strong = weak.data()) {
+				delete effect->get();
+				if (const auto strong = weak.get()) {
 					strong->hideMenu(true);
 				}
 			};
@@ -670,9 +671,47 @@ FillMenuResult AttachSendMenuEffect(
 	return FillMenuResult::Prepared;
 }
 
+FillMenuResult FillEditCommentPriceMenu(
+		not_null<Ui::PopupMenu*> menu,
+		std::shared_ptr<ChatHelpers::Show> show,
+		Details details,
+		Fn<void(Action, Details)> action,
+		const style::ComposeIcons *iconsOverride,
+		std::optional<QPoint> desiredPositionOverride) {
+	Expects(show != nullptr);
+
+	const auto &icons = iconsOverride
+		? *iconsOverride
+		: st::defaultComposeIcons;
+	menu->addAction(tr::lng_video_stream_edit_stars(tr::now), [=] {
+		show->show(Calls::Group::MakeVideoStreamStarsBox({
+			.show = show,
+			.min = int(details.commentPriceMin.value_or(1)),
+			.current = int(details.price.value_or(1)),
+			.save = [=](int count) {
+				auto copy = details;
+				copy.price = count;
+				action({ {}, Action::Type::ChangePrice }, copy);
+			},
+			.name = details.commentStreamerName,
+			//.preview = details.commentPreview,
+		}));
+	}, &icons.menuEditStars);
+	if (details.price.value_or(0) > details.commentPriceMin.value_or(0)) {
+		auto copy = details;
+		copy.price = details.commentPriceMin.value_or(0);
+		menu->addAction(tr::lng_video_stream_remove_stars(tr::now), [=] {
+			action({ {}, Action::Type::ChangePrice }, copy);
+		}, &icons.menuGifRemove);
+	}
+	const auto position = desiredPositionOverride.value_or(QCursor::pos());
+	menu->prepareGeometryFor(position);
+	return FillMenuResult::Prepared;
+}
+
 FillMenuResult FillSendMenu(
 		not_null<Ui::PopupMenu*> menu,
-		std::shared_ptr<ChatHelpers::Show> showForEffect,
+		std::shared_ptr<ChatHelpers::Show> maybeShow,
 		Details details,
 		Fn<void(Action, Details)> action,
 		const style::ComposeIcons *iconsOverride,
@@ -685,6 +724,14 @@ FillMenuResult FillSendMenu(
 		&& !details.price.has_value();
 	if (empty || !action) {
 		return FillMenuResult::Skipped;
+	} else if (type == Type::EditCommentPrice) {
+		return FillEditCommentPriceMenu(
+			menu,
+			maybeShow,
+			details,
+			action,
+			iconsOverride,
+			desiredPositionOverride);
 	}
 	const auto &icons = iconsOverride
 		? *iconsOverride
@@ -698,7 +745,7 @@ FillMenuResult FillSendMenu(
 	}
 	if (sending && type != Type::SilentOnly) {
 		menu->addAction(
-			(type == Type::Reminder
+			((type == Type::Reminder)
 				? tr::lng_reminder_message(tr::now)
 				: tr::lng_schedule_message(tr::now)),
 			[=] { action({ .type = ActionType::Schedule }, details); },
@@ -752,10 +799,10 @@ FillMenuResult FillSendMenu(
 			&icons.menuPrice);
 	}
 
-	if (showForEffect) {
+	if (maybeShow) {
 		return AttachSendMenuEffect(
 			menu,
-			showForEffect,
+			maybeShow,
 			details,
 			action,
 			desiredPositionOverride);
@@ -767,15 +814,22 @@ FillMenuResult FillSendMenu(
 
 void SetupMenuAndShortcuts(
 		not_null<Ui::RpWidget*> button,
-		std::shared_ptr<ChatHelpers::Show> show,
+		std::shared_ptr<ChatHelpers::Show> maybeShow,
 		Fn<Details()> details,
-		Fn<void(Action, Details)> action) {
+		Fn<void(Action, Details)> action,
+		const style::PopupMenu *stOverride,
+		const style::ComposeIcons *iconsOverride) {
 	const auto menu = std::make_shared<base::unique_qptr<Ui::PopupMenu>>();
 	const auto showMenu = [=] {
 		*menu = base::make_unique_q<Ui::PopupMenu>(
 			button,
-			st::popupMenuWithIcons);
-		const auto result = FillSendMenu(*menu, show, details(), action);
+			stOverride ? *stOverride : st::popupMenuWithIcons);
+		const auto result = FillSendMenu(
+			*menu,
+			maybeShow,
+			details(),
+			action,
+			iconsOverride);
 		if (result != FillMenuResult::Prepared) {
 			return false;
 		}
@@ -792,7 +846,7 @@ void SetupMenuAndShortcuts(
 	Shortcuts::Requests(
 	) | rpl::filter([=] {
 		return button->isActiveWindow();
-	}) | rpl::start_with_next([=](not_null<Shortcuts::Request*> request) {
+	}) | rpl::on_next([=](not_null<Shortcuts::Request*> request) {
 		using Command = Shortcuts::Command;
 
 		const auto now = details().type;
