@@ -236,7 +236,7 @@ void FilterRowButton::setup(
 	updateData(filter, true);
 	setState(_state, true);
 
-	sizeValue() | rpl::start_with_next([=](QSize size) {
+	sizeValue() | rpl::on_next([=](QSize size) {
 		const auto right = st::contactsPadding.right()
 			+ st::contactsCheckPosition.x();
 		const auto width = size.width();
@@ -463,11 +463,11 @@ void FilterRowButton::paintEvent(QPaintEvent *e) {
 		const auto button = wrap->add(
 			object_ptr<FilterRowButton>(wrap, session, filter));
 		button->removeRequests(
-		) | rpl::start_with_next([=] {
+		) | rpl::on_next([=] {
 			remove(button);
 		}, button->lifetime());
 		button->restoreRequests(
-		) | rpl::start_with_next([=] {
+		) | rpl::on_next([=] {
 			if (showLimitReached()) {
 				return;
 			}
@@ -503,7 +503,7 @@ void FilterRowButton::paintEvent(QPaintEvent *e) {
 		const auto id = filter.id();
 		if (ranges::contains(filters->list(), id, &Data::ChatFilter::id)) {
 			filters->chatsList(id)->fullSize().changes(
-			) | rpl::start_with_next([=] {
+			) | rpl::on_next([=] {
 				const auto found = find(button);
 				if (found->postponedCountUpdate) {
 					return;
@@ -543,7 +543,7 @@ void FilterRowButton::paintEvent(QPaintEvent *e) {
 	}
 
 	session->data().chatsFilters().isChatlistChanged(
-	) | rpl::start_with_next([=](FilterId id) {
+	) | rpl::on_next([=](FilterId id) {
 		const auto filters = &session->data().chatsFilters();
 		const auto &list = filters->list();
 		const auto i = ranges::find(list, id, &Data::ChatFilter::id);
@@ -605,7 +605,7 @@ void FilterRowButton::paintEvent(QPaintEvent *e) {
 		}
 	};
 	tagsButtonEnabled->events() | rpl::distinct_until_changed(
-	) | rpl::start_with_next([=](bool value) {
+	) | rpl::on_next([=](bool value) {
 		state->tagsEnabledAnimation.stop();
 		state->tagsEnabledAnimation.start(
 			setTagsProgress,
@@ -623,7 +623,7 @@ void FilterRowButton::paintEvent(QPaintEvent *e) {
 		return !list.empty();
 	}) | rpl::take(
 		1
-	) | rpl::start_with_next([=](
+	) | rpl::on_next([=](
 			const std::vector<Data::SuggestedFilter> &suggestions) {
 		for (const auto &suggestion : suggestions) {
 			const auto &filter = suggestion.filter;
@@ -637,7 +637,7 @@ void FilterRowButton::paintEvent(QPaintEvent *e) {
 				filter,
 				suggestion.description));
 			button->addRequests(
-				) | rpl::start_with_next([=] {
+				) | rpl::on_next([=] {
 				if (showLimitReached()) {
 					return;
 				}
@@ -856,22 +856,21 @@ void SetupTopContent(
 		st::settingsFilterIconPadding);
 	std::move(
 		showFinished
-	) | rpl::start_with_next([animate = std::move(icon.animate)] {
+	) | rpl::on_next([animate = std::move(icon.animate)] {
 		animate(anim::repeat::once);
 	}, verticalLayout->lifetime());
 	verticalLayout->add(std::move(icon.widget));
 
 	verticalLayout->add(
-		object_ptr<Ui::CenterWrap<>>(
+		object_ptr<Ui::FlatLabel>(
 			verticalLayout,
-			object_ptr<Ui::FlatLabel>(
-				verticalLayout,
-				tr::lng_filters_about(),
-				st::settingsFilterDividerLabel)),
-		st::settingsFilterDividerLabelPadding);
+			tr::lng_filters_about(),
+			st::settingsFilterDividerLabel),
+		st::settingsFilterDividerLabelPadding,
+		style::al_top)->setTryMakeSimilarLines(true);
 
 	verticalLayout->geometryValue(
-	) | rpl::start_with_next([=](const QRect &r) {
+	) | rpl::on_next([=](const QRect &r) {
 		divider->setGeometry(r);
 	}, divider->lifetime());
 
@@ -905,7 +904,7 @@ void SetupTagContent(
 			rpl::duplicate(premium),
 			rpl::mappers::_1 && rpl::mappers::_2),
 		state->tagsTurnOff.events()));
-	rpl::duplicate(premium) | rpl::start_with_next([=](bool value) {
+	rpl::duplicate(premium) | rpl::on_next([=](bool value) {
 		tagsButton->setToggleLocked(!value);
 	}, tagsButton->lifetime());
 
@@ -935,7 +934,7 @@ void SetupTagContent(
 			state->requestTimer.cancel();
 		}
 		return proceed;
-	}) | rpl::start_with_next([=](bool v) {
+	}) | rpl::on_next([=](bool v) {
 		state->sendCallback = [=] { send(v); };
 		state->requestTimer.cancel();
 		state->requestTimer.setCallback([=] { send(v); });
