@@ -14,6 +14,7 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 #include "api/api_global_privacy.h"
 #include "api/api_websites.h"
 #include "data/components/passkeys.h"
+#include "platform/platform_webauthn.h"
 #include "settings/cloud_password/settings_cloud_password_email_confirm.h"
 #include "settings/cloud_password/settings_cloud_password_input.h"
 #include "settings/cloud_password/settings_cloud_password_login_email.h"
@@ -106,7 +107,7 @@ void AddPremiumStar(
 	auto star = PremiumStar();
 	badge->resize(star.size() / style::DevicePixelRatio());
 	badge->paintRequest(
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		auto p = QPainter(badge);
 		p.drawImage(0, 0, star);
 	}, badge->lifetime());
@@ -114,7 +115,7 @@ void AddPremiumStar(
 	rpl::combine(
 		button->sizeValue(),
 		std::move(label)
-	) | rpl::start_with_next([=](const QSize &s, const QString &) {
+	) | rpl::on_next([=](const QSize &s, const QString &) {
 		if (s.isNull()) {
 			return;
 		}
@@ -272,7 +273,7 @@ void AddPremiumPrivacyButton(
 		state->widget.paintRequest(
 		) | rpl::filter([=]() -> bool {
 			return state->widget.x();
-		}) | rpl::start_with_next([=] {
+		}) | rpl::on_next([=] {
 			auto p = QPainter(&state->widget);
 			st::settingsPremiumLock.paint(p, 0, 0, state->widget.width());
 		}, state->widget.lifetime());
@@ -282,7 +283,7 @@ void AddPremiumPrivacyButton(
 			std::move(label),
 			PrivacyString(session, key),
 			Data::AmPremiumValue(session)
-		) | rpl::start_with_next([=, &st](
+		) | rpl::on_next([=, &st](
 				const QSize &buttonSize,
 				const QString &button,
 				const QString &text,
@@ -346,7 +347,7 @@ void AddPremiumPrivacyButton(
 			key
 		) | rpl::take(
 			1
-		) | rpl::start_with_next([=](const Privacy::Rule &value) {
+		) | rpl::on_next([=](const Privacy::Rule &value) {
 			controller->show(Box<EditPrivacyBox>(
 				controller,
 				controllerFactory(),
@@ -583,6 +584,10 @@ void SetupPasskeys(
 	if (!session->passkeys().possible()) {
 		return;
 	}
+	const auto wrap = container->add(
+		object_ptr<Ui::SlideWrap<Ui::VerticalLayout>>(
+			container,
+			object_ptr<Ui::VerticalLayout>(container)));
 	auto label = rpl::combine(
 		tr::lng_profile_loading(),
 		(rpl::single(rpl::empty_value())
@@ -597,7 +602,7 @@ void SetupPasskeys(
 			: tr::lng_settings_cloud_password_off(tr::now);
 	});
 	AddButtonWithLabel(
-		container,
+		wrap->entity(),
 		tr::lng_settings_passkeys_title(),
 		std::move(label),
 		st::settingsButton,
@@ -610,7 +615,7 @@ void SetupPasskeys(
 		if (count == 0) {
 			controller->show(Box([=](not_null<Ui::GenericBox*> box) {
 				PasskeysNoneBox(box, session);
-				box->boxClosing() | rpl::start_with_next([=] {
+				box->boxClosing() | rpl::on_next([=] {
 					if (session->passkeys().list().size()) {
 						controller->showSettings(PasskeysId());
 					}
@@ -620,6 +625,13 @@ void SetupPasskeys(
 			controller->showSettings(PasskeysId());
 		}
 	});
+	wrap->toggleOn(
+		(rpl::single(rpl::empty_value())
+			| rpl::then(session->passkeys().requestList())) | rpl::map([=] {
+			return Platform::WebAuthn::IsSupported()
+				|| !session->passkeys().list().empty();
+		}));
+	wrap->finishAnimating();
 }
 
 void SetupLoginEmail(
@@ -696,7 +708,7 @@ void SetupTopPeers(
 	}))->toggledChanges(
 	) | rpl::filter([=](bool enabled) {
 		return enabled == session->topPeers().disabled();
-	}) | rpl::start_with_next([=](bool enabled) {
+	}) | rpl::on_next([=](bool enabled) {
 		session->topPeers().toggleDisabled(!enabled);
 	}, container->lifetime());
 
@@ -715,7 +727,7 @@ void SetupSelfDestruction(
 
 	std::move(
 		updateTrigger
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		session->api().selfDestruct().reload();
 	}, container->lifetime());
 	const auto label = [&] {
@@ -862,7 +874,7 @@ void SetupBlockedList(
 	});
 	std::move(
 		updateTrigger
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		session->api().blockedPeers().reload();
 	}, blockedPeers->lifetime());
 }
@@ -874,7 +886,7 @@ void SetupWebsitesList(
 		Fn<void(Type)> showOther) {
 	std::move(
 		updateTrigger
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		controller->session().api().websites().reload();
 	}, container->lifetime());
 
@@ -912,7 +924,7 @@ void SetupSessionsList(
 		Fn<void(Type)> showOther) {
 	std::move(
 		updateTrigger
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		controller->session().api().authorizations().reload();
 	}, container->lifetime());
 
@@ -958,7 +970,7 @@ void SetupGlobalTTLList(
 	});
 	std::move(
 		updateTrigger
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		session->api().selfDestruct().reload();
 	}, container->lifetime());
 }
@@ -1020,7 +1032,7 @@ void SetupSensitiveContent(
 
 	std::move(
 		updateTrigger
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		session->api().sensitiveContent().reload();
 	}, container->lifetime());
 	inner->add(object_ptr<Button>(
@@ -1033,7 +1045,7 @@ void SetupSensitiveContent(
 	))->toggledChanges(
 	) | rpl::filter([=](bool toggled) {
 		return toggled != session->api().sensitiveContent().enabledCurrent();
-	}) | rpl::start_with_next([=](bool toggled) {
+	}) | rpl::on_next([=](bool toggled) {
 		if (toggled && session->appConfig().ageVerifyNeeded()) {
 			disable->fire({});
 
@@ -1083,12 +1095,12 @@ object_ptr<Ui::BoxContent> EditCloudPasswordBox(not_null<Main::Session*> session
 	rpl::merge(
 		box->newPasswordSet() | rpl::to_empty,
 		box->passwordReloadNeeded()
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		session->api().cloudPassword().reload();
 	}, box->lifetime());
 
 	box->clearUnconfirmedPassword(
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		session->api().cloudPassword().clearUnconfirmedPassword();
 	}, box->lifetime());
 
@@ -1111,12 +1123,12 @@ void RemoveCloudPassword(not_null<Window::SessionController*> controller) {
 	rpl::merge(
 		box->newPasswordSet() | rpl::to_empty,
 		box->passwordReloadNeeded()
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		session->api().cloudPassword().reload();
 	}, box->lifetime());
 
 	box->clearUnconfirmedPassword(
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		session->api().cloudPassword().clearUnconfirmedPassword();
 	}, box->lifetime());
 
@@ -1156,7 +1168,7 @@ not_null<Ui::SettingsButton*> AddPrivacyButton(
 			key
 		) | rpl::take(
 			1
-		) | rpl::start_with_next([=](const Privacy::Rule &value) {
+		) | rpl::on_next([=](const Privacy::Rule &value) {
 			controller->show(Box<EditPrivacyBox>(
 				controller,
 				controllerFactory(),
@@ -1193,7 +1205,7 @@ void SetupArchiveAndMute(
 	)->toggledChanges(
 	) | rpl::filter([=](bool toggled) {
 		return toggled != privacy->archiveAndMuteCurrent();
-	}) | rpl::start_with_next([=](bool toggled) {
+	}) | rpl::on_next([=](bool toggled) {
 		privacy->updateArchiveAndMute(toggled);
 	}, container->lifetime());
 
