@@ -198,7 +198,7 @@ Panel::Button::Button(QWidget *parent, const style::RoundButton &st)
 , _bg(st::windowBgActive->c)
 , _roundRect(st::callRadius, st::windowBgActive) {
 	_textFull.value(
-	) | rpl::start_with_next([=](const QString &text) {
+	) | rpl::on_next([=](const QString &text) {
 		_text.setText(st::semiboldTextStyle, text);
 		update();
 	}, lifetime());
@@ -220,7 +220,7 @@ void Panel::Button::updateBg(QColor bg) {
 void Panel::Button::updateBg(not_null<const style::color*> paletteBg) {
 	updateBg((*paletteBg)->c);
 	_bgLifetime = style::PaletteChanged(
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		updateBg((*paletteBg)->c);
 	});
 }
@@ -234,7 +234,7 @@ void Panel::Button::updateFg(QColor fg) {
 void Panel::Button::updateFg(not_null<const style::color*> paletteFg) {
 	updateFg((*paletteFg)->c);
 	_fgLifetime = style::PaletteChanged(
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		updateFg((*paletteFg)->c);
 	});
 }
@@ -258,7 +258,7 @@ void Panel::Button::toggleProgress(bool shown) {
 			this,
 			[=] { return _progress->widget.rect(); });
 		_progress->widget.paintRequest(
-		) | rpl::start_with_next([=](QRect clip) {
+		) | rpl::on_next([=](QRect clip) {
 			auto p = QPainter(&_progress->widget);
 			p.setOpacity(
 				_progress->shownAnimation.value(_progress->shown ? 1. : 0.));
@@ -303,7 +303,7 @@ void Panel::Button::setupProgressGeometry() {
 	}
 	_progress->geometryLifetime.destroy();
 	sizeValue(
-	) | rpl::start_with_next([=](QSize outer) {
+	) | rpl::on_next([=](QSize outer) {
 		const auto height = outer.height();
 		const auto size = st::paymentsLoading.size;
 		const auto skip = (height - size.height()) / 2;
@@ -385,7 +385,7 @@ Panel::Panel(Args &&args)
 	const auto panel = _widget.get();
 	rpl::duplicate(
 		args.title
-	) | rpl::start_with_next([=](const QString &title) {
+	) | rpl::on_next([=](const QString &title) {
 		const auto value = tr::lng_credits_box_history_entry_miniapp(tr::now)
 			+ u": "_q
 			+ title;
@@ -396,7 +396,7 @@ Panel::Panel(Args &&args)
 	updateColorOverrides(params);
 
 	_fullscreen.value(
-	) | rpl::start_with_next([=](bool fullscreen) {
+	) | rpl::on_next([=](bool fullscreen) {
 		_widget->toggleFullScreen(fullscreen);
 		layoutButtons();
 		sendFullScreen();
@@ -405,12 +405,12 @@ Panel::Panel(Args &&args)
 	}, _widget->lifetime());
 
 	_widget->fullScreenValue(
-	) | rpl::start_with_next([=](bool fullscreen) {
+	) | rpl::on_next([=](bool fullscreen) {
 		_fullscreen = fullscreen;
 	}, _widget->lifetime());
 
 	_widget->closeRequests(
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		if (_closeNeedConfirmation) {
 			scheduleCloseWithConfirmation();
 		} else {
@@ -421,12 +421,12 @@ Panel::Panel(Args &&args)
 	_widget->closeEvents(
 	) | rpl::filter([=] {
 		return !_hiddenForPayment;
-	}) | rpl::start_with_next([=] {
+	}) | rpl::on_next([=] {
 		_delegate->botClose();
 	}, _widget->lifetime());
 
 	_widget->backRequests(
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		postEvent("back_button_pressed");
 	}, _widget->lifetime());
 
@@ -435,7 +435,7 @@ Panel::Panel(Args &&args)
 		_themeUpdateForced.events()
 	) | rpl::filter([=] {
 		return !_themeUpdateScheduled;
-	}) | rpl::start_with_next([=] {
+	}) | rpl::on_next([=] {
 		_themeUpdateScheduled = true;
 		crl::on_main(_widget.get(), [=] {
 			_themeUpdateScheduled = false;
@@ -470,7 +470,7 @@ void Panel::setupDownloadsProgress(
 	widget->show();
 	widget->setAttribute(Qt::WA_TransparentForMouseEvents);
 
-	button->sizeValue() | rpl::start_with_next([=](QSize size) {
+	button->sizeValue() | rpl::on_next([=](QSize size) {
 		widget->setGeometry(QRect(QPoint(), size));
 	}, widget->lifetime());
 
@@ -496,7 +496,7 @@ void Panel::setupDownloadsProgress(
 	const auto state = widget->lifetime().make_state<State>(widget);
 	std::move(
 		progress
-	) | rpl::start_with_next([=](DownloadsProgress progress) {
+	) | rpl::on_next([=](DownloadsProgress progress) {
 		const auto toggle = [&](bool shown) {
 			if (state->shown == shown) {
 				return;
@@ -530,7 +530,7 @@ void Panel::setupDownloadsProgress(
 		state->progress = progress;
 	}, widget->lifetime());
 
-	widget->paintRequest() | rpl::start_with_next([=] {
+	widget->paintRequest() | rpl::on_next([=] {
 		const auto opacity = std::clamp(
 			state->fade.value(state->shown ? 2. : 0.) - 1.,
 			0.,
@@ -579,7 +579,7 @@ void Panel::toggleProgress(bool shown) {
 			_widget.get(),
 			[=] { return progressRect(); });
 		_progress->widget.paintRequest(
-		) | rpl::start_with_next([=](QRect clip) {
+		) | rpl::on_next([=](QRect clip) {
 			auto p = QPainter(&_progress->widget);
 			p.setOpacity(
 				_progress->shownAnimation.value(_progress->shown ? 1. : 0.));
@@ -646,7 +646,7 @@ void Panel::setupProgressGeometry() {
 	_progress->geometryLifetime.destroy();
 	if (_webviewBottom) {
 		_webviewBottom->geometryValue(
-		) | rpl::start_with_next([=](QRect bottom) {
+		) | rpl::on_next([=](QRect bottom) {
 			const auto height = bottom.height();
 			const auto size = st::paymentsLoading.size;
 			const auto skip = (height - size.height()) / 2;
@@ -699,7 +699,7 @@ bool Panel::showWebview(Args &&args, const Webview::ThemeParams &params) {
 	_webview->window.navigate(url);
 	_widget->setBackAllowed(allowBack);
 
-	rpl::duplicate(args.downloadsProgress) | rpl::start_with_next([=] {
+	rpl::duplicate(args.downloadsProgress) | rpl::on_next([=] {
 		_downloadsUpdated.fire({});
 	}, lifetime());
 
@@ -806,7 +806,7 @@ void Panel::createWebviewBottom() {
 	rpl::combine(
 		_webviewBottom->widthValue(),
 		label->widthValue()
-	) | rpl::start_with_next([=](int outerWidth, int width) {
+	) | rpl::on_next([=](int outerWidth, int width) {
 		label->move((outerWidth - width) / 2, padding.top());
 	}, label->lifetime());
 	label->show();
@@ -817,7 +817,7 @@ void Panel::createWebviewBottom() {
 			return _widget->innerGeometry();
 		}),
 		bottom->heightValue()
-	) | rpl::start_with_next([=](QRect inner, int height) {
+	) | rpl::on_next([=](QRect inner, int height) {
 		bottom->move(inner.x(), inner.y() + inner.height() - height);
 		bottom->resizeToWidth(inner.width());
 		layoutButtons();
@@ -892,7 +892,7 @@ bool Panel::createWebview(const Webview::ThemeParams &params) {
 	rpl::combine(
 		container->geometryValue(),
 		_footerHeight.value()
-	) | rpl::start_with_next([=](QRect geometry, int footer) {
+	) | rpl::on_next([=](QRect geometry, int footer) {
 		if (const auto view = raw->widget()) {
 			view->setGeometry(geometry.marginsRemoved({ 0, 0, 0, footer }));
 			crl::on_main(view, [=] {
@@ -1065,7 +1065,7 @@ postEvent: function(eventType, eventData) {
 			&& !widget->isHidden()
 			&& handle
 			&& (focused == handle);
-	}) | rpl::start_with_next([=] {
+	}) | rpl::on_next([=] {
 		_webview->window.focus();
 	}, _webview->lifetime);
 
@@ -1131,13 +1131,12 @@ void Panel::switchInlineQueryMessage(const QJsonObject &args) {
 	if (args.isEmpty()) {
 		_delegate->botClose();
 		return;
-	}
-	const auto query = args["query"].toString();
-	if (query.isEmpty()) {
-		LOG(("BotWebView Error: Bad 'query' in switchInlineQueryMessage."));
+	} else if (!args.contains("query")) {
+		LOG(("BotWebView Error: No 'query' in switchInlineQueryMessage."));
 		_delegate->botClose();
 		return;
 	}
+	const auto query = args["query"].toString();
 	const auto valid = base::flat_set<QString>{
 		u"users"_q,
 		u"bots"_q,
@@ -1692,7 +1691,7 @@ void Panel::processHeaderColor(const QJsonObject &args) {
 			args["color_key"].toString())) {
 		_widget->overrideTitleColor((*color)->c);
 		_headerColorLifetime = style::PaletteChanged(
-		) | rpl::start_with_next([=] {
+		) | rpl::on_next([=] {
 			_widget->overrideTitleColor((*color)->c);
 		});
 	} else {
@@ -1735,7 +1734,7 @@ void Panel::processBackgroundColor(const QJsonObject &args) {
 			args["color_key"].toString())) {
 		overrideBodyColor((*color)->c);
 		_bodyColorLifetime = style::PaletteChanged(
-		) | rpl::start_with_next([=] {
+		) | rpl::on_next([=] {
 			overrideBodyColor((*color)->c);
 		});
 	} else {
@@ -1761,7 +1760,7 @@ void Panel::processBottomBarColor(const QJsonObject &args) {
 		_widget->overrideBottomBarColor((*color)->c);
 		_bottomBarColor = (*color)->c;
 		_bottomBarColorLifetime = style::PaletteChanged(
-		) | rpl::start_with_next([=] {
+		) | rpl::on_next([=] {
 			_widget->overrideBottomBarColor((*color)->c);
 			_bottomBarColor = (*color)->c;
 		});
@@ -1808,7 +1807,7 @@ void Panel::createButton(std::unique_ptr<Button> &button) {
 		_bottomButtonsBg = std::make_unique<RpWidget>(_widget.get());
 
 		const auto raw = _bottomButtonsBg.get();
-		raw->paintRequest() | rpl::start_with_next([=] {
+		raw->paintRequest() | rpl::on_next([=] {
 			auto p = QPainter(raw);
 			auto hq = PainterHighQualityEnabler(p);
 			p.setPen(Qt::NoPen);
@@ -1838,7 +1837,7 @@ void Panel::createButton(std::unique_ptr<Button> &button) {
 	rpl::combine(
 		raw->shownValue(),
 		raw->heightValue()
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		layoutButtons();
 	}, raw->lifetime());
 }
@@ -1949,7 +1948,7 @@ void Panel::showBox(
 		raw->boxClosing(
 		) | rpl::filter([=] {
 			return _webview != nullptr;
-		}) | rpl::start_with_next([=] {
+		}) | rpl::on_next([=] {
 			auto &list = _webview->boxes;
 			list.erase(ranges::remove_if(list, [&](QPointer<RpWidget> b) {
 				return !b || (b == raw);
@@ -2035,7 +2034,7 @@ void Panel::showCriticalError(const TextWithEntities &text) {
 		return false;
 	});
 
-	raw->widthValue() | rpl::start_with_next([=](int width) {
+	raw->widthValue() | rpl::on_next([=](int width) {
 		error->resizeToWidth(width);
 		raw->resize(width, error->height());
 	}, raw->lifetime());
@@ -2125,10 +2124,6 @@ TextWithEntities ErrorText(const Webview::Available &info) {
 			Ui::Text::WithEntities);
 	case Error::NoWebKitGTK:
 		return { tr::lng_payments_webview_install_webkit(tr::now) };
-	case Error::NoOpenGL:
-		return { tr::lng_payments_webview_enable_opengl(tr::now) };
-	case Error::NonX11:
-		return { tr::lng_payments_webview_switch_x11(tr::now) };
 	case Error::OldWindows:
 		return { tr::lng_payments_webview_update_windows(tr::now) };
 	default:
