@@ -7,16 +7,25 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 */
 #include "ui/chat/choose_theme_controller.h"
 
+#include "boxes/background_box.h"
+#include "boxes/transfer_gift_box.h"
+#include "ui/dynamic_image.h"
+#include "ui/dynamic_thumbnails.h"
 #include "ui/rp_widget.h"
+#include "ui/boxes/confirm_box.h"
+#include "ui/chat/chat_theme.h"
+#include "ui/chat/message_bubble.h"
+#include "ui/layers/generic_box.h"
+#include "ui/text/text_utilities.h"
 #include "ui/widgets/shadow.h"
 #include "ui/widgets/labels.h"
 #include "ui/widgets/buttons.h"
-#include "ui/chat/chat_theme.h"
-#include "ui/chat/message_bubble.h"
 #include "ui/wrap/vertical_layout.h"
+#include "ui/painter.h"
 #include "main/main_session.h"
 #include "window/window_session_controller.h"
 #include "window/themes/window_theme.h"
+#include "data/stickers/data_custom_emoji.h"
 #include "data/data_session.h"
 #include "data/data_peer.h"
 #include "data/data_cloud_themes.h"
@@ -34,12 +43,19 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 namespace Ui {
 namespace {
 
-constexpr auto kDisableElement = "disable"_cs;
+const auto kDisableElement = [] { return u"disable"_q; };
 
-[[nodiscard]] QImage GeneratePreview(not_null<Ui::ChatTheme*> theme) {
+struct Preview {
+	QImage preview;
+	QRect userpic;
+};
+
+[[nodiscard]] Preview GeneratePreview(
+		not_null<Ui::ChatTheme*> theme,
+		const std::shared_ptr<Ui::DynamicImage> &takenUserpic) {
 	const auto &background = theme->background();
 	const auto &colors = background.colors;
-	const auto size = st::settingsThemePreviewSize;
+	const auto size = st::chatThemePreviewSize;
 	auto prepared = background.prepared;
 	const auto paintPattern = [&](QPainter &p, bool inverted) {
 		if (prepared.isNull()) {
@@ -69,6 +85,7 @@ constexpr auto kDisableElement = "disable"_cs;
 			QRect(QPoint(), size * style::DevicePixelRatio()),
 			small);
 	};
+	auto userpic = QRect();
 	const auto fullsize = size * style::DevicePixelRatio();
 	auto result = background.waitingForNegativePattern()
 		? QImage(
@@ -89,16 +106,16 @@ constexpr auto kDisableElement = "disable"_cs;
 		const auto sent = QRect(
 			QPoint(
 				(size.width()
-					- st::settingsThemeBubbleSize.width()
-					- st::settingsThemeBubblePosition.x()),
-				st::settingsThemeBubblePosition.y()),
-			st::settingsThemeBubbleSize);
+					- st::chatThemeBubbleSize.width()
+					- st::chatThemeBubblePosition.x()),
+				st::chatThemeBubblePosition.y()),
+			st::chatThemeBubbleSize);
 		const auto received = QRect(
-			st::settingsThemeBubblePosition.x(),
-			sent.y() + sent.height() + st::settingsThemeBubbleSkip,
+			st::chatThemeBubblePosition.x(),
+			sent.y() + sent.height() + st::chatThemeBubbleSkip,
 			sent.width(),
 			sent.height());
-		const auto radius = st::settingsThemeBubbleRadius;
+		const auto radius = st::chatThemeBubbleRadius;
 
 		PainterHighQualityEnabler hq(p);
 		p.setPen(Qt::NoPen);
@@ -109,22 +126,40 @@ constexpr auto kDisableElement = "disable"_cs;
 				Qt::SmoothTransformation
 			).convertToFormat(QImage::Format_ARGB32_Premultiplied);
 			const auto corners = Images::CornersMask(radius);
-			Images::prepareRound(bubble, corners);
-			p.drawImage(sent, bubble);
+			p.drawImage(sent, Images::Round(std::move(bubble), corners));
 		} else {
 			p.setBrush(theme->palette()->msgOutBg()->c);
 			p.drawRoundedRect(sent, radius, radius);
 		}
 		p.setBrush(theme->palette()->msgInBg()->c);
 		p.drawRoundedRect(received, radius, radius);
+
+		if (takenUserpic) {
+			const auto border = 2 * st::lineWidth;
+			const auto inner = received.marginsRemoved(
+				{ border, border, border, border });
+			userpic = inner;
+			userpic.setWidth(userpic.height());
+
+			st::chatThemeGiftTaken.paintInCenter(
+				p,
+				QRect(
+					inner.x() + inner.width() - inner.height() - border,
+					inner.y(),
+					inner.height(),
+					inner.height()),
+				theme->palette()->msgFileInBg()->c);
+		}
 	}
-	Images::prepareRound(result, ImageRoundRadius::Large);
-	return result;
+	return {
+		.preview = Images::Round(std::move(result), ImageRoundRadius::Large),
+		.userpic = userpic,
+	};
 }
 
 [[nodiscard]] QImage GenerateEmptyPreview() {
 	auto result = QImage(
-		st::settingsThemePreviewSize * style::DevicePixelRatio(),
+		st::chatThemePreviewSize * style::DevicePixelRatio(),
 		QImage::Format_ARGB32_Premultiplied);
 	result.fill(st::settingsThemeNotSupportedBg->c);
 	result.setDevicePixelRatio(style::DevicePixelRatio());
@@ -132,26 +167,30 @@ constexpr auto kDisableElement = "disable"_cs;
 		auto p = QPainter(&result);
 		p.setPen(st::menuIconFg);
 		p.setFont(st::semiboldFont);
-		const auto top = st::normalFont->height / 2;
-		const auto width = st::settingsThemePreviewSize.width();
-		const auto height = st::settingsThemePreviewSize.height() - top;
+		const auto top = st::chatThemeEmptyPreviewTop;
+		const auto width = st::chatThemePreviewSize.width();
+		const auto height = st::chatThemePreviewSize.height() - top;
 		p.drawText(
 			QRect(0, top, width, height),
 			tr::lng_chat_theme_none(tr::now),
 			style::al_top);
 	}
-	Images::prepareRound(result, ImageRoundRadius::Large);
-	return result;
+	return Images::Round(std::move(result), ImageRoundRadius::Large);
 }
 
 } // namespace
 
 struct ChooseThemeController::Entry {
+	QString token;
 	Ui::ChatThemeKey key;
 	std::shared_ptr<Ui::ChatTheme> theme;
 	std::shared_ptr<Data::DocumentMedia> media;
-	QImage preview;
+	std::shared_ptr<Data::UniqueGift> gift;
+	std::shared_ptr<Ui::DynamicImage> takenUserpic;
+	std::unique_ptr<Ui::Text::CustomEmoji> custom;
 	EmojiPtr emoji = nullptr;
+	QImage preview;
+	QRect userpic;
 	QRect geometry;
 	bool chosen = false;
 };
@@ -166,6 +205,7 @@ ChooseThemeController::ChooseThemeController(
 , _topShadow(std::make_unique<PlainShadow>(parent))
 , _content(_wrap->add(object_ptr<RpWidget>(_wrap.get())))
 , _inner(CreateChild<RpWidget>(_content.get()))
+, _disabledEmoji(Ui::Emoji::Find(QString::fromUtf8("\xe2\x9d\x8c")))
 , _dark(Window::Theme::IsThemeDarkValue()) {
 	init(parent->sizeValue());
 }
@@ -178,43 +218,58 @@ void ChooseThemeController::init(rpl::producer<QSize> outer) {
 	using namespace rpl::mappers;
 
 	const auto themes = &_controller->session().data().cloudThemes();
+	if (themes->myGiftThemesTokens().empty()) {
+		themes->myGiftThemesLoadMore();
+	}
+
 	const auto &list = themes->chatThemes();
 	if (!list.empty()) {
 		fill(list);
 	} else {
 		themes->refreshChatThemes();
 		themes->chatThemesUpdated(
-		) | rpl::take(1) | rpl::start_with_next([=] {
+		) | rpl::take(1) | rpl::on_next([=] {
 			fill(themes->chatThemes());
 		}, lifetime());
 	}
 
-	const auto skip = st::normalFont->spacew * 4;
 	const auto titleWrap = _wrap->insert(
 		0,
 		object_ptr<FixedHeightWidget>(
 			_wrap.get(),
-			skip + st::boxTitle.style.font->height + skip));
+			st::boxTitle.style.font->height),
+		st::chatThemeTitlePadding);
 	auto title = CreateChild<FlatLabel>(
 		titleWrap,
 		tr::lng_chat_theme_title(),
 		st::boxTitle);
 	_wrap->paintRequest(
-	) | rpl::start_with_next([=](QRect clip) {
+	) | rpl::on_next([=](QRect clip) {
 		QPainter(_wrap.get()).fillRect(clip, st::windowBg);
 	}, lifetime());
 
+	const auto close = Ui::CreateChild<Ui::IconButton>(
+		_wrap.get(),
+		st::boxTitleClose);
+	close->setClickedCallback([=] { this->close(); });
+	rpl::combine(
+		_wrap->widthValue(),
+		titleWrap->positionValue()
+	) | rpl::on_next([=](int width, QPoint position) {
+		close->moveToRight(0, 0, width);
+	}, close->lifetime());
+
 	initButtons();
 	initList();
 
 	_inner->positionValue(
-	) | rpl::start_with_next([=](QPoint position) {
-		title->move(std::max(position.x(), skip) + skip, skip);
+	) | rpl::on_next([=](QPoint position) {
+		title->move(std::max(position.x(), 0), 0);
 	}, title->lifetime());
 
 	std::move(
 		outer
-	) | rpl::start_with_next([=](QSize outer) {
+	) | rpl::on_next([=](QSize outer) {
 		_wrap->resizeToWidth(outer.width());
 		_wrap->move(0, outer.height() - _wrap->height());
 		const auto line = st::lineWidth;
@@ -225,7 +280,7 @@ void ChooseThemeController::init(rpl::producer<QSize> outer) {
 		_shouldBeShown.value(),
 		_forceHidden.value(),
 		_1 && !_2
-	) | rpl::start_with_next([=](bool shown) {
+	) | rpl::on_next([=](bool shown) {
 		_wrap->setVisible(shown);
 		_topShadow->setVisible(shown);
 	}, lifetime());
@@ -233,73 +288,129 @@ void ChooseThemeController::init(rpl::producer<QSize> outer) {
 
 void ChooseThemeController::initButtons() {
 	const auto controls = _wrap->add(object_ptr<RpWidget>(_wrap.get()));
-	const auto cancel = CreateChild<RoundButton>(
-		controls,
-		tr::lng_cancel(),
-		st::defaultLightButton);
 	const auto apply = CreateChild<RoundButton>(
 		controls,
 		tr::lng_chat_theme_apply(),
-		st::defaultActiveButton);
-	const auto skip = st::normalFont->spacew * 2;
+		st::defaultLightButton);
+	apply->setTextTransform(Ui::RoundButton::TextTransform::NoTransform);
+	const auto choose = CreateChild<RoundButton>(
+		controls,
+		tr::lng_chat_theme_change_wallpaper(),
+		st::defaultLightButton);
+	choose->setTextTransform(Ui::RoundButton::TextTransform::NoTransform);
+
+	const auto &margin = st::chatThemeButtonMargin;
 	controls->resize(
-		skip + cancel->width() + skip + apply->width() + skip,
-		apply->height() + skip * 2);
+		margin.left() + choose->width() + margin.right(),
+		margin.top() + choose->height() + margin.bottom());
 	rpl::combine(
 		controls->widthValue(),
-		cancel->widthValue(),
-		apply->widthValue()
-	) | rpl::start_with_next([=](
+		apply->widthValue(),
+		choose->widthValue(),
+		_chosen.value()
+	) | rpl::on_next([=](
 			int outer,
-			int cancelWidth,
-			int applyWidth) {
-		const auto inner = skip + cancelWidth + skip + applyWidth + skip;
+			int applyWidth,
+			int chooseWidth,
+			QString chosen) {
+		const auto was = _peer->themeToken();
+		const auto now = (chosen == kDisableElement()) ? QString() : chosen;
+		const auto changed = (now != was);
+		apply->setVisible(changed);
+		choose->setVisible(!changed);
+		const auto shown = changed ? apply : choose;
+		const auto shownWidth = changed ? applyWidth : chooseWidth;
+		const auto inner = margin.left() + shownWidth + margin.right();
 		const auto left = (outer - inner) / 2;
-		cancel->moveToLeft(left, 0);
-		apply->moveToRight(left, 0);
+		shown->moveToLeft(left, margin.top());
 	}, controls->lifetime());
 
-	cancel->setClickedCallback([=] { close(); });
+	const auto setTheme = crl::guard(apply, [=](
+			const QString &token,
+			const std::shared_ptr<Ui::ChatTheme> &theme) {
+		SetPeerTheme(_controller, _peer, token, theme);
+		_controller->toggleChooseChatTheme(_peer);
+	});
+	const auto confirmTakeGiftTheme = crl::guard(apply, [=](
+			const QString &token,
+			const std::shared_ptr<Ui::ChatTheme> &theme,
+			not_null<PeerData*> nowHasTheme) {
+		_controller->show(Box([=](not_null<Ui::GenericBox*> box) {
+			const auto confirmed = [=](Fn<void()> close) {
+				setTheme(token, theme);
+				close();
+			};
+			Ui::ConfirmBox(box, {
+				.text = tr::lng_chat_theme_gift_replace(
+					lt_name,
+					rpl::single(Ui::Text::Bold(nowHasTheme->shortName())),
+					Ui::Text::WithEntities),
+				.confirmed = confirmed,
+				.confirmText = tr::lng_box_yes(),
+			});
+		}));
+	});
 	apply->setClickedCallback([=] {
 		if (const auto chosen = findChosen()) {
-			if (Ui::Emoji::Find(_peer->themeEmoji()) != chosen->emoji) {
-				const auto now = chosen->key ? _chosen : QString();
-				_peer->setThemeEmoji(now);
-				if (chosen->theme) {
-					// Remember while changes propagate through event loop.
-					_controller->pushLastUsedChatTheme(chosen->theme);
+			const auto was = _peer->themeToken();
+			const auto now = chosen->key ? _chosen.current() : QString();
+			const auto user = chosen->gift
+				? chosen->gift->themeUser
+				: nullptr;
+			if (was != now) {
+				if (!user || user == _peer) {
+					setTheme(now, chosen->theme);
+				} else {
+					confirmTakeGiftTheme(now, chosen->theme, user);
 				}
-				const auto api = &_peer->session().api();
-				api->request(MTPmessages_SetChatTheme(
-					_peer->input,
-					MTP_string(now)
-				)).done([=](const MTPUpdates &result) {
-					api->applyUpdates(result);
-				}).send();
+			} else {
+				_controller->toggleChooseChatTheme(_peer);
 			}
+		} else {
+			_controller->toggleChooseChatTheme(_peer);
 		}
-		_controller->toggleChooseChatTheme(_peer);
+	});
+	choose->setClickedCallback([=] {
+		_controller->show(Box<BackgroundBox>(_controller, _peer));
 	});
 }
 
 void ChooseThemeController::paintEntry(QPainter &p, const Entry &entry) {
 	const auto geometry = entry.geometry;
 	p.drawImage(geometry, entry.preview);
+	if (const auto userpic = entry.takenUserpic.get()) {
+		userpic->subscribeToUpdates([=] {
+			_inner->update();
+		});
+		p.drawImage(
+			entry.userpic.translated(geometry.topLeft()),
+			userpic->image(entry.userpic.height()));
+	}
 
 	const auto size = Ui::Emoji::GetSizeLarge();
 	const auto factor = style::DevicePixelRatio();
-	const auto emojiLeft = geometry.x()
-		+ (geometry.width() - (size / factor)) / 2;
+	const auto esize = size / factor;
+	const auto emojiLeft = geometry.x() + (geometry.width() - esize) / 2;
 	const auto emojiTop = geometry.y()
 		+ geometry.height()
-		- (size / factor)
-		- (st::normalFont->spacew * 2);
-	Ui::Emoji::Draw(p, entry.emoji, size, emojiLeft, emojiTop);
+		- esize
+		- st::chatThemeEmojiBottom;
+	const auto customSize = Ui::Text::AdjustCustomEmojiSize(esize);
+	const auto customSkip = (esize - customSize) / 2;
+
+	if (const auto emoji = entry.emoji) {
+		Ui::Emoji::Draw(p, emoji, size, emojiLeft, emojiTop);
+	} else if (const auto custom = entry.custom.get()) {
+		custom->paint(p, {
+			.textColor = st::windowFg->c,
+			.position = { emojiLeft + customSkip, emojiTop + customSkip },
+		});
+	}
 
 	if (entry.chosen) {
 		auto hq = PainterHighQualityEnabler(p);
 		auto pen = st::activeLineFg->p;
-		const auto width = st::defaultFlatInput.borderWidth;
+		const auto width = st::defaultInputField.borderActive;
 		pen.setWidth(width);
 		p.setPen(pen);
 		const auto add = st::lineWidth + width;
@@ -313,11 +424,13 @@ void ChooseThemeController::paintEntry(QPainter &p, const Entry &entry) {
 void ChooseThemeController::initList() {
 	_content->resize(
 		_content->width(),
-		8 * st::normalFont->spacew + st::settingsThemePreviewSize.height());
+		(st::chatThemeEntryMargin.top()
+			+ st::chatThemePreviewSize.height()
+			+ st::chatThemeEntryMargin.bottom()));
 	_inner->setMouseTracking(true);
 
 	_inner->paintRequest(
-	) | rpl::start_with_next([=](QRect clip) {
+	) | rpl::on_next([=](QRect clip) {
 		auto p = QPainter(_inner.get());
 		for (const auto &entry : _entries) {
 			if (entry.preview.isNull() || !clip.intersects(entry.geometry)) {
@@ -338,13 +451,13 @@ void ChooseThemeController::initList() {
 		if (!entry) {
 			return QString();
 		} else if (entry->key) {
-			return entry->emoji->text();
+			return entry->token;
 		} else {
-			return kDisableElement.utf16();
+			return kDisableElement();
 		}
 	};
 	_inner->events(
-	) | rpl::start_with_next([=](not_null<QEvent*> event) {
+	) | rpl::on_next([=](not_null<QEvent*> event) {
 		const auto type = event->type();
 		if (type == QEvent::MouseMove) {
 			const auto mouse = static_cast<QMouseEvent*>(event.get());
@@ -377,7 +490,7 @@ void ChooseThemeController::initList() {
 			const auto mouse = static_cast<QMouseEvent*>(event.get());
 			const auto entry = byPoint(mouse->pos());
 			const auto chosen = chosenText(entry);
-			if (entry && chosen == _pressed && chosen != _chosen) {
+			if (entry && chosen == _pressed && chosen != _chosen.current()) {
 				clearCurrentBackgroundState();
 				if (const auto was = findChosen()) {
 					was->chosen = false;
@@ -385,7 +498,10 @@ void ChooseThemeController::initList() {
 				_chosen = chosen;
 				entry->chosen = true;
 				if (entry->theme || !entry->key) {
-					_controller->overridePeerTheme(_peer, entry->theme);
+					_controller->overridePeerTheme(
+						_peer,
+						entry->theme,
+						entry->token);
 				}
 				_inner->update();
 			}
@@ -406,7 +522,7 @@ void ChooseThemeController::initList() {
 	}, lifetime());
 
 	_content->events(
-	) | rpl::start_with_next([=](not_null<QEvent*> event) {
+	) | rpl::on_next([=](not_null<QEvent*> event) {
 		const auto type = event->type();
 		if (type == QEvent::KeyPress) {
 			const auto key = static_cast<QKeyEvent*>(event.get());
@@ -419,7 +535,7 @@ void ChooseThemeController::initList() {
 	rpl::combine(
 		_content->widthValue(),
 		_inner->widthValue()
-	) | rpl::start_with_next([=](int content, int inner) {
+	) | rpl::on_next([=](int content, int inner) {
 		if (!content || !inner) {
 			return;
 		} else if (!_entries.empty() && !_initialInnerLeftApplied) {
@@ -444,11 +560,15 @@ void ChooseThemeController::updateInnerLeft(int now) {
 		? (skip / 2)
 		: std::clamp(now, skip, 0);
 	_inner->move(clamped, 0);
+	const auto visibleTill = -clamped + _content->width();
+	if (_giftsFinishAt - visibleTill < _content->width()) {
+		_peer->owner().cloudThemes().myGiftThemesLoadMore();
+	}
 }
 
 void ChooseThemeController::close() {
 	if (const auto chosen = findChosen()) {
-		if (Ui::Emoji::Find(_peer->themeEmoji()) != chosen->emoji) {
+		if (_peer->themeToken() != chosen->token) {
 			clearCurrentBackgroundState();
 		}
 	}
@@ -464,13 +584,14 @@ void ChooseThemeController::clearCurrentBackgroundState() {
 }
 
 auto ChooseThemeController::findChosen() -> Entry* {
-	if (_chosen.isEmpty()) {
+	const auto chosen = _chosen.current();
+	if (chosen.isEmpty()) {
 		return nullptr;
 	}
 	for (auto &entry : _entries) {
-		if (!entry.key && _chosen == kDisableElement.utf16()) {
+		if (!entry.key && chosen == kDisableElement()) {
 			return &entry;
-		} else if (_chosen == entry.emoji->text()) {
+		} else if (chosen == entry.token) {
 			return &entry;
 		}
 	}
@@ -486,33 +607,41 @@ void ChooseThemeController::fill(
 	if (themes.empty()) {
 		return;
 	}
-	const auto count = int(themes.size()) + 1;
-	const auto single = st::settingsThemePreviewSize;
-	const auto skip = st::normalFont->spacew * 2;
-	const auto full = single.width() * count + skip * (count + 3);
-	_inner->resize(full, skip + single.height() + skip);
+	const auto single = st::chatThemePreviewSize;
+	const auto skip = st::chatThemeEntrySkip;
+	const auto &margin = st::chatThemeEntryMargin;
+	const auto initial = _peer->themeToken();
+	if (initial.isEmpty()) {
+		_chosen = kDisableElement();
+	}
 
-	const auto initial = Ui::Emoji::Find(_peer->themeEmoji());
-
-	_dark.value(
-	) | rpl::start_with_next([=](bool dark) {
+	const auto cloudThemes = &_controller->session().data().cloudThemes();
+	rpl::combine(
+		_dark.value(),
+		rpl::single(
+			rpl::empty
+		) | rpl::then(cloudThemes->myGiftThemesUpdated())
+	) | rpl::on_next([=](bool dark, auto) {
+		if (!cloudThemes->myGiftThemesReady()) {
+			return;
+		}
 		clearCurrentBackgroundState();
-		if (_chosen.isEmpty() && initial) {
-			_chosen = initial->text();
+		if (_chosen.current().isEmpty() && !initial.isEmpty()) {
+			_chosen = initial;
 		}
 
 		_cachingLifetime.destroy();
 		const auto old = base::take(_entries);
-		auto x = skip * 2;
+		auto x = margin.left();
 		_entries.push_back({
+			.emoji = _disabledEmoji,
 			.preview = GenerateEmptyPreview(),
-			.emoji = Ui::Emoji::Find(QString::fromUtf8("\xe2\x9d\x8c")),
-			.geometry = QRect(QPoint(x, skip), single),
-			.chosen = (_chosen == kDisableElement.utf16()),
+			.geometry = QRect(QPoint(x, margin.top()), single),
+			.chosen = (_chosen.current() == kDisableElement()),
 		});
 		Assert(_entries.front().emoji != nullptr);
 		style::PaletteChanged(
-		) | rpl::start_with_next([=] {
+		) | rpl::on_next([=] {
 			_entries.front().preview = GenerateEmptyPreview();
 		}, _cachingLifetime);
 
@@ -521,37 +650,61 @@ void ChooseThemeController::fill(
 			: Data::CloudThemeType::Light;
 
 		x += single.width() + skip;
-		for (const auto &theme : themes) {
-			const auto emoji = Ui::Emoji::Find(theme.emoticon);
-			if (!emoji || !theme.settings.contains(type)) {
-				continue;
+
+		const auto owner = &_controller->session().data();
+		const auto manager = &owner->customEmojiManager();
+		const auto push = [&](
+				const Data::CloudTheme &theme,
+				const QString &token) {
+			if (token.isEmpty() || !theme.settings.contains(type)) {
+				return;
 			}
 			const auto key = ChatThemeKey{ theme.id, dark };
-			const auto isChosen = (_chosen == emoji->text());
+			const auto isChosen = (_chosen.current() == token);
+			const auto themeUser = theme.unique
+				? theme.unique->themeUser
+				: nullptr;
 			_entries.push_back({
+				.token = token,
 				.key = key,
-				.emoji = emoji,
+				.gift = theme.unique,
+				.takenUserpic = (themeUser
+					? Ui::MakeUserpicThumbnail(themeUser, true)
+					: nullptr),
+				.custom = (theme.unique
+					? manager->create(
+						theme.unique->model.document,
+						[=] { _inner->update(); },
+						Data::CustomEmojiSizeTag::Large)
+					: nullptr),
+				.emoji = (theme.emoticon.isEmpty()
+					? nullptr
+					: Ui::Emoji::Find(theme.emoticon)),
 				.geometry = QRect(QPoint(x, skip), single),
 				.chosen = isChosen,
 			});
 			_controller->cachedChatThemeValue(
 				theme,
+				Data::WallPaper(0),
 				type
 			) | rpl::filter([=](const std::shared_ptr<ChatTheme> &data) {
 				return data && (data->key() == key);
 			}) | rpl::take(
 				1
-			) | rpl::start_with_next([=](std::shared_ptr<ChatTheme> &&data) {
+			) | rpl::on_next([=](std::shared_ptr<ChatTheme> &&data) {
 				const auto key = data->key();
 				const auto i = ranges::find(_entries, key, &Entry::key);
 				if (i == end(_entries)) {
 					return;
 				}
 				const auto theme = data.get();
+				const auto token = i->token;
 				i->theme = std::move(data);
-				i->preview = GeneratePreview(theme);
-				if (_chosen == i->emoji->text()) {
-					_controller->overridePeerTheme(_peer, i->theme);
+				auto generated = GeneratePreview(theme, i->takenUserpic);
+				i->preview = std::move(generated.preview);
+				i->userpic = generated.userpic;
+				if (_chosen.current() == token) {
+					_controller->overridePeerTheme(_peer, i->theme, token);
 				}
 				_inner->update();
 
@@ -568,7 +721,7 @@ void ChooseThemeController::fill(
 						&Entry::key);
 					return (i == end(_entries))
 						|| !i->theme->background().prepared.isNull();
-				}) | rpl::take(1) | rpl::start_with_next([=] {
+				}) | rpl::take(1) | rpl::on_next([=] {
 					const auto i = ranges::find(
 						_entries,
 						key,
@@ -576,12 +729,40 @@ void ChooseThemeController::fill(
 					if (i == end(_entries)) {
 						return;
 					}
-					i->preview = GeneratePreview(theme);
+					auto generated = GeneratePreview(theme, i->takenUserpic);
+					i->preview = std::move(generated.preview);
+					i->userpic = generated.userpic;
 					_inner->update();
 				}, _cachingLifetime);
 			}, _cachingLifetime);
 			x += single.width() + skip;
+		};
+
+		_giftsFinishAt = 0;
+		if (const auto now = cloudThemes->themeForToken(initial)) {
+			push(*now, initial);
 		}
+		for (const auto &token : cloudThemes->myGiftThemesTokens()) {
+			if (const auto found = cloudThemes->themeForToken(token)) {
+				if (token != initial) {
+					push(*found, token);
+					_giftsFinishAt = x;
+				}
+			}
+		}
+		for (const auto &theme : themes) {
+			if (const auto emoji = Ui::Emoji::Find(theme.emoticon)) {
+				const auto token = emoji->text();
+				if (token != initial) {
+					push(theme, token);
+				}
+			}
+		}
+
+		const auto full = x - skip + margin.right();
+		_inner->resize(
+			full,
+			margin.top() + single.height() + margin.bottom());
 
 		if (!_initialInnerLeftApplied && _content->width() > 0) {
 			applyInitialInnerLeft();
