@@ -83,7 +83,7 @@ void CameraBox(
 		return;
 	}
 	track->stateValue(
-	) | rpl::start_with_next([=](const VideoState &state) {
+	) | rpl::on_next([=](const VideoState &state) {
 		if (state == VideoState::Inactive) {
 			box->closeBox();
 		}
@@ -139,7 +139,7 @@ void SetupSubButtonBackground(
 
 	background->resize(size);
 	background->paintRequest(
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		auto p = QPainter(background);
 		auto hq = PainterHighQualityEnabler(p);
 		p.setBrush(st::boxBg);
@@ -148,7 +148,7 @@ void SetupSubButtonBackground(
 	}, background->lifetime());
 
 	upload->positionValue(
-	) | rpl::start_with_next([=](QPoint position) {
+	) | rpl::on_next([=](QPoint position) {
 		background->move(position - QPoint(border, border));
 	}, background->lifetime());
 }
@@ -221,6 +221,7 @@ UserpicButton::~UserpicButton() = default;
 
 void UserpicButton::prepare() {
 	resize(_st.size);
+	setNaturalWidth(_st.size.width());
 	_notShownYet = _waiting;
 	if (!_waiting) {
 		prepareUserpicPixmap();
@@ -230,7 +231,7 @@ void UserpicButton::prepare() {
 
 void UserpicButton::showCustomOnChosen() {
 	chosenImages(
-	) | rpl::start_with_next([=](ChosenImage &&chosen) {
+	) | rpl::on_next([=](ChosenImage &&chosen) {
 		showCustom(std::move(chosen.image));
 	}, lifetime());
 }
@@ -429,7 +430,7 @@ void UserpicButton::choosePhotoLocally() {
 					key
 				) | rpl::take(
 					1
-				) | rpl::start_with_next([=](const UserPrivacy::Rule &value) {
+				) | rpl::on_next([=](const UserPrivacy::Rule &value) {
 					using namespace Settings;
 					_window->show(Box<EditPrivacyBox>(
 						_window->sessionController(),
@@ -504,7 +505,7 @@ void UserpicButton::setupPeerViewers() {
 				user->hasPersonalPhoto());
 		}) | rpl::distinct_until_changed() | rpl::skip(
 			1
-		) | rpl::start_with_next([=] {
+		) | rpl::on_next([=] {
 			processNewPeerPhoto();
 			update();
 		}, _sourceLifetime);
@@ -515,7 +516,7 @@ void UserpicButton::setupPeerViewers() {
 		_peer->session().changes().peerUpdates(
 			_peer,
 			Data::PeerUpdate::Flag::Photo
-		) | rpl::start_with_next([=] {
+		) | rpl::on_next([=] {
 			processNewPeerPhoto();
 			update();
 		}, _sourceLifetime);
@@ -523,7 +524,7 @@ void UserpicButton::setupPeerViewers() {
 	_peer->session().downloaderTaskFinished(
 	) | rpl::filter([=] {
 		return _waiting;
-	}) | rpl::start_with_next([=] {
+	}) | rpl::on_next([=] {
 		const auto loading = _showPeerUserpic
 			? Ui::PeerUserpicLoading(_userpicView)
 			: (_nonPersonalView && !_nonPersonalView->loaded());
@@ -560,6 +561,20 @@ void UserpicButton::paintEvent(QPaintEvent *e) {
 			photoPosition.y(),
 			width(),
 			_st.photoSize);
+	} else if (showMyNotes()) {
+		Ui::EmptyUserpic::PaintMyNotes(
+			p,
+			photoPosition.x(),
+			photoPosition.y(),
+			width(),
+			_st.photoSize);
+	} else if (showAuthorHidden()) {
+		Ui::EmptyUserpic::PaintHiddenAuthor(
+			p,
+			photoPosition.x(),
+			photoPosition.y(),
+			width(),
+			_st.photoSize);
 	} else {
 		if (_a_appearance.animating()) {
 			p.drawPixmapLeft(photoPosition, width(), _oldUserpic);
@@ -774,7 +789,7 @@ bool UserpicButton::createStreamingObjects(not_null<PhotoData*> photo) {
 		nullptr);
 	_streamed->lockPlayer();
 	_streamed->player().updates(
-	) | rpl::start_with_next_error([=](Update &&update) {
+	) | rpl::on_next_error([=](Update &&update) {
 		handleStreamingUpdate(std::move(update));
 	}, [=](Error &&error) {
 		handleStreamingError(std::move(error));
@@ -954,7 +969,7 @@ void UserpicButton::switchChangePhotoOverlay(
 			updateCursorInChangeOverlay(
 				mapFromGlobal(QCursor::pos()));
 			if (chosen) {
-				chosenImages() | rpl::start_with_next(chosen, lifetime());
+				chosenImages() | rpl::on_next(chosen, lifetime());
 			}
 		} else {
 			_changeOverlayShown.stop();
@@ -975,6 +990,13 @@ void UserpicButton::showSavedMessagesOnSelf(bool enabled) {
 	}
 }
 
+void UserpicButton::showMyNotesOnSelf(bool enabled) {
+	if (_showMyNotesOnSelf != enabled) {
+		_showMyNotesOnSelf = enabled;
+		update();
+	}
+}
+
 bool UserpicButton::showSavedMessages() const {
 	return _showSavedMessagesOnSelf && _peer && _peer->isSelf();
 }
@@ -983,6 +1005,14 @@ bool UserpicButton::showRepliesMessages() const {
 	return _showSavedMessagesOnSelf && _peer && _peer->isRepliesChat();
 }
 
+bool UserpicButton::showMyNotes() const {
+	return _showMyNotesOnSelf && _peer && _peer->isSelf();
+}
+
+bool UserpicButton::showAuthorHidden() const {
+	return _showMyNotesOnSelf && _peer && _peer->isSavedHiddenAuthor();
+}
+
 void UserpicButton::startChangeOverlayAnimation() {
 	auto over = isOver() || isDown();
 	_changeOverlayShown.start(
