@@ -11,6 +11,7 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 #include "base/object_ptr.h"
 #include "lang/lang_keys.h"
 #include "ui/effects/gradient.h"
+#include "ui/effects/ministar_particles.h"
 #include "ui/effects/premium_graphics.h"
 #include "ui/wrap/padding_wrap.h"
 #include "ui/wrap/vertical_layout.h"
@@ -35,8 +36,12 @@ constexpr auto kSlideDuration = crl::time(1000);
 TextFactory ProcessTextFactory(
 		std::optional<tr::phrase<lngtag_count>> phrase) {
 	return phrase
-		? TextFactory([=](int n) { return (*phrase)(tr::now, lt_count, n); })
-		: TextFactory([=](int n) { return QString::number(n); });
+		? TextFactory([=](int n) -> BubbleText {
+			return { (*phrase)(tr::now, lt_count, n) };
+		})
+		: TextFactory([=](int n) -> BubbleText {
+			return { QString::number(n) };
+		});
 }
 
 Bubble::Bubble(
@@ -51,14 +56,17 @@ Bubble::Bubble(
 , _icon(icon)
 , _numberAnimation(_st.font, _updateCallback)
 , _height(_st.height + _st.tailSize.height())
-, _textTop((_height - _st.tailSize.height() - _st.font->height) / 2)
 , _hasTail(hasTail) {
 	_numberAnimation.setDisabledMonospace(true);
 	_numberAnimation.setWidthChangedCallback([=] {
 		_widthChanges.fire({});
 	});
-	_numberAnimation.setText(_textFactory(0), 0);
+	const auto texts = _textFactory(0);
+	_numberAnimation.setText(texts.counter, 0);
 	_numberAnimation.finishAnimating();
+	if (!texts.additional.isEmpty()) {
+		_additional.setText(_st.additionalStyle, texts.additional);
+	}
 }
 
 crl::time Bubble::SlideNoDeflectionDuration() {
@@ -74,7 +82,7 @@ int Bubble::height() const {
 }
 
 int Bubble::bubbleRadius() const {
-	return (_height - _st.tailSize.height()) / 2 - kBubbleRadiusSubtractor;
+	return (_st.height / 2) - kBubbleRadiusSubtractor;
 }
 
 int Bubble::filledWidth() const {
@@ -84,24 +92,50 @@ int Bubble::filledWidth() const {
 		+ _st.padding.right();
 }
 
-int Bubble::width() const {
-	return filledWidth() + _numberAnimation.countWidth();
+int Bubble::topTextWidth() const {
+	return filledWidth()
+		+ _numberAnimation.countWidth()
+		+ (_additional.isEmpty()
+			? 0
+			: (_st.additionalSkip + _additional.maxWidth()));
 }
 
-int Bubble::countMaxWidth(int maxPossibleCounter) const {
+int Bubble::bottomTextWidth() const {
+	return _subtext.isEmpty()
+		? 0
+		: (_st.subtextPadding.left()
+			+ _subtext.maxWidth()
+			+ _st.subtextPadding.right());
+}
+
+int Bubble::width() const {
+	return std::max(topTextWidth(), bottomTextWidth());
+}
+
+int Bubble::countTargetWidth(int targetCounter) const {
 	auto numbers = Ui::NumbersAnimation(_st.font, [] {});
 	numbers.setDisabledMonospace(true);
 	numbers.setDuration(0);
-	numbers.setText(_textFactory(0), 0);
-	numbers.setText(_textFactory(maxPossibleCounter), maxPossibleCounter);
+	const auto texts = _textFactory(targetCounter);
+	numbers.setText(texts.counter, targetCounter);
 	numbers.finishAnimating();
-	return filledWidth() + numbers.maxWidth();
+	const auto top = filledWidth()
+		+ numbers.maxWidth()
+		+ (_additional.isEmpty()
+			? 0
+			: (_st.additionalSkip
+				+ _st.additionalStyle.font->width(texts.additional)));
+	return std::max(top, bottomTextWidth());
 }
 
 void Bubble::setCounter(int value) {
 	if (_counter != value) {
 		_counter = value;
-		_numberAnimation.setText(_textFactory(value), value);
+		const auto texts = _textFactory(value);
+		_numberAnimation.setText(texts.counter, value);
+		if (!texts.additional.isEmpty()) {
+			_additional.setText(_st.additionalStyle, texts.additional);
+		}
 	}
 }
 
@@ -113,53 +147,88 @@ void Bubble::setFlipHorizontal(bool value) {
 	_flipHorizontal = value;
 }
 
+QRect Bubble::bubbleGeometry(const QRect &r) const {
+	const auto penWidth = _st.penWidth;
+	const auto penWidthHalf = penWidth / 2;
+	return r - style::margins(
+		penWidthHalf,
+		penWidthHalf,
+		penWidthHalf,
+		_st.tailSize.height() + penWidthHalf);
+}
+
+QPainterPath Bubble::bubblePath(const QRect &r) const {
+	const auto bubbleRect = bubbleGeometry(r);
+	const auto radius = bubbleRadius();
+	auto pathTail = QPainterPath();
+
+	const auto tailWHalf = _st.tailSize.width() / 2.;
+	const auto progress = _tailEdge;
+
+	const auto tailTop = bubbleRect.y() + bubbleRect.height();
+	const auto tailLeftFull = bubbleRect.x()
+		+ (bubbleRect.width() * 0.5)
+		- tailWHalf;
+	const auto tailLeft = bubbleRect.x()
+		+ (bubbleRect.width() * 0.5 * (progress + 1.))
+		- tailWHalf;
+	const auto tailCenter = tailLeft + tailWHalf;
+	const auto tailRight = [&] {
+		const auto max = bubbleRect.x() + bubbleRect.width();
+		const auto right = tailLeft + _st.tailSize.width();
+		const auto bottomMax = max - radius;
+		return (right > bottomMax)
+			? std::max(float64(tailCenter), float64(bottomMax))
+			: right;
+	}();
+	if (_hasTail) {
+		pathTail.moveTo(tailLeftFull, tailTop);
+		pathTail.lineTo(tailLeft, tailTop);
+		pathTail.lineTo(tailCenter, tailTop + _st.tailSize.height());
+		pathTail.lineTo(tailRight, tailTop);
+		pathTail.lineTo(tailRight, tailTop - radius);
+		pathTail.moveTo(tailLeftFull, tailTop);
+	}
+	auto pathBubble = QPainterPath();
+	pathBubble.setFillRule(Qt::WindingFill);
+	pathBubble.addRoundedRect(bubbleRect, radius, radius);
+
+	auto result = pathTail + pathBubble;
+	if (_flipHorizontal) {
+		auto m = QTransform();
+		const auto center = QRectF(bubbleRect).center();
+		m.translate(center.x(), center.y());
+		m.scale(-1., 1.);
+		m.translate(-center.x(), -center.y());
+		return m.map(result);
+	}
+	return result;
+}
+
+void Bubble::setSubtext(QString subtext) {
+	if (_subtext.toString() == subtext) {
+		return;
+	} else if (subtext.isEmpty()) {
+		_subtext = {};
+	} else {
+		_subtext.setText(_st.subtextStyle, subtext);
+	}
+	_widthChanges.fire({});
+	_updateCallback();
+}
+
+void Bubble::finishAnimating() {
+	_numberAnimation.finishAnimating();
+}
+
 void Bubble::paintBubble(QPainter &p, const QRect &r, const QBrush &brush) {
 	if (!_counter.has_value()) {
 		return;
 	}
 
+	const auto bubbleRect = bubbleGeometry(r);
 	const auto penWidth = _st.penWidth;
-	const auto penWidthHalf = penWidth / 2;
-	const auto bubbleRect = r - style::margins(
-		penWidthHalf,
-		penWidthHalf,
-		penWidthHalf,
-		_st.tailSize.height() + penWidthHalf);
 	{
-		const auto radius = bubbleRadius();
-		auto pathTail = QPainterPath();
-
-		const auto tailWHalf = _st.tailSize.width() / 2.;
-		const auto progress = _tailEdge;
-
-		const auto tailTop = bubbleRect.y() + bubbleRect.height();
-		const auto tailLeftFull = bubbleRect.x()
-			+ (bubbleRect.width() * 0.5)
-			- tailWHalf;
-		const auto tailLeft = bubbleRect.x()
-			+ (bubbleRect.width() * 0.5 * (progress + 1.))
-			- tailWHalf;
-		const auto tailCenter = tailLeft + tailWHalf;
-		const auto tailRight = [&] {
-			const auto max = bubbleRect.x() + bubbleRect.width();
-			const auto right = tailLeft + _st.tailSize.width();
-			const auto bottomMax = max - radius;
-			return (right > bottomMax)
-				? std::max(float64(tailCenter), float64(bottomMax))
-				: right;
-		}();
-		if (_hasTail) {
-			pathTail.moveTo(tailLeftFull, tailTop);
-			pathTail.lineTo(tailLeft, tailTop);
-			pathTail.lineTo(tailCenter, tailTop + _st.tailSize.height());
-			pathTail.lineTo(tailRight, tailTop);
-			pathTail.lineTo(tailRight, tailTop - radius);
-			pathTail.moveTo(tailLeftFull, tailTop);
-		}
-		auto pathBubble = QPainterPath();
-		pathBubble.setFillRule(Qt::WindingFill);
-		pathBubble.addRoundedRect(bubbleRect, radius, radius);
-
 		auto hq = PainterHighQualityEnabler(p);
 		p.setPen(QPen(
 			brush,
@@ -168,28 +237,59 @@ void Bubble::paintBubble(QPainter &p, const QRect &r, const QBrush &brush) {
 			Qt::RoundCap,
 			Qt::RoundJoin));
 		p.setBrush(brush);
-		if (_flipHorizontal) {
-			auto m = QTransform();
-			const auto center = QRectF(bubbleRect).center();
-			m.translate(center.x(), center.y());
-			m.scale(-1., 1.);
-			m.translate(-center.x(), -center.y());
-			p.drawPath(m.map(pathTail + pathBubble));
-		} else {
-			p.drawPath(pathTail + pathBubble);
-		}
+		p.drawPath(bubblePath(r));
 	}
 	p.setPen(st::activeButtonFg);
 	p.setFont(_st.font);
-	const auto iconLeft = r.x() + _st.padding.left();
+	const auto withSubtext = !_subtext.isEmpty();
+	const auto height = withSubtext
+		? (_st.font->height
+			+ _st.subtextPadding.top()
+			+ _st.subtextStyle.font->height)
+		: _st.font->height;
+	const auto topWidth = withSubtext ? topTextWidth() : 0;
+	const auto bottomWidth = withSubtext ? bottomTextWidth() : 0;
+	const auto iconShift = (topWidth >= bottomWidth)
+		? 0
+		: (bottomWidth - topWidth) / 2;
+	const auto iconLeft = r.x() + _st.padding.left() + iconShift;
+	const auto topShift = (_st.font->height - height) / 2;
 	const auto iconTop = bubbleRect.y()
+		+ topShift
 		+ (bubbleRect.height() - _icon->height()) / 2;
 	_icon->paint(p, iconLeft, iconTop, bubbleRect.width());
-	_numberAnimation.paint(
-		p,
-		iconLeft + _icon->width() + _st.textSkip,
-		r.y() + _textTop,
-		width() / 2);
+	const auto numberLeft = iconLeft + _icon->width() + _st.textSkip;
+	const auto numberTop = r.y() + (_st.height - height) / 2;
+	_numberAnimation.paint(p, numberLeft, numberTop, width());
+	if (!_additional.isEmpty()) {
+		p.setOpacity(0.7);
+		const auto additionalLeft = numberLeft
+			+ _numberAnimation.countWidth()
+			+ _st.additionalSkip;
+		const auto additionalTop = numberTop
+			+ _st.font->ascent
+			- _st.additionalStyle.font->ascent;
+		_additional.draw(p, {
+			.position = { additionalLeft, additionalTop },
+			.availableWidth = _additional.maxWidth(),
+		});
+	}
+	if (withSubtext) {
+		p.setOpacity(1.);
+		const auto subtextShift = (bottomWidth >= topWidth)
+			? 0
+			: (topWidth - bottomWidth) / 2;
+		const auto subtextLeft = r.x()
+			+ _st.subtextPadding.left()
+			+ subtextShift;
+		const auto subtextTop = numberTop
+			+ _st.font->height
+			+ _st.subtextPadding.top();
+		_subtext.draw(p, {
+			.position = { subtextLeft, subtextTop },
+			.availableWidth = _subtext.maxWidth(),
+		});
+	}
 }
 
 rpl::producer<> Bubble::widthChanges() const {
@@ -205,7 +305,7 @@ BubbleWidget::BubbleWidget(
 	rpl::producer<> showFinishes,
 	const style::icon *icon,
 	const style::margins &outerPadding)
-: RpWidget(parent)
+: AbstractButton(parent)
 , _st(st)
 , _state(std::move(state))
 , _bubble(
@@ -219,6 +319,9 @@ BubbleWidget::BubbleWidget(
 , _deflection(kDeflection)
 , _stepBeforeDeflection(kStepBeforeDeflection)
 , _stepAfterDeflection(kStepAfterDeflection) {
+	if (_type == BubbleType::Credits) {
+		setupParticles(parent);
+	}
 	const auto resizeTo = [=](int w, int h) {
 		_deflection = (w > _st.widthLimit)
 			? kDeflectionSmall
@@ -229,38 +332,115 @@ BubbleWidget::BubbleWidget(
 
 	resizeTo(_bubble.width(), _bubble.height());
 	_bubble.widthChanges(
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		resizeTo(_bubble.width(), _bubble.height());
 	}, lifetime());
 
+	const auto instant = !showFinishes;
+	if (instant) {
+		showFinishes = rpl::single(rpl::empty);
+	}
 	std::move(
 		showFinishes
-	) | rpl::take(1) | rpl::start_with_next([=] {
+	) | rpl::take(1) | rpl::on_next([=] {
 		_state.value(
-		) | rpl::start_with_next([=](BubbleRowState state) {
+		) | rpl::on_next([=](BubbleRowState state) {
 			animateTo(state);
 		}, lifetime());
+		if (instant) {
+			_appearanceAnimation.stop();
+			if (const auto onstack = base::take(_appearanceCallback)) {
+				onstack(1.);
+			}
+			_bubble.finishAnimating();
+		}
 
-		parent->widthValue() | rpl::start_with_next([=](int w) {
+		parent->widthValue() | rpl::on_next([=](int w) {
 			if (!_appearanceAnimation.animating()) {
-				const auto x = base::SafeRound(
-					w * _state.current().ratio - width() / 2);
-				const auto padding = _spaceForDeflection.width();
-				moveToLeft(
-					std::clamp(int(x), -padding, w - width() + padding),
-					y());
+				const auto available = w
+					- _outerPadding.left()
+					- _outerPadding.right();
+				const auto x = (available * _animatingFromResultRatio);
+				moveToLeft(-_spaceForDeflection.width()
+					+ std::max(
+						int(base::SafeRound(x
+							- (_bubble.width() / 2)
+							+ _outerPadding.left())),
+						0),
+					0);
 			}
 		}, lifetime());
 	}, lifetime());
 }
 
+void BubbleWidget::setupParticles(not_null<Ui::RpWidget*> parent) {
+	_particles.emplace(StarParticles::Type::Radial, 50, st::lineWidth * 4);
+	_particles->setSpeed(0.1);
+
+	_particlesWidget = Ui::CreateChild<Ui::RpWidget>(parent);
+	_particlesWidget->setAttribute(Qt::WA_TransparentForMouseEvents);
+	_particlesWidget->show();
+	_particlesWidget->raise();
+
+	_particlesAnimation.init([=] { _particlesWidget->update(); });
+
+	_particlesWidget->paintRequest() | rpl::on_next([=] {
+		if (!_particlesAnimation.animating()) {
+			_particlesAnimation.start();
+		}
+		auto p = QPainter(_particlesWidget);
+		auto hq = PainterHighQualityEnabler(p);
+
+		const auto offset = QPoint(
+			(_particlesWidget->width() - width()) / 2,
+			(_particlesWidget->height() - height()) / 2);
+		const auto bubbleRect = rect().translated(offset)
+			- QMargins(
+				_spaceForDeflection.width(),
+				_spaceForDeflection.height(),
+				_spaceForDeflection.width(),
+				_spaceForDeflection.height());
+
+		p.save();
+		p.translate(offset);
+		const auto bubblePath = _bubble.bubblePath(bubbleRect);
+		p.restore();
+
+		auto fullRect = QPainterPath();
+		fullRect.addRect(QRectF(_particlesWidget->rect()));
+
+		p.setClipPath(bubblePath);
+		_particles->setColor(st::premiumButtonFg->c);
+		_particles->paint(p, _particlesWidget->rect(), crl::now());
+		p.setClipping(false);
+
+		p.setClipPath(fullRect.subtracted(bubblePath));
+		_particles->setColor(_brushOverride
+			? st::groupCallMemberInactiveIcon->c
+			: st::creditsBg3->c);
+		_particles->paint(p, _particlesWidget->rect(), crl::now());
+	}, _particlesWidget->lifetime());
+
+	geometryValue() | rpl::on_next([=](QRect geometry) {
+		const auto particlesSize = QSize(
+			int(geometry.width() * 1.5),
+			int(geometry.height() * 1.5));
+		const auto center = geometry.center();
+		_particlesWidget->setGeometry(
+			center.x() - particlesSize.width() / 2,
+			center.y() - particlesSize.height() / 2,
+			particlesSize.width(),
+			particlesSize.height());
+	}, lifetime());
+}
+
 void BubbleWidget::animateTo(BubbleRowState state) {
-	_maxBubbleWidth = _bubble.countMaxWidth(state.counter);
+	const auto targetWidth = _bubble.countTargetWidth(state.counter);
 	const auto parent = parentWidget();
 	const auto available = parent->width()
 		- _outerPadding.left()
 		- _outerPadding.right();
-	const auto halfWidth = (_maxBubbleWidth / 2);
+	const auto halfWidth = (targetWidth / 2);
 	const auto computeLeft = [=](float64 pointRatio, float64 animProgress) {
 		const auto delta = (pointRatio - _animatingFromResultRatio);
 		const auto center = available
@@ -269,9 +449,7 @@ void BubbleWidget::animateTo(BubbleRowState state) {
 	};
 	const auto moveEndPoint = state.ratio;
 	const auto computeRightEdge = [=] {
-		return parent->width()
-			- _outerPadding.right()
-			- _maxBubbleWidth;
+		return parent->width() - _outerPadding.right() - targetWidth;
 	};
 	struct Edge final {
 		float64 goodPointRatio = 0.;
@@ -324,11 +502,12 @@ void BubbleWidget::animateTo(BubbleRowState state) {
 		_animatingFromResultRatio = 0.;
 		_animatingFromBubbleEdge = 0.;
 	}
-	_appearanceAnimation.start([=](float64 value) {
+	_appearanceCallback = [=](float64 value) {
 		if (!_appearanceAnimation.animating()) {
 			_animatingFrom = state;
 			_animatingFromResultRatio = resultMoveEndPoint;
 			_animatingFromBubbleEdge = finalEdge;
+			_appearanceCallback = nullptr;
 		}
 		value = std::abs(value);
 		const auto moveProgress = std::clamp(
@@ -352,14 +531,30 @@ void BubbleWidget::animateTo(BubbleRowState state) {
 			+ counterProgress * (state.counter - _animatingFrom.counter);
 		_bubble.setCounter(int(base::SafeRound(now)));
 
+		if (_particles) {
+			const auto progress = now / float(state.counter);
+			_particles->setSpeed(0.01 + progress * 0.25);
+		}
+
 		_bubble.setFlipHorizontal(nowBubbleEdge < 0);
 		_bubble.setTailEdge(std::abs(nowBubbleEdge));
 		update();
-	},
-	0.,
-	(state.ratio >= _animatingFrom.ratio) ? 1. : -1.,
-	duration,
-	anim::easeOutCirc);
+	};
+	_appearanceAnimation.start(
+		_appearanceCallback,
+		0.,
+		(state.ratio >= _animatingFrom.ratio) ? 1. : -1.,
+		duration,
+		anim::easeOutCirc);
+}
+
+void BubbleWidget::setBrushOverride(std::optional<QBrush> brushOverride) {
+	_brushOverride = std::move(brushOverride);
+	update();
+}
+
+void BubbleWidget::setSubtext(QString subtext) {
+	_bubble.setSubtext(subtext);
 }
 
 void BubbleWidget::paintEvent(QPaintEvent *e) {
@@ -420,8 +615,12 @@ void BubbleWidget::paintEvent(QPaintEvent *e) {
 
 
 	_bubble.paintBubble(p, bubbleRect, [&] {
+		if (_brushOverride) {
+			return *_brushOverride;
+		}
 		switch (_type) {
 		case BubbleType::NoPremium:
+		case BubbleType::UpgradePrice:
 		case BubbleType::StarRating: return st::windowBgActive->b;
 		case BubbleType::NegativeRating: return st::attentionButtonFg->b;
 		case BubbleType::Premium: return QBrush(_cachedGradient);
@@ -431,7 +630,11 @@ void BubbleWidget::paintEvent(QPaintEvent *e) {
 	}());
 }
 
-void AddBubbleRow(
+void BubbleWidget::resizeEvent(QResizeEvent *e) {
+	RpWidget::resizeEvent(e);
+}
+
+not_null<BubbleWidget*> AddBubbleRow(
 		not_null<Ui::VerticalLayout*> parent,
 		const style::PremiumBubble &st,
 		rpl::producer<> showFinishes,
@@ -441,7 +644,7 @@ void AddBubbleRow(
 		BubbleType type,
 		std::optional<tr::phrase<lngtag_count>> phrase,
 		const style::icon *icon) {
-	AddBubbleRow(
+	return AddBubbleRow(
 		parent,
 		st,
 		std::move(showFinishes),
@@ -455,17 +658,19 @@ void AddBubbleRow(
 		st::boxRowPadding);
 }
 
-void AddBubbleRow(
+not_null<BubbleWidget*> AddBubbleRow(
 		not_null<Ui::VerticalLayout*> parent,
 		const style::PremiumBubble &st,
 		rpl::producer<> showFinishes,
 		rpl::producer<BubbleRowState> state,
 		BubbleType type,
-		Fn<QString(int)> text,
+		TextFactory text,
 		const style::icon *icon,
 		const style::margins &outerPadding) {
 	const auto container = parent->add(
 		object_ptr<Ui::FixedHeightWidget>(parent, 0));
+	container->show();
+
 	const auto bubble = Ui::CreateChild<BubbleWidget>(
 		container,
 		st,
@@ -475,13 +680,15 @@ void AddBubbleRow(
 		std::move(showFinishes),
 		icon,
 		outerPadding);
+	bubble->setAttribute(Qt::WA_TransparentForMouseEvents);
 	rpl::combine(
 		container->sizeValue(),
 		bubble->sizeValue()
-	) | rpl::start_with_next([=](const QSize &parentSize, const QSize &size) {
+	) | rpl::on_next([=](const QSize &parentSize, const QSize &size) {
 		container->resize(parentSize.width(), size.height());
 	}, bubble->lifetime());
 	bubble->show();
+	return bubble;
 }
 
 } // namespace Ui::Premium
