@@ -28,6 +28,7 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 #include "window/window_session_controller.h"
 #include "window/themes/window_theme_editor.h"
 #include "ui/boxes/confirm_box.h"
+#include "data/components/promo_suggestions.h"
 #include "data/data_thread.h"
 #include "apiwrap.h" // ApiWrap::acceptTerms.
 #include "styles/style_layers.h"
@@ -167,13 +168,13 @@ void Controller::showAccount(
 
 	if (!isPrimary()) {
 		_id.account->sessionChanges(
-		) | rpl::start_with_next([=](Main::Session *session) {
+		) | rpl::on_next([=](Main::Session *session) {
 			Core::App().closeWindow(this);
 		}, _accountLifetime);
 	}
 
 	_id.account->sessionValue(
-	) | rpl::start_with_next([=](Main::Session *session) {
+	) | rpl::on_next([=](Main::Session *session) {
 		const auto was = base::take(_sessionController);
 		_sessionController = session
 			? std::make_unique<SessionController>(session, this)
@@ -189,12 +190,12 @@ void Controller::showAccount(
 			session->updates().isIdleValue(
 			) | rpl::filter([=](bool idle) {
 				return !idle;
-			}) | rpl::start_with_next([=] {
+			}) | rpl::on_next([=] {
 				widget()->checkActivation();
 			}, _sessionController->lifetime());
 
 			session->termsLockValue(
-			) | rpl::start_with_next([=] {
+			) | rpl::on_next([=] {
 				checkLockByTerms();
 				_widget.updateGlobalMenu();
 			}, _sessionController->lifetime());
@@ -202,11 +203,16 @@ void Controller::showAccount(
 			widget()->setInnerFocus();
 
 			_sessionController->activeChatChanges(
-			) | rpl::start_with_next([=] {
+			) | rpl::on_next([=] {
 				_widget.updateTitle();
 			}, _sessionController->lifetime());
 			_widget.updateTitle();
 
+			if (session->promoSuggestions().setupEmailState()
+				!= Data::SetupEmailState::None) {
+				_widget.setupSetupEmailLock();
+			}
+
 			session->updates().updateOnline(crl::now());
 		} else {
 			sideBarChanged();
@@ -225,7 +231,7 @@ void Controller::setupSideBar() {
 		return;
 	}
 	_sessionController->filtersMenuChanged(
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		sideBarChanged();
 	}, _sessionController->lifetime());
 
@@ -259,7 +265,7 @@ void Controller::checkLockByTerms() {
 
 	const auto id = data->id;
 	box->agreeClicks(
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		const auto mention = box ? box->lastClickedMention() : QString();
 		box->closeBox();
 		if (const auto session = account().maybeSession()) {
@@ -272,7 +278,7 @@ void Controller::checkLockByTerms() {
 	}, box->lifetime());
 
 	box->cancelClicks(
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		showTermsDecline();
 	}, box->lifetime());
 
@@ -291,7 +297,7 @@ void Controller::showTermsDecline() {
 		true));
 
 	box->agreeClicks(
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		if (box) {
 			box->closeBox();
 		}
@@ -299,7 +305,7 @@ void Controller::showTermsDecline() {
 	}, box->lifetime());
 
 	box->cancelClicks(
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		if (box) {
 			box->closeBox();
 		}
@@ -346,7 +352,7 @@ auto Controller::sessionControllerChanges() const
 }
 
 bool Controller::locked() const {
-	if (Core::App().passcodeLocked()) {
+	if (Core::App().passcodeLocked()/* || Core::App().setupEmailLocked()*/) {
 		return true;
 	} else if (const auto controller = sessionController()) {
 		return controller->session().termsLocked().has_value();
@@ -374,6 +380,19 @@ void Controller::clearPasscodeLock() {
 	}
 }
 
+void Controller::setupSetupEmailLock() {
+	if (const auto &session = _sessionController) {
+		if (session->session().promoSuggestions().setupEmailState()
+			!= Data::SetupEmailState::None) {
+			_widget.setupSetupEmailLock();
+		}
+	}
+}
+
+void Controller::clearSetupEmailLock() {
+	_widget.clearSetupEmailLock();
+}
+
 void Controller::setupIntro(QPixmap oldContentCache) {
 	const auto point = Core::App().domain().maybeLastOrSomeAuthedAccount()
 		? Intro::EnterPoint::Qr
@@ -431,7 +450,7 @@ void Controller::showBox(
 	_widget.showOrHideBoxOrLayer(std::move(content), options, animated);
 }
 
-void Controller::showRightColumn(object_ptr<TWidget> widget) {
+void Controller::showRightColumn(object_ptr<Ui::RpWidget> widget) {
 	_widget.showRightColumn(std::move(widget));
 }
 
