@@ -33,7 +33,7 @@ enum {
     kRtpMinParseLength = 12
 };
 
-static void updateHeaderWithVoiceActivity(rtc::CopyOnWriteBuffer *packet, const uint8_t* ptrRTPDataExtensionEnd, const uint8_t* ptr, bool voiceActivity) {
+static void updateHeaderWithVoiceActivity(rtc::CopyOnWriteBuffer *packet, const uint8_t* ptrRTPDataExtensionEnd, const uint8_t* ptr, bool voiceActivity, bool zeroAudioLevel) {
     while (ptrRTPDataExtensionEnd - ptr > 0) {
         //  0
         //  0 1 2 3 4 5 6 7
@@ -67,6 +67,15 @@ static void updateHeaderWithVoiceActivity(rtc::CopyOnWriteBuffer *packet, const
 
         if (id == 1) { // kAudioLevelUri
             uint8_t audioLevel = ptr[0] & 0x7f;
+            if (zeroAudioLevel) {
+                if (audioLevel < 47) {
+                    audioLevel = 0;
+                } else if (audioLevel < 107) {
+                    audioLevel = 106;
+                } else {
+                    audioLevel = 127;
+                }
+            }
             bool parsedVoiceActivity = (ptr[0] & 0x80) != 0;
 
             if (parsedVoiceActivity != voiceActivity) {
@@ -129,7 +138,7 @@ static void readHeaderVoiceActivity(const uint8_t* ptrRTPDataExtensionEnd, const
 #endif
 
 
-static void maybeUpdateRtpVoiceActivity(rtc::CopyOnWriteBuffer *packet, bool voiceActivity) {
+static void maybeUpdateRtpVoiceActivity(rtc::CopyOnWriteBuffer *packet, bool voiceActivity, bool zeroAudioLevel) {
     const uint8_t *_ptrRTPDataBegin = packet->data();
     const uint8_t *_ptrRTPDataEnd = packet->data() + packet->size();
 
@@ -199,7 +208,7 @@ static void maybeUpdateRtpVoiceActivity(rtc::CopyOnWriteBuffer *packet, bool voi
       static constexpr uint16_t kRtpOneByteHeaderExtensionId = 0xBEDE;
       if (definedByProfile == kRtpOneByteHeaderExtensionId) {
           const uint8_t* ptrRTPDataExtensionEnd = ptr + XLen;
-          updateHeaderWithVoiceActivity(packet, ptrRTPDataExtensionEnd, ptr, voiceActivity);
+          updateHeaderWithVoiceActivity(packet, ptrRTPDataExtensionEnd, ptr, voiceActivity, zeroAudioLevel);
       }
     }
 }
@@ -287,16 +296,17 @@ public:
     bool _voiceActivity = false;
 
 public:
-    WrappedDtlsSrtpTransport(bool rtcp_mux_enabled, const webrtc::FieldTrialsView& fieldTrials, std::function<void(webrtc::RtpPacketReceived const &, bool)> &&processRtpPacket) :
+    WrappedDtlsSrtpTransport(bool rtcp_mux_enabled, const webrtc::FieldTrialsView& fieldTrials, std::function<void(webrtc::RtpPacketReceived const &, bool)> &&processRtpPacket, bool zeroAudioLevel) :
     webrtc::DtlsSrtpTransport(rtcp_mux_enabled, fieldTrials),
-    _processRtpPacket(std::move(processRtpPacket)) {
+    _processRtpPacket(std::move(processRtpPacket)),
+    _zeroAudioLevel(zeroAudioLevel) {
     }
 
     virtual ~WrappedDtlsSrtpTransport() {
     }
 
     bool SendRtpPacket(rtc::CopyOnWriteBuffer *packet, const rtc::PacketOptions& options, int flags) override {
-        maybeUpdateRtpVoiceActivity(packet, _voiceActivity);
+        maybeUpdateRtpVoiceActivity(packet, _voiceActivity, _zeroAudioLevel);
         return webrtc::DtlsSrtpTransport::SendRtpPacket(packet, options, flags);
     }
     
@@ -306,6 +316,7 @@ public:
 
 private:
     std::function<void(webrtc::RtpPacketReceived const &, bool)> _processRtpPacket;
+    bool _zeroAudioLevel;
 };
 
 webrtc::CryptoOptions GroupNetworkManager::getDefaulCryptoOptions() {
@@ -322,13 +333,17 @@ GroupNetworkManager::GroupNetworkManager(
     std::function<void(bool)> dataChannelStateUpdated,
     std::function<void(std::string const &)> dataChannelMessageReceived,
     std::function<void(uint32_t, uint8_t, bool)> audioActivityUpdated,
+    bool zeroAudioLevel,
+    std::function<void(uint32_t)> anyActivityUpdated,
     std::shared_ptr<Threads> threads) :
 _threads(std::move(threads)),
 _stateUpdated(std::move(stateUpdated)),
 _unknownSsrcPacketReceived(std::move(unknownSsrcPacketReceived)),
 _dataChannelStateUpdated(dataChannelStateUpdated),
 _dataChannelMessageReceived(dataChannelMessageReceived),
-_audioActivityUpdated(audioActivityUpdated) {
+_audioActivityUpdated(audioActivityUpdated),
+_zeroAudioLevel(zeroAudioLevel),
+_anyActivityUpdated(anyActivityUpdated) {
     assert(_threads->getNetworkThread()->IsCurrent());
 
     _localIceParameters = PeerIceParameters(rtc::CreateRandomString(cricket::ICE_UFRAG_LENGTH), rtc::CreateRandomString(cricket::ICE_PWD_LENGTH), false);
@@ -343,7 +358,7 @@ _audioActivityUpdated(audioActivityUpdated) {
 
     _dtlsSrtpTransport = std::make_unique<WrappedDtlsSrtpTransport>(true, fieldTrials, [this](webrtc::RtpPacketReceived const &packet, bool isUnresolved) {
         this->RtpPacketReceived_n(packet, isUnresolved);
-    });
+    }, _zeroAudioLevel);
     _dtlsSrtpTransport->SetDtlsTransports(nullptr, nullptr);
     _dtlsSrtpTransport->SetActiveResetSrtpParams(false);
     _dtlsSrtpTransport->SubscribeReadyToSend(this, [this](bool value) {
@@ -370,7 +385,14 @@ GroupNetworkManager::~GroupNetworkManager() {
 
 void GroupNetworkManager::resetDtlsSrtpTransport() {
     std::unique_ptr<cricket::BasicPortAllocator> portAllocator = std::make_unique<cricket::BasicPortAllocator>(_networkManager.get(), _socketFactory.get(), _turnCustomizer.get(), nullptr);
-    portAllocator->set_flags(portAllocator->flags());
+    
+    uint32_t flags = portAllocator->flags();
+    
+    flags |=
+        cricket::PORTALLOCATOR_ENABLE_IPV6 |
+        cricket::PORTALLOCATOR_ENABLE_IPV6_ON_WIFI;
+    
+    portAllocator->set_flags(flags);
     portAllocator->Initialize();
 
     portAllocator->SetConfiguration({}, {}, 2, webrtc::NO_PRUNE, _turnCustomizer.get());
@@ -497,7 +519,7 @@ void GroupNetworkManager::setRemoteParams(PeerIceParameters const &remoteIcePara
     cricket::IceParameters parameters(
         remoteIceParameters.ufrag,
         remoteIceParameters.pwd,
-        false
+        true
     );
 
     _transportChannel->SetRemoteIceParameters(parameters);
@@ -608,6 +630,10 @@ void GroupNetworkManager::RtpPacketReceived_n(webrtc::RtpPacketReceived const &p
             }
         }
     }
+    
+    if (_anyActivityUpdated) {
+        _anyActivityUpdated(packet.Ssrc());
+    }
 
     if (isUnresolved && _unknownSsrcPacketReceived) {
         uint32_t ssrc = packet.Ssrc();
