@@ -11,4 +11,8 @@ namespace base::Platform {
 void Haptic() {
 }
 
+bool IsSwipeBackEnabled() {
+	return true;
+}
+
 } // namespace base::Platform
