@@ -7,7 +7,9 @@
 #include "lottie/lottie_icon.h"
 
 #include "lottie/lottie_common.h"
+#include "lottie/lottie_wrap.h"
 #include "ui/image/image_prepare.h"
+#include "ui/text/text_custom_emoji.h"
 #include "ui/style/style_core.h"
 
 #include <QtGui/QPainter>
@@ -16,10 +18,6 @@
 #include <crl/crl_on_main.h>
 #include <rlottie.h>
 
-#if __has_include(<glib.h>)
-#include <glib.h>
-#endif
-
 namespace Lottie {
 namespace {
 
@@ -27,7 +25,6 @@ namespace {
 		const QByteArray &content,
 		QColor replacement) {
 	auto string = ReadUtf8(Images::UnpackGzip(content));
-#ifndef LOTTIE_USE_PACKAGED_RLOTTIE
 	auto list = std::vector<std::pair<std::uint32_t, std::uint32_t>>();
 	if (replacement != Qt::white) {
 		const auto value = (uint32_t(replacement.red()) << 16)
@@ -35,31 +32,17 @@ namespace {
 			| (uint32_t(replacement.blue()));
 		list.push_back({ 0xFFFFFFU, value });
 	}
-	auto result = rlottie::Animation::loadFromData(
+	auto result = LoadAnimationFromData(
 		std::move(string),
 		std::string(),
 		std::string(),
 		false,
 		std::move(list));
-#else
-#if __has_include(<glib.h>)
-	[[maybe_unused]] static auto logged = [&] {
-		g_warning(
-			"rlottie is incompatible, expect animations with color issues.");
-		return true;
-	}();
-#endif
-	auto result = rlottie::Animation::loadFromData(
-		std::move(string),
-		std::string(),
-		std::string(),
-		false);
-#endif
 	return result;
 }
 
 [[nodiscard]] QColor RealRenderedColor(QColor color) {
-#ifndef LOTTIE_USE_PACKAGED_RLOTTIE
+#ifndef LOTTIE_DISABLE_RECOLORING
 	return QColor(color.red(), color.green(), color.blue(), 255);
 #else
 	return Qt::white;
@@ -78,6 +61,116 @@ namespace {
 			ReadContent({}, u":/animations/"_q + name + u".tgs"_q));
 }
 
+class LocalLottieCustomEmoji final
+	: public Ui::Text::CustomEmoji
+	, public base::has_weak_ptr {
+public:
+	LocalLottieCustomEmoji(
+		Lottie::IconDescriptor &&descriptor,
+		Fn<void()> repaint);
+	~LocalLottieCustomEmoji() override = default;
+
+	int width() override;
+	QString entityData() override;
+	void paint(QPainter &p, const Context &context) override;
+	void unload() override;
+	bool ready() override;
+	bool readyInDefaultState() override;
+
+private:
+	void startAnimation();
+	void handleAnimationFrame();
+
+	int _width = 0;
+	const QString _entityData;
+	std::unique_ptr<Lottie::Icon> _icon;
+	Fn<void()> _repaint;
+	bool _looped = true;
+};
+
+LocalLottieCustomEmoji::LocalLottieCustomEmoji(
+	Lottie::IconDescriptor &&descriptor,
+	Fn<void()> repaint)
+: _width(descriptor.sizeOverride.width())
+, _entityData(!descriptor.name.isEmpty()
+	? descriptor.name
+	: descriptor.path.isEmpty()
+	? descriptor.path
+	: u"lottie_custom_emoji"_q)
+, _icon(Lottie::MakeIcon(std::move(descriptor)))
+, _repaint(std::move(repaint)) {
+	if (!_width && _icon && _icon->valid()) {
+		_width = _icon->width();
+		startAnimation();
+	}
+}
+
+int LocalLottieCustomEmoji::width() {
+	return _width;
+}
+
+QString LocalLottieCustomEmoji::entityData() {
+	return _entityData;
+}
+
+void LocalLottieCustomEmoji::paint(QPainter &p, const Context &context) {
+	if (!_icon || !_icon->valid()) {
+		return;
+	}
+
+	const auto color = context.textColor;
+	const auto position = context.position;
+	const auto paused = context.paused
+		|| context.internal.forceFirstFrame
+		|| context.internal.overrideFirstWithLastFrame;
+
+	if (paused) {
+		const auto frame = context.internal.forceLastFrame
+			? _icon->framesCount() - 1
+			: 0;
+		_icon->jumpTo(frame, _repaint);
+	} else if (!_icon->animating()) {
+		startAnimation();
+	}
+
+	_icon->paint(p, position.x(), position.y(), color);
+}
+
+void LocalLottieCustomEmoji::unload() {
+	if (_icon) {
+		_icon->jumpTo(0, nullptr);
+	}
+}
+
+bool LocalLottieCustomEmoji::ready() {
+	return _icon && _icon->valid();
+}
+
+bool LocalLottieCustomEmoji::readyInDefaultState() {
+	return _icon && _icon->valid() && _icon->frameIndex() == 0;
+}
+
+void LocalLottieCustomEmoji::startAnimation() {
+	if (!_icon || !_icon->valid() || _icon->framesCount() <= 1) {
+		return;
+	}
+
+	_icon->animate(
+		[weak = base::make_weak(this)] {
+			if (const auto strong = weak.get()) {
+				strong->handleAnimationFrame();
+			}
+		},
+		0,
+        _icon->framesCount() - 1);
+}
+
+void LocalLottieCustomEmoji::handleAnimationFrame() {
+	if (_repaint && _looped && _icon->frameIndex() > 0) {
+		_repaint();
+	}
+}
+
 } // namespace
 
 struct Icon::Frame {
@@ -191,6 +284,7 @@ void Icon::Inner::prepareFromAsync(
 		std::move(surface));
 	_current.renderedColor = RealRenderedColor(color);
 	_current.renderedImage = std::move(image);
+	_current.colorizedColor = QColor(); // Mark colorizedImage as invalid.
 	_desiredSize = size;
 }
 
@@ -302,6 +396,7 @@ void Icon::Inner::renderPreloadFrame(const QColor &color) {
 		std::move(surface));
 	_preloaded.renderedColor = color;
 	_preloaded.resizedImage = QImage();
+	_preloaded.colorizedColor = QColor(); // Mark colorizedImage as invalid.
 	_preloadState = PreloadState::Ready;
 	crl::on_main(_weak, [=] {
 		_weak->frameJumpFinished();
@@ -314,7 +409,8 @@ Icon::Icon(IconDescriptor &&descriptor)
 	base::make_weak(this),
 	descriptor.limitFps))
 , _color(descriptor.color)
-, _animationFrameTo(descriptor.frame) {
+, _animationFrameTo(descriptor.frame)
+, _colorizeUsingAlpha(descriptor.colorizeUsingAlpha) {
 	crl::async([
 		inner = _inner,
 		name = descriptor.name,
@@ -383,7 +479,13 @@ Icon::ResizedFrame Icon::frame(
 		frame.colorizedImage = CreateFrameStorage(desired);
 	}
 	frame.colorizedColor = color;
-	style::colorizeImage(frame.renderedImage, color, &frame.colorizedImage);
+	style::colorizeImage(
+		frame.renderedImage,
+		color,
+		&frame.colorizedImage,
+		QRect(),
+		QPoint(),
+		_colorizeUsingAlpha);
 	return { frame.colorizedImage };
 }
 
@@ -413,7 +515,7 @@ void Icon::paint(
 	}
 	const auto rect = QRect{ QPoint(x, y), size() };
 	if (color == frame.renderedColor || !_color) {
-		p.drawImage(rect, frame.renderedImage);
+		 p.drawImage(rect, frame.renderedImage);
 	} else if (color.alphaF() < 1.
 		&& (QColor(color.red(), color.green(), color.blue())
 			== frame.renderedColor)) {
@@ -441,7 +543,10 @@ void Icon::paint(
 		style::colorizeImage(
 			frame.renderedImage,
 			color,
-			&frame.colorizedImage);
+			&frame.colorizedImage,
+			QRect(),
+			QPoint(),
+			_colorizeUsingAlpha);
 		p.drawImage(rect, frame.colorizedImage);
 	}
 }
@@ -467,7 +572,12 @@ void Icon::animate(
 	if (frameFrom != frameTo) {
 		_animationFrameTo = frameTo;
 		_animation.start(
-			[=] { preloadNextFrame(); if (_repaint) _repaint(); },
+			[=] {
+				preloadNextFrame();
+				if (_repaint) {
+					_repaint();
+				}
+			},
 			frameFrom,
 			frameTo,
 			(duration
@@ -512,4 +622,12 @@ std::unique_ptr<Icon> MakeIcon(IconDescriptor &&descriptor) {
 	return std::make_unique<Icon>(std::move(descriptor));
 }
 
+std::unique_ptr<Ui::Text::CustomEmoji> MakeEmoji(
+		IconDescriptor &&descriptor,
+		Fn<void()> repaint) {
+	return std::make_unique<LocalLottieCustomEmoji>(
+		std::move(descriptor),
+		repaint);
+}
+
 } // namespace Lottie
