@@ -30,7 +30,7 @@ void ColorData::set(uchar r, uchar g, uchar b, uchar a) {
 
 void ComplexColor::subscribeToPaletteChanges() {
 	style::PaletteChanged(
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		refresh();
 	}, _lifetime);
 }
