@@ -142,7 +142,7 @@ void RippleButton::setForceRippled(
 			_forceRippledSubscription = style::PaletteChanged(
 			) | rpl::filter([=] {
 				return _ripple != nullptr;
-			}) | rpl::start_with_next([=] {
+			}) | rpl::on_next([=] {
 				_ripple->forceRepaint();
 			});
 			ensureRipple();
@@ -304,7 +304,7 @@ RoundButton::RoundButton(
 , _roundRect(st.radius ? st.radius : st::buttonRadius, _st.textBg)
 , _roundRectOver(st.radius ? st.radius : st::buttonRadius, _st.textBgOver) {
 	_textFull.value(
-	) | rpl::start_with_next([=](const TextWithEntities &text) {
+	) | rpl::on_next([=](const TextWithEntities &text) {
 		accessibilityNameChanged();
 		resizeToText(text);
 	}, lifetime());
@@ -368,6 +368,11 @@ void RoundButton::setTextFgOverride(std::optional<QColor> textFg) {
 	update();
 }
 
+void RoundButton::setIconOverride(const style::icon *icon) {
+	_iconOverride = icon;
+	update();
+}
+
 void RoundButton::finishNumbersAnimation() {
 	if (_numbers) {
 		_numbers->finishAnimating();
@@ -537,7 +542,9 @@ void RoundButton::paintEvent(QPaintEvent *e) {
 		_numbers->paint(p, textLeft, textTop, width());
 	}
 	if (!_st.icon.empty()) {
-		const auto &current = ((over || down) && !_st.iconOver.empty())
+		const auto &current = _iconOverride
+			? *_iconOverride
+			: ((over || down) && !_st.iconOver.empty())
 			? _st.iconOver
 			: _st.icon;
 		current.paint(p, QPoint(iconLeft, iconTop), width());
@@ -812,7 +819,7 @@ SettingsButton::SettingsButton(
 , _context(context) {
 	std::move(
 		text
-	) | rpl::start_with_next([this](TextWithEntities &&value) {
+	) | rpl::on_next([this](TextWithEntities &&value) {
 		setText(std::move(value));
 	}, lifetime());
 }
@@ -851,7 +858,7 @@ SettingsButton *SettingsButton::toggleOn(
 	}
 	std::move(
 		toggled
-	) | rpl::start_with_next([this](bool toggled) {
+	) | rpl::on_next([this](bool toggled) {
 		_toggle->setChecked(toggled, anim::type::normal);
 	}, lifetime());
 	_toggle->finishAnimating();
@@ -988,7 +995,7 @@ not_null<RippleButton*> CreateSimpleRectButton(
 		QWidget *parent,
 		const style::RippleAnimation &st) {
 	const auto result = CreateChild<SimpleRippleButton>(parent, st);
-	result->paintRequest() | rpl::start_with_next([result] {
+	result->paintRequest() | rpl::on_next([result] {
 		auto p = QPainter(result);
 		result->paintRipple(p, 0, 0);
 	}, result->lifetime());
@@ -1000,7 +1007,7 @@ not_null<RippleButton*> CreateSimpleSettingsButton(
 		const style::RippleAnimation &st,
 		const style::color &bg) {
 	const auto result = CreateChild<SimpleRippleButton>(parent, st);
-	result->paintRequest() | rpl::start_with_next([result, bg] {
+	result->paintRequest() | rpl::on_next([result, bg] {
 		auto p = QPainter(result);
 		const auto paintOver = (result->isOver() || result->isDown())
 			&& !result->isDisabled();
@@ -1016,7 +1023,7 @@ not_null<RippleButton*> CreateSimpleCircleButton(
 		QWidget *parent,
 		const style::RippleAnimation &st) {
 	const auto result = CreateChild<SimpleCircleButton>(parent, st);
-	result->paintRequest() | rpl::start_with_next([result] {
+	result->paintRequest() | rpl::on_next([result] {
 		auto p = QPainter(result);
 		result->paintRipple(p, 0, 0);
 	}, result->lifetime());
@@ -1027,7 +1034,7 @@ not_null<RippleButton*> CreateSimpleRoundButton(
 		QWidget *parent,
 		const style::RippleAnimation &st) {
 	const auto result = CreateChild<SimpleRoundButton>(parent, st);
-	result->paintRequest() | rpl::start_with_next([result] {
+	result->paintRequest() | rpl::on_next([result] {
 		auto p = QPainter(result);
 		result->paintRipple(p, 0, 0);
 	}, result->lifetime());
