@@ -287,7 +287,7 @@ Fn<void()> CheckView::PrepareNonToggledError(
 	view->checkedChanges(
 	) | rpl::filter([=](bool checked) {
 		return checked;
-	}) | rpl::start_with_next([=] {
+	}) | rpl::on_next([=] {
 		state->error = false;
 		view->setUntoggledOverride(std::nullopt);
 	}, lifetime);
@@ -505,7 +505,7 @@ Checkbox::Checkbox(
 	setCursor(style::cur_pointer);
 	std::move(
 		text
-	) | rpl::start_with_next([=](const TextWithEntities &value) {
+	) | rpl::on_next([=](const TextWithEntities &value) {
 		setMarkedText(value);
 	}, lifetime());
 }
@@ -943,7 +943,7 @@ Radiobutton::Radiobutton(
 	checkbox()->checkedChanges(
 	) | rpl::filter(
 		_1
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		_group->setValue(_value);
 	}, lifetime());
 
@@ -968,7 +968,7 @@ void Radiobutton::trackScreenReaderState() {
 	rpl::combine(
 		reader->activeValue(),
 		(_group->hasValue()
-			? std::move(maybeValue) | rpl::type_erased()
+			? (std::move(maybeValue) | rpl::type_erased)
 			: rpl::single(
 				std::optional<int>()
 			) | rpl::then(std::move(maybeValue)))
@@ -984,7 +984,7 @@ void Radiobutton::trackScreenReaderState() {
 			}
 		}
 		return Qt::StrongFocus;
-	}) | rpl::start_with_next([=](Qt::FocusPolicy value) {
+	}) | rpl::on_next([=](Qt::FocusPolicy value) {
 		if (focusPolicy() != value) {
 			setFocusPolicy(value);
 		}
@@ -1065,6 +1065,14 @@ AccessibilityState Checkbox::accessibilityState() const {
 	return { .checkable = true, .checked = checked() };
 }
 
+void Checkbox::accessibilityDoAction(const QString &name) {
+	if (name == QAccessibleActionInterface::pressAction()) {
+		if (!isDisabled()) {
+			handlePress();
+		}
+	}
+}
+
 bool Checkbox::isSubmitEvent(not_null<QKeyEvent*> e) const {
 	return !e->isAutoRepeat()
 		&& (e->key() == Qt::Key_Space
