@@ -361,7 +361,7 @@ ElasticScroll::ElasticScroll(
 	setAttribute(Qt::WA_AcceptTouchEvents);
 
 	_bar->visibleFromDragged(
-	) | rpl::start_with_next([=](int from) {
+	) | rpl::on_next([=](int from) {
 		tryScrollTo(from, false);
 	}, _bar->lifetime());
 }
